@@ -1,19 +1,30 @@
 <?php
-	# Mantis - a php based bugtracking system
-	# Copyright (C) 2000 - 2002  Kenzaburo Ito - kenito@300baud.org
-	# Copyright (C) 2002 - 2004  Mantis Team   - mantisbt-dev@lists.sourceforge.net
-	# This program is distributed under the terms and conditions of the GPL
-	# See the README and LICENSE files for details
+# Mantis - a php based bugtracking system
+
+# Copyright (C) 2000 - 2002  Kenzaburo Ito - kenito@300baud.org
+# Copyright (C) 2002 - 2007  Mantis Team   - mantisbt-dev@lists.sourceforge.net
+
+# Mantis is free software: you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation, either version 2 of the License, or
+# (at your option) any later version.
+#
+# Mantis is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with Mantis.  If not, see <http://www.gnu.org/licenses/>.
 
 	# --------------------------------------------------------
-	# $Id: install.php,v 1.22.10.3 2006/05/05 16:03:25 vboctor Exp $
+	# $Id: install.php,v 1.38.2.1 2007-10-13 22:34:55 giallu Exp $
 	# --------------------------------------------------------
-?>
-<?php
+
 	error_reporting( E_ALL );
 
 	//@@@ put this somewhere
-	set_time_limit ( 0 ) ;
+	@set_time_limit ( 0 ) ;
 	$g_skip_open_db = true;  # don't open the database in database_api.php
 	@require_once( dirname( dirname( __FILE__ ) ) . DIRECTORY_SEPARATOR . 'core.php' );
 	$g_error_send_page_header = false; # bypass page headers in error handler
@@ -80,10 +91,22 @@
 	$f_database_name = gpc_get( 'database_name', config_get( 'database_name', 'bugtrack') );
 	$f_db_username = gpc_get( 'db_username', config_get( 'db_username', '' ) );
 	$f_db_password = gpc_get( 'db_password', config_get( 'db_password', '' ) );
+	if ( CONFIGURED_PASSWORD == $f_db_password ) {
+		$f_db_password = config_get( 'db_password' ); 
+	}
 	$f_admin_username = gpc_get( 'admin_username', '' );
 	$f_admin_password = gpc_get( 'admin_password', '');
 	$f_log_queries = gpc_get_bool( 'log_queries', false );
 	$f_db_exists = gpc_get_bool( 'db_exists', false );
+
+	$f_db_schema='';	
+	if ( $f_db_type == 'db2' ) {
+		# If schema name is supplied, then separate it from database name.
+		if ( strpos( $f_database_name, '/' ) != false ) {
+			$f_db2AS400 = $f_database_name;
+			list( $f_database_name, $f_db_schema ) = split( '/', $f_db2AS400, 2 );
+		}
+	}
 ?>
 <html>
 <head>
@@ -145,18 +168,14 @@ if ( 0 == $t_install_state ) {
 		Checking PHP version (your version is <?php echo phpversion(); ?>)
 	</td>
 	<?php
-		if (phpversion() == '4.0.6') {
-			print_test_result( GOOD );
-		} else {
-			if ( function_exists ( 'version_compare' ) ) {
-				if ( version_compare ( phpversion() , '4.0.6', '>=' ) ) {
-					print_test_result( GOOD );
-				} else {
-					print_test_result( BAD, true, 'Upgrade to a more recent version of PHP' );
-				}
+		if ( function_exists ( 'version_compare' ) ) {
+			if ( version_compare ( phpversion() , '4.3.0', '>=' ) ) {
+				print_test_result( GOOD );
 			} else {
-			 	print_test_result( BAD, true, 'Upgrade to a more recent version of PHP' );
+				print_test_result( BAD, true, 'Upgrade to a more recent version of PHP' );
 			}
+		} else {
+		 	print_test_result( BAD, true, 'Upgrade to a more recent version of PHP' );
 		}
 	?>
 </tr>
@@ -208,6 +227,9 @@ if ( 2 == $t_install_state ) {
 				case 'oci8':
 					$t_support = function_exists('OCILogon');
 					break;
+				case 'db2':
+					$t_support = function_exists( 'db2_connect' );
+					break;
 				default:
 					$t_support = false;
 			}
@@ -223,6 +245,11 @@ if ( 2 == $t_install_state ) {
 <?php print_test( 'Setting Database Username', '' !== $f_db_username , true, 'database username is blank' ) ?>
 <?php print_test( 'Setting Database Password', '' !== $f_db_password , false, 'database password is blank' ) ?>
 <?php print_test( 'Setting Database Name', '' !== $f_database_name , true, 'database name is blank' )?>
+<?php
+	if ( $f_db_type == 'db2' ) {
+		print_test( 'Setting Database Schema', !is_blank( $f_db_schema ), true, 'must have a schema name for AS400 in the form of DBNAME/SCHEMA' );
+	}
+?>
 <tr>
 	<td bgcolor="#ffffff">
 		Setting Admin Username
@@ -260,51 +287,30 @@ if ( 2 == $t_install_state ) {
 		Attempting to connect to database as admin
 	</td>
 	<?php
+        $t_db_open = false;
 		$g_db = ADONewConnection($f_db_type);
 		$t_result = @$g_db->Connect($f_hostname, $f_admin_username, $f_admin_password);
 
 		if ( $t_result ) {
-			print_test_result( GOOD );
 			# check if db exists for the admin
 			$t_result = @$g_db->Connect($f_hostname, $f_admin_username, $f_admin_password, $f_database_name);
 			if ( $t_result ) {
+    			$t_db_open = true;
 				$f_db_exists = true;
 			}
+    		if ( $f_db_type == 'db2' ) {
+    			$result = &$g_db->execute( 'set schema ' . $f_db_schema );
+    			if ( $result === false ) {
+        			print_test_result( BAD, true, 'set schema failed: ' . $g_db->errorMsg() );
+    			}
+    		} else {			
+			    print_test_result( GOOD );
+			}
 		} else {
 			print_test_result( BAD, true, 'Does administrative user have access to the database? ( ' .  db_error_msg() . ' )' );
 		}
-	?>
-</tr>
 
-<!-- display database version -->
-<tr>
-	<td bgcolor="#ffffff">
-		Checking Database Server Version
-		<?php
-			# due to a bug in ADODB, this call prompts warnings, hence the @
-			$t_version_info = @$g_db->ServerInfo();
-			echo '<br /> Running ' . $f_db_type . ' version ' . $t_version_info['description'];
-		?>
-	</td>
-	<?php
-		$t_warning = '';
-		$t_error = '';
-		switch ( $f_db_type ) {
-			case 'mysql':
-			case 'mysqli':
-				if ( function_exists ( 'version_compare' ) ) {
-					if ( version_compare ( $t_version_info['version'] , '4.1.0', '>' ) ) {
-						$t_warning = 'Please ensure that your installation supports the new password scheme used in MySQL 4.1.0 and later. See ' .
-							'<a href="http://dev.mysql.com/doc/mysql/en/password-hashing.html">http://dev.mysql.com/doc/mysql/en/password-hashing.html</a>.';
-					}
-				}
-				break;
-			case 'pgsql':
-			case 'mssql':
-			default:
-		}
-			
-		print_test_result( ( '' == $t_error ) && ( '' == $t_warning ), ( '' != $t_error ), $t_error . ' ' . $t_warning );
+		
 	?>
 </tr>
 <?php
@@ -319,13 +325,56 @@ if ( 2 == $t_install_state ) {
 		$t_result = @$g_db->Connect($f_hostname, $f_db_username, $f_db_password, $f_database_name);
 
 		if ( $t_result == true ) {
-			print_test_result( GOOD );
+			$t_db_open = true;
+    		if ( $f_db_type == 'db2' ) {
+    			$result = &$g_db->execute( 'set schema ' . $f_db_schema );
+    			if ( $result === false ) {
+        			print_test_result( BAD, true, 'set schema failed: ' . $g_db->errorMsg() );
+    			}
+    		} else {		
+			    print_test_result( GOOD );
+		    }
 		} else {
 			print_test_result( BAD, false, 'Database user doesn\'t have access to the database ( ' .  db_error_msg() . ' )' );
 		}
 	?>
 </tr>
 
+<?php 
+    }
+    if( $t_db_open ) {
+?>
+<!-- display database version -->
+<tr>
+	<td bgcolor="#ffffff">
+		Checking Database Server Version
+		<?php
+			# due to a bug in ADODB, this call prompts warnings, hence the @
+			# the check only works on mysql if the database is open
+			$t_version_info = @$g_db->ServerInfo();
+			echo '<br /> Running ' . $f_db_type . ' version ' . $t_version_info['description'];
+		?>
+	</td>
+	<?php
+		$t_warning = '';
+		$t_error = '';
+		switch ( $f_db_type ) {
+			case 'mysql':
+			case 'mysqli':
+				if ( version_compare ( $t_version_info['version'] , '4.1.0', '<' ) ) {
+					$t_error = 'MySQL 4.1.0 or later is required for installation.';
+				}
+				break;
+			case 'pgsql':
+			case 'mssql':
+			case 'db2':
+			default:
+				break;
+		}
+			
+		print_test_result( ( '' == $t_error ) && ( '' == $t_warning ), ( '' != $t_error ), $t_error . ' ' . $t_warning );
+	?>
+</tr>
 <?php
 	}
 	if ( false == $g_failed ) {
@@ -382,6 +431,12 @@ if ( 1 == $t_install_state ) {
 			} else {
 				echo '<option value="oci8">Oracle - oci8 (Experimental)</option>';
 			}
+
+			if ( $f_db_type == 'db2' ) {
+				echo '<option value="db2" selected="selected">db2/400 (experimental)</option>';
+			} else {
+				echo '<option value="db2">db2/400 (experimental)</option>';
+			}
 		?>
 		</select>
 	</td>
@@ -410,7 +465,7 @@ if ( 1 == $t_install_state ) {
 		Password (for Database)
 	</td>
 	<td>
-		<input name="db_password" type="password" value="<?php echo $f_db_password ?>"></input>
+		<input name="db_password" type="password" value="<?php echo ( !is_blank( $f_db_password ) ? CONFIGURED_PASSWORD : "" ) ?>"></input>
 	</td>
 </tr>
 
@@ -480,27 +535,100 @@ if ( 3 == $t_install_state ) {
 	</td>
 	<?php
 		$t_result = @$g_db->Connect( $f_hostname, $f_admin_username, $f_admin_password, $f_database_name );
-		$g_db->Close();
 
-		if ( $t_result == true ) {
-			print_test_result( GOOD );
+		if ( $f_db_type == 'db2' ) {
+			$rs = $g_db->Execute("select * from SYSIBM.SCHEMATA WHERE SCHEMA_NAME = '" . $f_db_schema . "' AND SCHEMA_OWNER = '" . $f_db_username . "'" ); 
+			if ( $rs === false ) {
+				echo "<br />false";
+			}
+
+			if ( $rs->EOF ) {
+				$t_result = false;
+				echo $g_db->errorMsg();
+			} else {
+				$t_result = &$g_db->execute( 'set schema ' . $f_db_schema );
+			}
+		}
+
+		$t_db_open = false;
+		
+	if ( $t_result == true ) {
+		print_test_result( GOOD );
+		$t_db_open = true;
+	} else {
+		// create db
+		$g_db = ADONewConnection( $f_db_type );
+		$t_result = $g_db->Connect( $f_hostname, $f_admin_username, $f_admin_password );
+
+		$dict = NewDataDictionary( $g_db );
+
+		if ( $f_db_type == 'db2' ) {
+			$rs = &$g_db->Execute("CREATE SCHEMA "   . $f_db_schema  );   
+
+			if ( !$rs ) {
+				$t_result = false;
+				print_test_result( BAD, true, 'Does administrative user have access to create the database? ( ' .  db_error_msg() . ' )' );
+				$t_install_state--;	# db creation failed, allow user to re-enter user/password info
+			} else {
+				print_test_result( GOOD );
+				$t_db_open = true;
+			}
 		} else {
-			// create db
-			$g_db = ADONewConnection( $f_db_type );
-			$t_result = $g_db->Connect( $f_hostname, $f_admin_username, $f_admin_password );
-			$dict = NewDataDictionary( $g_db );
 			$sqlarray = $dict->CreateDatabase( $f_database_name );
 			$ret = $dict->ExecuteSQLArray( $sqlarray );
 			if( $ret == 2) {
 				print_test_result( GOOD );
+				$t_db_open = true;
 			} else {
-				print_test_result( BAD, true, 'Does administrative user have access to create the database? ( ' .  db_error_msg() . ' )' );
-				$t_install_state--;	# db creation failed, allow user to re-enter user/password info
+				$t_error = db_error_msg();
+				if( strstr( $t_error, 'atabase exists' ) ) {
+					print_test_result( BAD, false, 'Database already exists? ( ' .  db_error_msg() . ' )' );
+				} else {
+					print_test_result( BAD, true, 'Does administrative user have access to create the database? ( ' .  db_error_msg() . ' )' );
+					$t_install_state--;	# db creation failed, allow user to re-enter user/password info
+				}
 			}
-			$g_db->Close();
 		}
+	}
 	?>
 </tr>
+<?php 
+    if( $t_db_open ) {
+?>
+<!-- display database version -->
+<tr>
+	<td bgcolor="#ffffff">
+		Checking Database Server Version
+		<?php
+			# due to a bug in ADODB, this call prompts warnings, hence the @
+			$t_version_info = @$g_db->ServerInfo();
+			echo '<br /> Running ' . $f_db_type . ' version ' . $t_version_info['description'];
+		?>
+	</td>
+	<?php
+		$t_warning = '';
+		$t_error = '';
+		switch ( $f_db_type ) {
+			case 'mysql':
+			case 'mysqli':
+				if ( version_compare ( $t_version_info['version'] , '4.1.0', '<' ) ) {
+					$t_error = 'MySQL 4.1.0 or later is required for installation.';
+				}
+				break;
+			case 'pgsql':
+			case 'mssql':
+			case 'db2':
+			default:
+				break;
+		}
+			
+		print_test_result( ( '' == $t_error ) && ( '' == $t_warning ), ( '' != $t_error ), $t_error . ' ' . $t_warning );
+	?>
+</tr>
+<?php
+    }
+	$g_db->Close();
+?>
 <tr>
 	<td bgcolor="#ffffff">
 		Attempting to connect to database as user
@@ -509,6 +637,13 @@ if ( 3 == $t_install_state ) {
 		$g_db = ADONewConnection($f_db_type);
 		$t_result = @$g_db->Connect($f_hostname, $f_db_username, $f_db_password, $f_database_name);
 
+		if ( $f_db_type == 'db2' ) {
+			$result = &$g_db->execute( 'set schema ' . $f_db_schema );
+			if ( $result === false ) {
+				echo $g_db->errorMsg();
+			}
+		}
+
 		if ( $t_result == true ) {
 			print_test_result( GOOD );
 		} else {
@@ -519,6 +654,7 @@ if ( 3 == $t_install_state ) {
 </tr>
 <?php
 	}
+
 	# install the tables
 	if ( false == $g_failed ) {
 		$g_db_connected = false; # fake out database access routines used by config_get
@@ -536,15 +672,31 @@ if ( 3 == $t_install_state ) {
 			echo '<tr><td bgcolor="#ffffff" col_span="2"> Database Creation Suppressed, SQL Queries follow <pre>';
 		}
 
+		if ( $f_db_type == 'db2' ) {
+			$result = &$g_db->execute( 'set schema ' . $f_db_schema );
+			if ( $result === false ) {
+				echo $g_db->errorMsg();
+			}
+		}
+
 		while ( ( $i <= $lastid ) && ! $g_failed ) {
 			if ( ! $f_log_queries ) {
-				echo '<tr><td bgcolor="#ffffff">Create Schema ( ' . $upgrade[$i][0] . ' on ' . $upgrade[$i][1][0] . ' )</td>';
+				echo '<tr><td bgcolor="#ffffff">';
 			}
 
 			$dict = NewDataDictionary($g_db);
+			$t_sql = true;
+			$t_target = $upgrade[$i][1][0];
 			if ( $upgrade[$i][0] == 'InsertData' ) {
 				$sqlarray = call_user_func_array( $upgrade[$i][0], $upgrade[$i][1] );
-			} else {
+			} else if ( $upgrade[$i][0] == 'UpdateSQL' ) {
+    			$sqlarray = array( $upgrade[$i][1] );
+    			$t_target = $upgrade[$i][1];
+    		} else if ( $upgrade[$i][0] == 'UpdateFunction' ) {
+        		$sqlarray = array( $upgrade[$i][1] );
+        		$t_sql = false;
+    			$t_target = $upgrade[$i][1];
+    		} else {
 				$sqlarray = call_user_func_array(Array($dict,$upgrade[$i][0]),$upgrade[$i][1]);
 			}
 			if ( $f_log_queries ) {
@@ -552,7 +704,11 @@ if ( 3 == $t_install_state ) {
 					echo htmlentities( $sql ) . ";\r\n\r\n";
 				}
 			} else {
-				$ret = $dict->ExecuteSQLArray($sqlarray);
+    			echo 'Schema ' . $upgrade[$i][0] . ' ( ' . $t_target . ' )</td>';
+			    if ($t_sql)
+				    $ret = $dict->ExecuteSQLArray($sqlarray);
+				else 
+				    $ret = call_user_func( 'install_' . $sqlarray[0] );
 				if ( $ret == 2 ) {
 					print_test_result( GOOD );
 					config_set( 'database_version', $i );
@@ -603,6 +759,8 @@ if ( 4 == $t_install_state ) {
 
 # all checks have passed, install the database
 if ( 5 == $t_install_state ) {
+		$t_config_filename = $g_absolute_path . 'config_inc.php';
+		$t_config_exists = file_exists ( $t_config_filename );
 ?>
 <table width="100%" border="0" cellpadding="10" cellspacing="1">
 <tr>
@@ -613,8 +771,14 @@ if ( 5 == $t_install_state ) {
 
 <tr>
 	<td bgcolor="#ffffff">
-		Creating Default Config File<br />
-		<font color="red">(if this file is not created, create it manually with the contents below)</font>
+		<?php
+			if ( !$t_config_exists ) {
+				echo 'Creating Configuration File (config_inc.php)<br />';
+				echo '<font color="red">(if this file is not created, create it manually with the contents below)</font>';
+			} else {
+				echo 'Updating Configuration File (config_inc.php)<br />';
+			}
+		 ?>
 	</td>
 	<?php
 		$t_config = '<?php'."\r\n";
@@ -623,12 +787,16 @@ if ( 5 == $t_install_state ) {
 		$t_config .= "\t\$g_database_name = '$f_database_name';\r\n";
 		$t_config .= "\t\$g_db_username = '$f_db_username';\r\n";
 		$t_config .= "\t\$g_db_password = '$f_db_password';\r\n";
+
+		if ( $f_db_type == 'db2' ) {
+			$t_config .= "\t\$g_db_schema = '$f_db_schema';\r\n";
+		}
+
 		$t_config .= '?>' . "\r\n";
 		$t_write_failed = true;
 
-		$t_config_filename = $g_absolute_path . 'config_inc.php';
-		if ( !file_exists ( $t_config_filename ) ) {
-			if ( $fd = @fopen( $t_config_filename, 'x' ) ) {
+		if ( !$t_config_exists ) {
+			if ( $fd = @fopen( $t_config_filename, 'w' ) ) {
 				fwrite( $fd, $t_config );
 				fclose( $fd );
 			}
@@ -644,6 +812,7 @@ if ( 5 == $t_install_state ) {
 			if ( ( $f_hostname != config_get( 'hostname', '' ) ) ||
 					( $f_db_type != config_get( 'db_type', '' ) ) ||
 					( $f_database_name != config_get( 'database_name', '') ) ||
+					( $f_db_schema != config_get( 'db_schema', '') ) ||
 					( $f_db_username != config_get( 'db_username', '' ) ) ||
 					( $f_db_password != config_get( 'db_password', '' ) ) ) {
 				print_test_result( BAD, false, 'file ' . $g_absolute_path . 'config_inc.php' . ' already exists and has different settings' );
@@ -680,9 +849,6 @@ if ( 6 == $t_install_state ) {
 	</td>
 </tr>
 
-<!-- Checking MD5 -->
-<?php print_test( 'Checking for MD5 Crypt() support', 1 === CRYPT_MD5, false, 'password security may be lower than expected' ) ?>
-
 <!-- Checking register_globals are off -->
 <?php print_test( 'Checking for register_globals are off for mantis', ! ini_get_bool( 'register_globals' ), false, 'change php.ini to disable register_globals setting' ) ?>
 
@@ -699,6 +865,13 @@ if ( 6 == $t_install_state ) {
 		} else {
 			print_test_result( BAD, false, 'Database user doesn\'t have access to the database ( ' .  db_error_msg() . ' )' );
 		}
+
+		if ( $f_db_type == 'db2' ) {
+			$result = &$g_db->execute('set schema ' . $f_db_schema);
+			if ( $result === false ) {
+				echo $g_db->errorMsg();
+			}
+		}
 	?>
 </tr>
 <tr>
