@@ -1,17 +1,30 @@
 <?php
-	# Mantis - a php based bugtracking system
-	# Copyright (C) 2000 - 2002  Kenzaburo Ito - kenito@300baud.org
-	# Copyright (C) 2002 - 2004  Mantis Team   - mantisbt-dev@lists.sourceforge.net
-	# This program is distributed under the terms and conditions of the GPL
-	# See the README and LICENSE files for details
+# Mantis - a php based bugtracking system
+
+# Copyright (C) 2000 - 2002  Kenzaburo Ito - kenito@300baud.org
+# Copyright (C) 2002 - 2007  Mantis Team   - mantisbt-dev@lists.sourceforge.net
+
+# Mantis is free software: you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation, either version 2 of the License, or
+# (at your option) any later version.
+#
+# Mantis is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with Mantis.  If not, see <http://www.gnu.org/licenses/>.
 
 	# --------------------------------------------------------
-	# $Id: system_utils.php,v 1.4 2004/09/23 21:22:12 thraxisp Exp $
+	# $Id: system_utils.php,v 1.9.2.1 2007-10-13 22:34:56 giallu Exp $
 	# --------------------------------------------------------
 ?>
 <?php
 	require_once ( dirname( dirname( __FILE__ ) ) . DIRECTORY_SEPARATOR . 'core.php' );
 ?>
+<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
 <html>
 <head>
 <title>Mantis Administration - System Utilities</title>
@@ -23,7 +36,6 @@
 	<tr class="top-bar">
 		<td class="links">
 			[ <a href="index.php">Back to Mantis Administration</a> ]
-			[ <a href="upgrade_escaping.php">Refresh view</a> ]
 		</td>
 		<td class="title">
 			System Utilities
@@ -54,7 +66,7 @@
 	<form method="post" action="copy_field.php">
 	   From
 		<SELECT name="source_id">
-			<?php 
+			<?php
 				$t_custom_ids = custom_field_get_ids();
 				foreach ( $t_custom_ids as $t_id ) {
 					printf("<OPTION VALUE=\"%d\">%s", $t_id, custom_field_get_field($t_id, 'name' ) );
@@ -71,16 +83,15 @@
 				}
 			?>
 		</SELECT>
-	<input type="submit" class="button" value="Copy" >
+	<input type="submit" class="button" value="Copy" />
 	</form>
 	</center></td></tr>
 
-	<!-- move database project files to disk -->
-	<tr bgcolor="#ffffff"><td>Analyse Workflow</td><td><center>
-	<?php html_button( 'workflow.php', 'Analyse' ); ?>
+	<!-- Database Statistics -->
+	<tr bgcolor="#ffffff"><td>Show database statistics.</td><td><center>
+	<?php html_button( 'db_stats.php', 'Display', array() ); ?>
 	</center></td></tr>
 
-
 </table>
 </body>
-</html>
\ No newline at end of file
+</html>
