@@ -1,12 +1,24 @@
 <?php
-	# Mantis - a php based bugtracking system
-	# Copyright (C) 2000 - 2002  Kenzaburo Ito - kenito@300baud.org
-	# Copyright (C) 2002 - 2004  Mantis Team   - mantisbt-dev@lists.sourceforge.net
-	# This program is distributed under the terms and conditions of the GPL
-	# See the README and LICENSE files for details
+# Mantis - a php based bugtracking system
+
+# Copyright (C) 2000 - 2002  Kenzaburo Ito - kenito@300baud.org
+# Copyright (C) 2002 - 2007  Mantis Team   - mantisbt-dev@lists.sourceforge.net
+
+# Mantis is free software: you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation, either version 2 of the License, or
+# (at your option) any later version.
+#
+# Mantis is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with Mantis.  If not, see <http://www.gnu.org/licenses/>.
 
 	# --------------------------------------------------------
-	# $Id: bug_actiongroup_page.php,v 1.52 2005/08/04 16:59:39 thraxisp Exp $
+	# $Id: bug_actiongroup_page.php,v 1.55.2.1 2007-10-13 22:32:34 giallu Exp $
 	# --------------------------------------------------------
 ?>
 <?php
@@ -52,8 +64,15 @@
 	$t_finished = false;
 	$t_request = '';
 
-	$t_custom_group_actions = config_get( 'custom_group_actions' );
+	$t_external_action_prefix = 'EXT_';
+	if ( strpos( $f_action, $t_external_action_prefix ) === 0 ) {
+		$t_form_page = 'bug_actiongroup_ext_page.php';
+		require_once( $t_form_page );
+		exit;
+	}
 
+	$t_custom_group_actions = config_get( 'custom_group_actions' );
+	
 	foreach( $t_custom_group_actions as $t_custom_group_action ) {
 		if ( $f_action == $t_custom_group_action['action'] ) {
 			require_once( $t_custom_group_action['form_page'] );
@@ -74,18 +93,21 @@
 			$t_finished 			= true;
 			$t_question_title 		= lang_get( 'close_bugs_conf_msg' );
 			$t_button_title 		= lang_get( 'close_group_bugs_button' );
+			$t_form_name			= 'bug_close';
 			break;
 
 		case 'DELETE' :
 			$t_finished 			= true;
 			$t_question_title		= lang_get( 'delete_bugs_conf_msg' );
 			$t_button_title 		= lang_get( 'delete_group_bugs_button' );
+			$t_form_name			= 'bug_delete';
 			break;
 
 		case 'SET_STICKY' :
 			$t_finished 			= true;
 			$t_question_title		= lang_get( 'set_sticky_bugs_conf_msg' );
 			$t_button_title 		= lang_get( 'set_sticky_group_bugs_button' );
+			$t_form_name			= 'bug_set_sticky';
 			break;
 
 		# ...else we define the variables used in the form
@@ -93,18 +115,21 @@
 			$t_question_title 		= lang_get( 'move_bugs_conf_msg' );
 			$t_button_title 		= lang_get( 'move_group_bugs_button' );
 			$t_form					= 'project_id';
+			$t_form_name			= 'bug_move';
 			break;
 
 		case 'COPY' :
 			$t_question_title 		= lang_get( 'copy_bugs_conf_msg' );
 			$t_button_title 		= lang_get( 'copy_group_bugs_button' );
 			$t_form					= 'project_id';
+			$t_form_name			= 'bug_copy';
 			break;
 
 		case 'ASSIGN' :
 			$t_question_title 		= lang_get( 'assign_bugs_conf_msg' );
 			$t_button_title 		= lang_get( 'assign_group_bugs_button' );
 			$t_form 				= 'assign';
+			$t_form_name			= 'bug_assign';
 			break;
 
 		case 'RESOLVE' :
@@ -116,6 +141,7 @@
 				$t_question_title2 = lang_get( 'fixed_in_version' );
 				$t_form2 = 'fixed_in_version';
 			}
+			$t_form_name			= 'bug_resolve';
 			break;
 
 		case 'UP_PRIOR' :
@@ -123,6 +149,7 @@
 			$t_button_title 		= lang_get( 'priority_group_bugs_button' );
 			$t_form 				= 'priority';
 			$t_request 				= 'priority';
+			$t_form_name			= 'bug_update_priority';
 			break;
 
 		case 'UP_STATUS' :
@@ -130,20 +157,35 @@
 			$t_button_title 		= lang_get( 'status_group_bugs_button' );
 			$t_form 				= 'status';
 			$t_request 				= 'status';
+			$t_form_name			= 'bug_update_status';
 			break;
 
 		case 'UP_CATEGORY' :
 			$t_question_title		= lang_get( 'category_bugs_conf_msg' );
 			$t_button_title			= lang_get( 'category_group_bugs_button' );
 			$t_form					= 'category';
-			$t_request				= 'category';
+			$t_form_name			= 'bug_update_category';
 			break;
 
 		case 'VIEW_STATUS' :
 			$t_question_title		= lang_get( 'view_status_bugs_conf_msg' );
 			$t_button_title			= lang_get( 'view_status_group_bugs_button' );
-			$t_form				= 'view_status';
-			$t_request			= 'view_status';
+			$t_form					= 'view_status';
+			$t_form_name			= 'bug_update_view_status';
+			break;
+		
+		case 'UP_FIXED_IN_VERSION':
+			$t_question_title		= lang_get( 'fixed_in_version_bugs_conf_msg' );
+			$t_button_title			= lang_get( 'fixed_in_version_group_bugs_button' );
+			$t_form					= 'fixed_in_version';
+			$t_form_name			= 'bug_update_fixed_in_version';
+			break;
+
+		case 'UP_TARGET_VERSION':
+			$t_question_title		= lang_get( 'target_version_bugs_conf_msg' );
+			$t_button_title			= lang_get( 'target_version_group_bugs_button' );
+			$t_form					= 'target_version';
+			$t_form_name			= 'bug_update_target_version';
 			break;
 
 		case 'CUSTOM' :
@@ -151,6 +193,7 @@
 			$t_question_title = sprintf( lang_get( 'actiongroup_menu_update_field' ), lang_get_defaulted( $t_custom_field_def['name'] ) );
 			$t_button_title = $t_question_title;
 			$t_form = "custom_field_$t_custom_field_id";
+			$t_form_name			= 'bug_update_custom_field_' . $t_custom_field_id;
 			break;
 
 		default:
@@ -167,7 +210,12 @@
 <br />
 
 <div align="center">
-<form method="POST" action="bug_actiongroup.php">
+<form method="post" action="bug_actiongroup.php">
+<?php
+if ( !is_blank( $t_form_name ) ) {
+	echo form_security_field( $t_form_name );
+}
+?>
 <input type="hidden" name="action" value="<?php echo string_attribute( $f_action ) ?>" />
 <?php
 	bug_group_action_print_hidden_fields( $f_bug_arr );
@@ -215,6 +263,10 @@ if ( !$t_finished ) {
 				case 'UP_CATEGORY':
 					print_category_option_list();
 					break;
+				case 'UP_TARGET_VERSION':
+				case 'UP_FIXED_IN_VERSION':
+					print_version_option_list( '', $t_project_id, VERSION_ALL );
+					break;
 			}
 
 			# other forms use the same function to display the list
@@ -281,4 +333,4 @@ if ( !$t_finished ) {
 
 <?php
 	bug_group_action_print_bottom();
-?>
\ No newline at end of file
+?>
