@@ -1,12 +1,24 @@
 <?php
-	# Mantis - a php based bugtracking system
-	# Copyright (C) 2000 - 2002  Kenzaburo Ito - kenito@300baud.org
-	# Copyright (C) 2002 - 2006  Mantis Team   - mantisbt-dev@lists.sourceforge.net
-	# This program is distributed under the terms and conditions of the GPL
-	# See the README and LICENSE files for details
+# Mantis - a php based bugtracking system
+
+# Copyright (C) 2000 - 2002  Kenzaburo Ito - kenito@300baud.org
+# Copyright (C) 2002 - 2007  Mantis Team   - mantisbt-dev@lists.sourceforge.net
+
+# Mantis is free software: you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation, either version 2 of the License, or
+# (at your option) any later version.
+#
+# Mantis is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with Mantis.  If not, see <http://www.gnu.org/licenses/>.
 
 	# --------------------------------------------------------
-	# $Id: config_defaults_inc.php,v 1.283.2.1.2.1.2.1.2.2.2.15 2007/06/30 22:25:05 vboctor Exp $
+	# $Id: config_defaults_inc.php,v 1.364.2.6 2007-10-28 15:39:30 nuclear_eclipse Exp $
 	# --------------------------------------------------------
 
 
@@ -23,7 +35,7 @@
 	# In general a value of OFF means the feature is disabled and ON means the
 	# feature is enabled.  Any other cases will have an explanation.
 
-	# For more details see http://www.mantisbt.org/manual/
+	# For more details see http://manual.mantisbt.org/
 
 	################################
 	# Mantis Database Settings
@@ -41,9 +53,11 @@
 	$g_db_username			= 'root';
 	$g_db_password			= '';
 	$g_database_name		= 'bugtracker';
+	$g_db_schema			= ''; // used in the case of db2
 
-	# Supported types: mysql for MySQL, mysqli for MySQL, pgsql for PostgreSQL, mssql for MS SQL Server, oci8 for Oracle.
-	$g_db_type			= 'mysql';
+	# Supported types: 'mysql' or 'mysqli' for MySQL, 'pgsql' for PostgreSQL,
+	# 'mssql' for MS SQL Server, 'oci8' for Oracle, and 'db2' for DB2.
+	$g_db_type				= 'mysql';
 
 	############################
 	# Mantis Path Settings
@@ -70,7 +84,9 @@
 			$t_port = '';
 		}
 
-		if ( isset( $_SERVER['HTTP_HOST'] ) ) {
+		if ( isset( $_SERVER['HTTP_X_FORWARDED_HOST'] ) ) { // Support ProxyPass
+			$t_host = $_SERVER['HTTP_X_FORWARDED_HOST'];
+		} else if ( isset( $_SERVER['HTTP_HOST'] ) ) {
 			$t_host = $_SERVER['HTTP_HOST'];
 		} else if ( isset( $_SERVER['SERVER_NAME'] ) ) {
 			$t_host = $_SERVER['SERVER_NAME'] . $t_port;
@@ -79,8 +95,19 @@
 		} else {
 			$t_host = 'www.example.com';
 		}
-
+		
 		$t_path = dirname( strip_tags( $_SERVER['PHP_SELF'] ) );
+
+		# Remove /api/soap/ from the path to handle the case where the config_defaults_inc.php is included from the
+		# soap api.
+		$t_soap_api_path = '/api/soap';
+		$t_soap_api_path_pos = strpos( strtolower( $t_path ), $t_soap_api_path );
+		if ( $t_soap_api_path_pos !== false ) {
+			if ( $t_soap_api_path_pos == ( strlen( $t_path ) - strlen( $t_soap_api_path ) ) ) {
+				$t_path = substr( $t_path, 0, $t_soap_api_path_pos );
+			}
+		}
+
 		if ( '/' == $t_path || '\\' == $t_path ) {
 			$t_path = '';
 		}
@@ -103,7 +130,7 @@
 	$g_core_path			= $g_absolute_path . 'core' . DIRECTORY_SEPARATOR;
 
 	# Used to link to manual for User Documentation.
-	$g_manual_url = 'http://www.mantisbt.org/manual/';
+	$g_manual_url = 'http://manual.mantisbt.org/';
 
 	#############################
 	# Web Server
@@ -116,6 +143,11 @@
 		$g_use_iis = OFF;
 	}
 
+	# Session handler.  Possible values:
+	#   'php' -> Default PHP filesystem sessions
+	#   'adodb' -> Database storage sessions
+	#   'memcached' -> Memcached storage sessions
+	$g_session_handler = 'php';
 
 	#############################
 	# Configuration Settings
@@ -125,9 +157,9 @@
 	# These patterns will be concatenated and used as a regular expression
 	# to bypass the database lookup and look here for appropriate global settings.
 	$g_global_settings = array(
-		'_table$', 'cookie', '^db_', 'hostname', 'database_name',
+		'_table$', 'cookie', '^db_', 'hostname', 'database_name', 'session_handler',
 		'_path$', 'use_iis', 'language', 'use_javascript', 'display_errors', 'stop_on_errors', 'login_method', '_file$',
-		'anonymous', 'content_expire', 'html_valid_tags', 'custom_headers'
+		'anonymous', 'content_expire', 'html_valid_tags', 'custom_headers', 'rss_key_seed'
 	);
 
 	#############################
@@ -189,8 +221,11 @@
 	$g_administrator_email	= 'administrator@example.com';
 	$g_webmaster_email		= 'webmaster@example.com';
 
-	# the 'From: ' field in emails
-	$g_from_email			= 'noreply@example.com';
+	# the sender email, part of 'From: ' header in emails
+ 	$g_from_email			= 'noreply@example.com';
+	
+	# the sender name, part of 'From: ' header in emails
+	$g_from_name			= 'Mantis Bug Tracker';
 
 	# the return address for bounced mail
 	$g_return_path_email	= 'admin@example.com';
@@ -260,7 +295,7 @@
 	$g_email_receive_own	= OFF;
 
 	# set to OFF to disable email check
-	$g_validate_email		= ON;
+	$g_validate_email		= ( substr( php_uname(), 0, 7 ) == 'Windows' ) ? OFF : ON;
 	$g_check_mx_record		= OFF;	# Not supported under Windows.
 
 	# if ON, allow the user to omit an email field
@@ -289,7 +324,10 @@
 	$g_phpMailer_method		= 0;
 
 	# This option allows you to use a remote SMTP host.  Must use the phpMailer script
-	# Name of smtp host, needed for phpMailer, taken from php.ini
+	# One or more hosts, separated by a semicolon, can be listed. 
+	# You can also specify a different port for each host by using this 
+	# format: [hostname:port] (e.g. "smtp1.example.com:25;smtp2.example.com").
+	# Hosts will be tried in order.
 	$g_smtp_host			= 'localhost';
 
 	# These options allow you to use SMTP Authentication when you use a remote
@@ -298,6 +336,12 @@
 	$g_smtp_username = '';
 	$g_smtp_password = '';
 
+	# It is recommended to use a cronjob or a scheduler task to send emails.  
+	# The cronjob should typically run every 5 minutes.  If no cronjob is used,
+	# then user will have to wait for emails to be sent after performing an action
+	# which triggers notifications.  This slows user performance.
+	$g_email_send_using_cronjob = OFF;
+
 	# Specify whether e-mails should be sent with the category set or not.  This is tested
 	# with Microsoft Outlook.  More testing for this feature + other formats will be added
 	# in the future.
@@ -314,7 +358,6 @@
 	#############################
 
 	# --- version variables -----------
-	$g_mantis_version		= '1.0.8';
 	$g_show_version			= ON;
 
 	################################
@@ -334,49 +377,40 @@
 		'bulgarian',
 		'catalan',
 		'chinese_simplified',
-		'chinese_simplified_utf8',
 		'chinese_traditional',
-		'chinese_traditional_utf8',
 		'croatian',
 		'czech',
-		'czech_utf8',
 		'danish',
 		'dutch',
 		'english',
 		'estonian',
 		'finnish',
 		'french',
-		'french_utf8',
-		'french_canadian',
 		'german',
+		'german_eintrag',
+		'greek',
+		'hebrew',
 		'hungarian',
 		'icelandic',
 		'italian',
-		'italian_utf8',
-		'japanese_euc',
-		'japanese_sjis',
-		'japanese_utf8',
+		'japanese',
 		'korean',
-		'korean_utf8',
 		'latvian',
 		'lithuanian',
 		'norwegian',
 		'polish',
-		'polish_utf8',
 		'portuguese_brazil',
 		'portuguese_standard',
 		'romanian',
 		'russian',
-		'russian_koi8',
-		'russian_utf8',
 		'serbian',
 		'slovak',
 		'slovene',
-		'slovene_utf8',
 		'spanish',
 		'swedish',
 		'turkish',
-		'ukrainian'
+		'ukrainian',
+		'urdu',
 	);
 
 	# Browser language mapping for 'auto' language selection
@@ -391,14 +425,14 @@
 		'en-us, en-gb, en-au, en' => 'english',
 		'et' => 'estonian',
 		'fi' => 'finnish',
-		'fr-be, fr-ch, fr' => 'french',
-		'fr-ca' => 'french_canadian',
+		'fr-ca, fr-be, fr-ch, fr' => 'french',
 		'de-de, de-at, de-ch, de' => 'german',
+		'he' => 'hebrew',
 		'hu' => 'hungarian',
 		'hr' => 'croatian',
 		'is' => 'icelandic',
 		'it-ch, it' => 'italian',
-		'ja' => 'japanese_utf8',
+		'ja' => 'japanese',
 		'ko' => 'korean',
 		'lt' => 'lithuanian',
 		'lv' => 'latvian',
@@ -445,6 +479,10 @@
 	# --- show extra menu bar with all available projects ---
 	$g_show_project_menu_bar = OFF;
 
+	# --- show extra dropdown for subprojects ---
+	# Shows only top projects in the project dropdown and adds an extra dropdown for subprojects.
+	$g_show_extended_project_browser = OFF;
+
 	# --- show assigned to names ------
 	# This is in the view all pages
 	$g_show_assigned_names	= ON;
@@ -454,22 +492,45 @@
 	# ON:  Shows priority as text in view all bugs page
 	$g_show_priority_text	= OFF;
 
+	# A configuration option that identifies the columns to be shown on the View Issues page.
+	# In Mantis 1.1, this option can be overriden using the Generic Configuration screen.
+	# This configuration can be overriden dynamically by overriding the custom function "get_columns_to_view".
+	# Some of the columns specified here can be removed automatically if they conflict with other configuration.
+	# For example, sponsorship_total will be removed if sponsorships are disabled.
+	# To include custom field 'xyz', include the column name as 'custom_xyz'.
+	#
+	# Standard Column Names (i.e. names to choose from):
+	# selection, edit, id, project_id, reporter_id, handler_id, priority, reproducibility, projection, eta,
+	# resolution, fixed_in_version, view_state, os, os_build, platform, version, date_submitted, attachment,
+	# category, sponsorship_total, severity, status, last_updated, summary, bugnotes_count
+	$g_view_issues_page_columns = array ( 'selection', 'edit', 'priority', 'id', 'sponsorship_total', 'bugnotes_count', 'attachment', 'category', 'severity', 'status', 'last_updated', 'summary' );
+	
+	# A configuration option that identifies the columns to be show on the print issues page.
+	# In Mantis 1.1, this option can be overriden using the Generic Configuration screen.
+	# This configuration can be overriden dynamically by overriding the custom function "get_columns_to_view".
+	$g_print_issues_page_columns = array ( 'selection', 'priority', 'id', 'sponsorship_total', 'bugnotes_count', 'attachment', 'category', 'severity', 'status', 'last_updated', 'summary' );
+
+	# A configuration option that identifies the columns to be include in the CSV export.
+	# In Mantis 1.1, this option can be overriden using the Generic Configuration screen.
+	# This configuration can be overriden dynamically by overriding the custom function "get_columns_to_view".
+	$g_csv_columns = array ( 'id', 'project_id', 'reporter_id', 'handler_id', 'priority', 'severity', 'reproducibility', 'version', 'projection', 'category', 'date_submitted', 'eta', 'os', 'os_build', 'platform', 'view_state', 'last_updated', 'summary', 'status', 'resolution', 'fixed_in_version', 'duplicate_id' );
+
 	# --- show projects when in All Projects mode ---
 	$g_show_bug_project_links	= ON;
 
 	# --- Position of the status colour legend, can be: STATUS_LEGEND_POSITION_*
-	# --- see constant_inc.php. (*: BOTTOM or TOP)
+	# --- see constant_inc.php. (*: TOP , BOTTOM , or BOTH)
 	$g_status_legend_position	= STATUS_LEGEND_POSITION_BOTTOM;
 
-	# --- Position of the filter box, can be: FILTER_POSITION_*
-	# FILTER_POSITION_TOP, FILTER_POSITION_BOTTOM, or 0 for none.
-	$g_filter_position	= FILTER_POSITION_TOP;
-
 	# --- Show a legend with percentage of bug status
 	# --- x% of all bugs are new, y% of all bugs are assigned and so on.
 	# --- If set to ON it will printed below the status colour legend.
 	$g_status_percentage_legend = OFF;
 
+	# --- Position of the filter box, can be: FILTER_POSITION_*
+	# FILTER_POSITION_TOP, FILTER_POSITION_BOTTOM, or 0 for none.
+	$g_filter_position	= FILTER_POSITION_TOP;
+
 	# --- show product versions in create, view and update screens
 	#  ON forces display even if none are defined
 	#  OFF suppresses display
@@ -483,6 +544,20 @@
 	# -- sorting for names in dropdown lists. If turned on, "Jane Doe" will be sorted with the "D"s
 	$g_sort_by_last_name = OFF;
 
+	# Show user avatar
+	# the current implementation is based on http://www.gravatar.com
+	# users will need to register there the same address used in 
+	# this mantis installation to have their avatar shown
+	# Please note: upon registration or avatar change, it takes some time for
+	# the updated gravatar images to show on sites
+	$g_show_avatar = OFF;
+	
+	# Only users above this threshold will have their avatar shown
+	$g_show_avatar_threshold = DEVELOPER;
+
+        # Default avatar for users without a gravatar account
+        $g_default_avatar = "%path%images/no_avatar.png";
+
 	############################
 	# Mantis JPGRAPH Addon
 	############################
@@ -499,6 +574,10 @@
 	$g_use_jpgraph			= OFF;
 	$g_jpgraph_path			= '.' . DIRECTORY_SEPARATOR . 'jpgraph' . DIRECTORY_SEPARATOR;   # dont forget the ending slash!
 
+	# use antialiasing - Enabling anti-aliasing will greatly improve the visual apperance of certain graphs.
+	# Note: Using anti-aliasing makes line drawing roughly 8 time slower than normal lines
+	$g_jpgraph_antialias	= ON;
+
 	# what truetype font will the graphs use. Allowed values are 'arial', 'verdana', 'courier', 'book', 'comic', 'times',
 	#  'georgia', 'trebuche', 'vera', 'veramono', or 'veraserif'. Refer to the jpgraph manual for details.
 	# NOTE: these fonts need to be installed in the TTF_DIR as specified to jpgraph
@@ -511,19 +590,22 @@
 
 	# how many graphs to put in each row in the advanced summary page
 	$g_graph_summary_graphs_per_row = 2;
+	
+	# initial graph type selected on bug_graph_page (see that page for possible values)
+	# 0 asks user to select
+	$g_default_graph_type = 0;
+	
+	# graph colours, once the list is exhausted it will repeat
+	$g_graph_colors = array('coral', 'red', 'blue', 'black', 'green', 'orange', 'pink', 'brown', 'gray',
+	        'blueviolet','chartreuse','magenta','purple3','teal','tan','olivedrab','magenta');
 
 	############################
 	# Mantis Time Settings
 	############################
 
-	# --- time varaibles --------------
-
 	# time for 'permanent' cookie to live in seconds (1 year)
 	$g_cookie_time_length	= 30000000;
 
-	# time to delay between page redirects (in seconds)
-	$g_wait_time			= 2;
-
 	# minutes to wait before document is stale (in minutes)
 	$g_content_expire		= 0;
 
@@ -538,12 +620,12 @@
 	############################
 
 	# --- date format settings --------
-	# date format strings (default is 'US' formatting)
+	# date format strings defaults to ISO 8601 formatting
 	# go to http://www.php.net/manual/en/function.date.php
 	# for detailed instructions on date formatting
-	$g_short_date_format	= 'm-d-y';
-	$g_normal_date_format	= 'm-d-y H:i';
-	$g_complete_date_format	= 'm-d-Y H:i T';
+	$g_short_date_format    = 'Y-m-d';
+	$g_normal_date_format   = 'Y-m-d H:i';
+	$g_complete_date_format = 'Y-m-d H:i T';
 
 	############################
 	# Mantis News Settings
@@ -589,6 +671,12 @@
 
 	# Default bug priority when reporting a new bug
 	$g_default_bug_priority = NORMAL;
+	
+	# Default bug reproducibility when reporting a new bug
+	$g_default_bug_reproducibility = REPRODUCIBILITY_HAVENOTTRIED;
+
+	# Default bug category when reporting a new bug
+	$g_default_bug_category = '';
 
 	# --- viewing defaults ------------
 	# site defaults for viewing preferences
@@ -730,6 +818,15 @@
 	# DISK, DATABASE, or FTP.
 	$g_file_upload_method	= DATABASE;
 
+	# When using FTP or DISK for storing uploaded files, this setting control 
+	# the access permissions they will have on the web server: with the default
+	# value (0400) files will be read-only, and accessible only by the user
+	# running the apache process (probably "apache" in Linux and "Administrator"
+	# in Windows).
+	# For more details on unix style permissions:
+	# http://www.perlfect.com/articles/chmod.shtml
+	$g_attachments_file_permissions = 0400;
+
 	# FTP settings, used if $g_file_upload_method = FTP
 	$g_file_upload_ftp_server	= 'ftp.myserver.com';
 	$g_file_upload_ftp_user		= 'readwriteuser';
@@ -763,9 +860,15 @@
 	# email adresses into clickable links
 	$g_html_make_links		= ON;
 
+	# These are the valid html tags for multi-line fields (e.g. description)
 	# do NOT include href or img tags here
 	# do NOT include tags that have parameters (eg. <font face="arial">)
-	$g_html_valid_tags		= 'p, li, ul, ol, br, pre, i, b, u';
+	$g_html_valid_tags		= 'p, li, ul, ol, br, pre, i, b, u, em';
+
+	# These are the valid html tags for single line fields (e.g. issue summary).
+	# do NOT include href or img tags here
+	# do NOT include tags that have parameters (eg. <font face="arial">)
+	$g_html_valid_tags_single_line		= 'i, b, u, em';
 
 	# maximum length of the description in a dropdown menu (for search)
 	# set to 0 to disable truncations
@@ -799,6 +902,9 @@
 	$g_ldap_bind_dn			= '';
 	$g_ldap_bind_passwd		= '';
 	$g_use_ldap_email		= OFF; # Should we send to the LDAP email address or what MySql tells us
+	
+	# The LDAP Protocol Version, if 0, then the protocol version is not set.
+	$g_ldap_protocol_version = 0;
 
 	############################
 	# Status Settings
@@ -854,6 +960,20 @@
 	# This feature applies to: bmp, png, gif, jpg
 	$g_preview_attachments_inline_max_size = 0;
 
+	# Extenstions for text files that can be expanded inline.
+	$g_preview_text_extensions = array( 'txt', 'diff', 'patch' );
+
+	# Extensions for images that can be expanded inline.
+	$g_preview_image_extensions = array( 'bmp', 'png', 'gif', 'jpg', 'jpeg' );
+
+	# Specifies the maximum width for the auto-preview feature.  If no maximum width should be imposed
+	# then it should be set to 0.
+	$g_preview_max_width = 0;
+
+	# Specifies the maximum height for the auto-preview feature.  If no maximum height should be imposed
+	# then it should be set to 0.
+	$g_preview_max_height = 250;
+
 	# --- Show an attachment indicator on bug list ---
 	# Show a clickable attachment indicator on the bug
 	# list page if the bug has one or more files attached.
@@ -866,6 +986,11 @@
 	# sizes, and timestamps of the attachments.
 	$g_view_attachments_threshold	= VIEWER;
 
+	# list of filetypes to view inline. This is a string of extentions separated by commas
+	# This is used when downloading an attachment.  Rather than downloading, the attachment
+	# is viewed in the browser.
+	$g_inline_file_exts = 'gif,png';
+
 	# access level needed to download bug attachments
 	$g_download_attachments_threshold	= VIEWER;
 
@@ -949,9 +1074,6 @@
 	# Update bugnote threshold (if the bugnote is not your own)
 	$g_update_bugnote_threshold = DEVELOPER;
 
-	# Add profile threshold
-	$g_add_profile_threshold = REPORTER;
-
 	# Threshold needed to view project documentation
 	$g_view_proj_doc_threshold = ANYBODY;
 
@@ -1012,12 +1134,15 @@
 	# $g_bug_readonly_status_threshold.
 	$g_update_readonly_bug_threshold = MANAGER;
 
-	# Threshold needed to be able to create and modify global profiles
-	$g_manage_global_profile_threshold = MANAGER;
-
 	# threshold for viewing changelog
 	$g_view_changelog_threshold = VIEWER;
 
+	# threshold for viewing roadmap
+	$g_roadmap_view_threshold = VIEWER;
+	
+	# threshold for updating roadmap, target_version, etc
+	$g_roadmap_update_threshold = DEVELOPER;
+	
 	# status change thresholds
 	$g_update_bug_status_threshold = DEVELOPER;
 
@@ -1026,6 +1151,10 @@
 
 	# access level needed to set a bug sticky
 	$g_set_bug_sticky_threshold			= MANAGER;
+	
+	# The minimum access level for someone to be a member of the development team
+	# and appear on the project information page.
+	$g_development_team_threshold = DEVELOPER;
 
 	# this array sets the access thresholds needed to enter each status listed.
 	# if a status is not listed, it falls back to $g_update_bug_status_threshold
@@ -1119,10 +1248,6 @@
 	# $g_bug_count_hyperlink_prefix = 'view_all_set.php?type=1';				# permanently change the filter
 	$g_bug_count_hyperlink_prefix = 'view_all_set.php?type=1&amp;temporary=y';	# only change the filter this time
 
-	# --- Queries --------------------
-	# Shows the total number/unique number of queries executed to serve the page.
-	$g_show_queries_count	= ON;
-
 	# The regular expression to use when validating new user login names
 	# The default regular expression allows a-z, A-z, 0-9, as well as space and
 	#  underscore.  If you change this, you may want to update the
@@ -1143,6 +1268,12 @@
 	# threshold for users to view the system configurations
 	$g_view_configuration_threshold = DEVELOPER;
 
+	# threshold for users to set the system configurations generically via Mantis web interface.
+	# WARNING: Users who have access to set configuration via the interface MUST be trusted.  This is due
+	# to the fact that such users can set configurations to PHP code and hence there can be a security
+	# risk if such users are not trusted.
+	$g_set_configuration_threshold = ADMINISTRATOR;
+
 	################################
 	# Mantis Look and Feel Variables
 	################################
@@ -1183,7 +1314,7 @@
 	$g_cookie_path			= '/';
 	$g_cookie_domain		= '';
 	# cookie version for view_all_page
-	$g_cookie_version		= 'v7';
+	$g_cookie_version		= 'v8';
 
 	# --- cookie prefix ---------------
 	# set this to a unique identifier.  No spaces.
@@ -1208,6 +1339,9 @@
 	# Rather than launching a separate page, the filters are updated in-line in the
 	# view_all_bugs_page.
 	$g_dhtml_filters = ON;
+	
+	# The service to use to create a short URL.  The %s will be replaced by the long URL.
+	$g_create_short_url = 'http://tinyurl.com/create.php?url=%s';
 
 	#######################################
 	# Mantis Database Table Variables
@@ -1223,6 +1357,7 @@
 	$g_mantis_bug_monitor_table				= '%db_table_prefix%_bug_monitor%db_table_suffix%';
 	$g_mantis_bug_relationship_table		= '%db_table_prefix%_bug_relationship%db_table_suffix%';
 	$g_mantis_bug_table						= '%db_table_prefix%_bug%db_table_suffix%';
+	$g_mantis_bug_tag_table					= '%db_table_prefix%_bug_tag%db_table_suffix%';
 	$g_mantis_bug_text_table				= '%db_table_prefix%_bug_text%db_table_suffix%';
 	$g_mantis_bugnote_table					= '%db_table_prefix%_bugnote%db_table_suffix%';
 	$g_mantis_bugnote_text_table			= '%db_table_prefix%_bugnote_text%db_table_suffix%';
@@ -1232,6 +1367,7 @@
 	$g_mantis_project_table					= '%db_table_prefix%_project%db_table_suffix%';
 	$g_mantis_project_user_list_table		= '%db_table_prefix%_project_user_list%db_table_suffix%';
 	$g_mantis_project_version_table			= '%db_table_prefix%_project_version%db_table_suffix%';
+	$g_mantis_tag_table						= '%db_table_prefix%_tag%db_table_suffix%';
 	$g_mantis_user_table					= '%db_table_prefix%_user%db_table_suffix%';
 	$g_mantis_user_profile_table			= '%db_table_prefix%_user_profile%db_table_suffix%';
 	$g_mantis_user_pref_table				= '%db_table_prefix%_user_pref%db_table_suffix%';
@@ -1245,7 +1381,8 @@
 	$g_mantis_tokens_table					= '%db_table_prefix%_tokens%db_table_suffix%';
 	$g_mantis_project_hierarchy_table		= '%db_table_prefix%_project_hierarchy%db_table_suffix%';
 	$g_mantis_config_table					= '%db_table_prefix%_config%db_table_suffix%';
-	$g_mantis_database_table					= '%db_table_prefix%_database%db_table_suffix%';
+	$g_mantis_database_table				= '%db_table_prefix%_database%db_table_suffix%';
+	$g_mantis_email_table					= '%db_table_prefix%_email%db_table_suffix%';
 
 	###########################
 	# Mantis Enum Strings
@@ -1366,12 +1503,22 @@
 	# original To, Cc, Bcc included in the message body.
 	$g_debug_email			= OFF;
 
+	# --- Queries --------------------
+	# Shows the total number/unique number of queries executed to serve the page.
+	$g_show_queries_count	= ON;
+
+	# Indicates the access level required for a user to see the queries count / list.
+	# This only has an effect if $g_show_queries_count is ON.  Note that this threshold
+	# is compared against the user's default global access level rather than the
+	# threshold based on the current active project.
+	$g_show_queries_threshold = ADMINISTRATOR;
+
 	# Shows the list of all queries that are executed in chronological order from top
 	# to bottom.  This option is only effective when $g_show_queries_count is ON.
 	# WARNING: Potential security hazard.  Only turn this on when you really
 	# need it (for debugging/profiling)
 	$g_show_queries_list	= OFF;
-
+	
 	# --- detailed error messages -----
 	# Shows a list of variables and their values when an error is triggered
 	# Only applies to error types configured to 'halt' in $g_display_errors, below
@@ -1385,8 +1532,6 @@
 	#  'halt' - stop and display traceback
 	#  'inline' - display 1 line error and continue
 	#  'none' - no error displayed
-	# obsoletes $g_show_notices (E_NOTICE and E_USER_NOTICE) and
-	#   $g_show_warnings (E_WARNING and E_USER_WARNING)
 	# A developer might set this in config_inc.php as:
 	#	$g_display_errors = array(
 	#		E_WARNING => 'halt',
@@ -1404,18 +1549,6 @@
 		E_USER_NOTICE => 'none'
 	);
 
-	# --- notice display ---
-	# Control whether errors of level NOTICE, the lowest level of error,
-	#  are displayed to the user.  Default is OFF, but turning it ON may
-	#  be useful while debugging
-	$g_show_notices			= OFF;
-
-	# --- warning display ---
-	# Control whether errors of level WARNING, the middle level of error,
-	#  are displayed to the user.  Default is ON.  Turning it OFF may
-	#  hide useful information from the user.
-	$g_show_warnings		= ON;
-
 	# --- debug messages ---
 	# If this option is turned OFF (default) page redirects will continue to
 	#  function even if a non-fatal error occurs.  For debugging purposes, you
@@ -1428,13 +1561,14 @@
 	# This controls the logging of information to a separate file for debug or audit
 	# $g_log_level controls what information is logged
 	#  see constant_inc.php for details on the log channels available
-	#  e.g., $g_log_level = LOG_EMAIL | LOG_PROJECT;
+	#  e.g., $g_log_level = LOG_EMAIL | LOG_EMAIL_RECIPIENT | LOG_FILTERING | LOG_AJAX;
 	#
 	# $g_log_destination specifies the file where the data goes
 	#   right now, only "file:<file path>" is supported
-	#   e.g., $g_log_destination = 'file:/tmp/mantis_log';
+	#   e.g. (Linux), $g_log_destination = 'file:/tmp/mantis.log';
+	#   e.g. (Windows), $g_log_destination = 'file:c:/temp/mantis.log';
 	#   see http://www.php.net/error_log for details
-	$g_log_level = 0;
+	$g_log_level = LOG_NONE;
 	$g_log_destination = '';
 
 	##################
@@ -1472,33 +1606,68 @@
 	# Note:
 	# - Extensions must be in lower case
 	# - All icons will be displayed as 16x16 pixels.
-	$g_file_type_icons = array(	'pdf' => 'pdficon.gif',
-					'doc' => 'wordicon.gif',
-					'dot' => 'wordicon.gif',
-					'rtf' => 'wordicon.gif',
-					'xls' => 'excelicon.gif',
-					'xlk' => 'excelicon.gif',
-					'csv' => 'excelicon.gif',
-					'ppt' => 'ppticon.gif',
-					'htm' => 'htmlicon.gif',
-					'html' => 'htmlicon.gif',
-					'css' => 'htmlicon.gif',
-					'gif' => 'gificon.gif',
-					'jpg' => 'jpgicon.gif',
-					'png' => 'pngicon.gif',
-					'zip' => 'zipicon.gif',
-					'tar' => 'zipicon.gif',
-					'gz' => 'zipicon.gif',
-					'tgz' => 'zipicon.gif',
-					'rar' => 'zipicon.gif',
-					'arj' => 'zipicon.gif',
-					'lzh' => 'zipicon.gif',
-					'uc2' => 'zipicon.gif',
-					'ace' => 'zipicon.gif',
-					'txt' => 'texticon.gif',
-					'log' => 'texticon.gif',
-					'eml' => 'mailicon.gif',
-					'?' => 'fileicon.gif' );
+	$g_file_type_icons = array(	
+		'7z'	=> 'zip.gif',
+		'ace'	=> 'zip.gif',
+		'arj'	=> 'zip.gif',
+		'bz2'	=> 'zip.gif',
+		'c'		=> 'cpp.gif',
+		'chm'	=> 'chm.gif',
+		'cpp'	=> 'cpp.gif',
+		'css'	=> 'css.gif',
+		'csv'	=> 'csv.gif',
+		'cxx'	=> 'cpp.gif',
+		'doc'	=> 'doc.gif',
+		'dot'	=> 'doc.gif',
+		'eml'	=> 'eml.gif',
+		'htm'	=> 'html.gif',
+		'html'	=> 'html.gif',
+		'gif'	=> 'gif.gif',
+		'gz'	=> 'zip.gif',
+		'jpe'	=> 'jpg.gif',
+		'jpg'	=> 'jpg.gif',
+		'jpeg'	=> 'jpg.gif',
+		'log'	=> 'text.gif',
+		'lzh'	=> 'zip.gif',
+		'mhtml'	=> 'html.gif',
+		'mid'	=> 'mid.gif',
+		'midi'	=> 'mid.gif',
+		'mov'	=> 'mov.gif',
+		'msg'	=> 'eml.gif',
+		'one'	=> 'one.gif',
+		'pcx'	=> 'pcx.gif',
+		'pdf'	=> 'pdf.gif',
+		'png'	=> 'png.gif',
+		'pot'	=> 'pot.gif',
+		'pps'	=> 'pps.gif',
+		'ppt'	=> 'ppt.gif',
+		'pub'	=> 'pub.gif',
+		'rar'	=> 'zip.gif',
+		'reg'	=> 'reg.gif',
+		'rtf'	=> 'doc.gif',
+		'tar'	=> 'zip.gif',
+		'tgz'	=> 'zip.gif',
+		'txt'	=> 'text.gif',
+		'uc2'	=> 'zip.gif',
+		'vsd'	=> 'vsd.gif',
+		'vsl'	=> 'vsl.gif',
+		'vss'	=> 'vsd.gif',
+		'vst'	=> 'vst.gif',
+		'vsu'	=> 'vsd.gif',
+		'vsw'	=> 'vsd.gif',
+		'vsx'	=> 'vsd.gif',
+		'vtx'	=> 'vst.gif',
+		'wav'	=> 'wav.gif',
+		'wbk'	=> 'wbk.gif',
+		'wma'	=> 'wav.gif',
+		'wmv'	=> 'mov.gif',
+		'wri'	=> 'wri.gif',
+		'xlk'	=> 'xls.gif',
+		'xls'	=> 'xls.gif',
+		'xlt'	=> 'xlt.gif',
+		'xml'	=> 'xml.gif',
+		'zip'	=> 'zip.gif',
+		'?'		=> 'generic.gif' );
 
 	# Icon associative arrays
 	# Status to icon mapping
@@ -1513,8 +1682,8 @@
 	# --------------------
 	# Sort direction to icon mapping
 	$g_sort_icon_arr = array (
-		ASC        => 'up.gif',
-		DESC       => 'down.gif'
+		ASCENDING  => 'up.gif',
+		DESCENDING => 'down.gif'
 	);
 	# --------------------
 	# Read status to icon mapping
@@ -1550,6 +1719,20 @@
 	# Default page after Login or Set Project
 	$g_default_home_page = 'my_view_page.php';
 
+	######################
+	# RSS Feeds
+	######################
+
+	# This flag enables or disables RSS syndication.  In the case where RSS syndication is not used,
+	# it is recommended to set it to OFF.
+	$g_rss_enabled = ON;
+
+	# This seed is used as part of the inputs for calculating the authentication key for the RSS feeds.
+	# If this seed changes, all the existing keys for the RSS feeds will become invalid.  This is 
+	# defaulted to the database user name, but it is recommended to overwrite it with a specific value
+	# on installation.
+	$g_rss_key_seed = '%db_username%';
+
 	######################
 	# Bug Relationships
 	######################
@@ -1622,10 +1805,20 @@
 	$g_forward_year_count 				= 4 ;
 
 	# Custom Group Actions
+	#
+	# This extensibility model allows developing new group custom actions.  This
+	# can be implemented with a totally custom form and action pages or with a 
+	# pre-implemented form and action page and call-outs to some functions.  These
+	# functions are to be implemented in a predefined file whose name is based on
+	# the action name.  For example, for an action to add a note, the action would
+	# be EXT_ADD_NOTE and the file implementing it would be bug_actiongroup_add_note_inc.php.
+	# See implementation of this file for details.
+	#
 	# Sample:
 	#
 	# array(
 	#	array(	'action' => 'my_custom_action',
+	#			'label' => 'my_label',   // string to be passed to lang_get_defaulted()
 	#			'form_page' => 'my_custom_action_page.php',
 	#			'action_page' => 'my_custom_action.php'
 	#   )
@@ -1633,6 +1826,116 @@
 	#			'form_page' => 'my_custom_action2_page.php',
 	#			'action_page' => 'my_custom_action2.php'
 	#   )
+	#	array(	'action' => 'EXT_ADD_NOTE',  // you need to implement bug_actiongroup_<action_without_'EXT_')_inc.php
+	#		'label' => 'actiongroup_menu_add_note' // see strings_english.txt for this label
+	#   )
 	# );
 	$g_custom_group_actions = array();
+
+	#####################
+	# Wiki Integration
+	#####################
+ 
+	# Wiki Integration Enabled?
+	$g_wiki_enable = OFF;
+
+	# Wiki Engine (supported engines: 'dokuwiki', 'mediawiki', 'xwiki')
+	$g_wiki_engine = 'dokuwiki';
+ 
+	# Wiki namespace to be used as root for all pages relating to this mantis installation.
+	$g_wiki_root_namespace = 'mantis';
+ 
+	# URL under which the wiki engine is hosted.  Must be on the same server.
+	$g_wiki_engine_url = $t_protocol . '://' . $t_host . '/%wiki_engine%/';
+	
+	#####################
+	# Recently Visited
+	#####################
+
+	# Whether to show the most recently visited issues or not.  At the moment we always track them even if this flag is off.
+	$g_recently_visited = ON;
+	
+	# The maximum number of issues to keep in the recently visited list.
+	$g_recently_visited_count = 5;
+
+	#####################
+	# Bug Tagging
+	#####################
+
+	# String that will separate tags as entered for input
+	$g_tag_separator = ',';
+
+	# Access level required to view tags attached to a bug
+	$g_tag_view_threshold = VIEWER;
+
+	# Access level required to attach tags to a bug
+	$g_tag_attach_threshold = REPORTER;
+
+	# Access level required to detach tags from a bug
+	$g_tag_detach_threshold = DEVELOPER;
+
+	# Access level required to detach tags attached by the same user
+	$g_tag_detach_own_threshold = REPORTER;
+
+	# Access level required to create new tags
+	$g_tag_create_threshold = REPORTER;
+
+	# Access level required to edit tag names and descriptions
+	$g_tag_edit_threshold = DEVELOPER;
+
+	# Access level required to edit descriptions by the creating user
+	$g_tag_edit_own_threshold = REPORTER;
+
+	#####################
+	# Time tracking
+	#####################
+
+	# Turn on Time Tracking accounting
+	$g_time_tracking_enabled = OFF;
+
+	# A billing sums
+	$g_time_tracking_with_billing = OFF;
+
+	# Stop watch to build time tracking field
+	$g_time_tracking_stopwatch = OFF;
+
+	# access level required to view time tracking information
+	$g_time_tracking_view_threshold = DEVELOPER;
+
+	# access level required to add/edit time tracking information
+	$g_time_tracking_edit_threshold = DEVELOPER;
+
+	# access level required to run reports
+	$g_time_tracking_reporting_threshold = MANAGER;
+
+	#allow time tracking to be recorded without a bugnote
+	$g_time_tracking_without_note = ON;
+
+	#############################
+	# Profile Related Settings
+	#############################
+
+	# Add profile threshold
+	$g_add_profile_threshold = REPORTER;
+
+	# Threshold needed to be able to create and modify global profiles
+	$g_manage_global_profile_threshold = MANAGER;
+
+	# Allows the users to enter free text when reporting/updating issues 
+	# for the profile related fields (i.e. platform, os, os build)
+	$g_allow_freetext_in_profile_fields = ON;
+
+	#############################
+	# Twitter Settings
+	#############################
+
+	# The integration with twitter allows for a Mantis installation to post
+	# updates to a twitter account.  This feature will be disabled if username
+	# is empty or if the curl extension is not enabled.
+
+	# The twitter account user name.
+	$g_twitter_username = '';
+	
+	# The twitter account password.
+	$g_twitter_password = '';
 ?>
