@@ -1,17 +1,32 @@
 <?php
-	# Mantis - a php based bugtracking system
-	# Copyright (C) 2000 - 2002  Kenzaburo Ito - kenito@300baud.org
-	# Copyright (C) 2002 - 2004  Mantis Team   - mantisbt-dev@lists.sourceforge.net
-	# This program is distributed under the terms and conditions of the GPL
-	# See the README and LICENSE files for details
+# Mantis - a php based bugtracking system
+
+# Copyright (C) 2000 - 2002  Kenzaburo Ito - kenito@300baud.org
+# Copyright (C) 2002 - 2007  Mantis Team   - mantisbt-dev@lists.sourceforge.net
+
+# Mantis is free software: you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation, either version 2 of the License, or
+# (at your option) any later version.
+#
+# Mantis is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with Mantis.  If not, see <http://www.gnu.org/licenses/>.
 
 	# --------------------------------------------------------
-	# $Id: authentication_api.php,v 1.45.8.1 2005/09/25 13:27:24 vboctor Exp $
+	# $Id: authentication_api.php,v 1.60.2.3 2007-10-19 06:54:58 vboctor Exp $
 	# --------------------------------------------------------
 
+	require_once( dirname( __FILE__ ) . DIRECTORY_SEPARATOR . 'gpc_api.php' );
+
 	### Authentication API ###
 
 	$g_script_login_cookie = null;
+	$g_cache_anonymous_user_cookie_string = null;
 
 	#===================================
 	# Boolean queries and ensures
@@ -24,10 +39,6 @@
 	#  If parameter is given it is used as a URL to redirect to following
 	#   successful login.  If none is given, the URL of the current page is used
 	function auth_ensure_user_authenticated( $p_return_page = '' ) {
-		if ( !php_version_at_least( '4.1.0' ) ) {
-			global $_SERVER;
-		}
-
 		# if logged in
 		if ( auth_is_user_authenticated() ) {
 			# check for access enabled
@@ -51,7 +62,7 @@
 	# Return true if there is a currently logged in and authenticated user,
 	#  false otherwise
 	function auth_is_user_authenticated() {
-		return ( !is_blank( auth_get_current_user_cookie() ) );
+		return ( auth_is_cookie_valid( auth_get_current_user_cookie() ) );
 	}
 
 
@@ -128,6 +139,7 @@
 
 		# set the cookies
 		auth_set_cookies( $t_user_id, $p_perm_login );
+		auth_set_tokens( $t_user_id );
 
 		return true;
 	}
@@ -155,8 +167,10 @@
 
 		# ok, we're good to login now
 
+		# With cases like RSS feeds and MantisConnect there is a login per operation, hence, there is no
+		# real significance of incrementing login count.
 		# increment login count
-		user_increment_login_count( $t_user_id );
+		# user_increment_login_count( $t_user_id );
 
 		# set the cookies
 		$g_script_login_cookie = $t_user['cookie_string'];
@@ -171,8 +185,15 @@
 	# Logout the current user and remove any remaining cookies from their browser
 	# Returns true on success, false otherwise
 	function auth_logout() {
-		auth_clear_cookies();
-		helper_clear_pref_cookies();
+        global $g_cache_current_user_id;
+        
+        # clear cached userid
+        $g_cache_current_user_id = null;
+        
+        # clear cookies, if they were set  
+        if (auth_clear_cookies()) {
+            helper_clear_pref_cookies();
+        }
 		return true;
 	}
 
@@ -196,6 +217,13 @@
 
 			# pass the stored password in as the salt
 			if ( auth_process_plain_password( $p_test_password, $t_password, $t_login_method ) == $t_password ) {
+				# Do not support migration to PLAIN, since this would be a crazy thing to do.
+				# Also if we do, then a user will be able to login by providing the MD5 value
+				# that is copied from the database.  See #8467 for more details.
+				if ( $t_configured_login_method != PLAIN && $t_login_method == PLAIN ) {
+					continue;
+				}
+
 				# Check for migration to another login method and test whether the password was encrypted
 				# with our previously insecure implemention of the CRYPT method
 				if ( ( $t_login_method != $t_configured_login_method ) ||
@@ -288,16 +316,23 @@
 	}
 
 	# --------------------
-	# Clear login cookies
+	# Clear login cookies, return true if they were cleared
 	function auth_clear_cookies() {
 		global $g_script_login_cookie;
 
-		$g_script_login_cookie = null;
+        $t_cookies_cleared = false;
+        
+        # clear cookie, if not logged in from script
+        if ($g_script_login_cookie == null) {
+		    $t_cookie_name =  config_get( 'string_cookie' );
+		    $t_cookie_path = config_get( 'cookie_path' );
 
-		$t_cookie_name =  config_get( 'string_cookie' );
-		$t_cookie_path = config_get( 'cookie_path' );
-
-		gpc_clear_cookie( $t_cookie_name, $t_cookie_path );
+		    gpc_clear_cookie( $t_cookie_name, $t_cookie_path );
+            $t_cookies_cleared = true;
+        } else {
+            $g_script_login_cookie = null;
+        }
+        return $t_cookies_cleared;
 	}
 
 	# --------------------
@@ -348,30 +383,41 @@
 	#  the browser. This shouldn't normally matter, except that the password verification uses
 	#  this routine to bypass the normal authentication, and can get confused when a normal user
 	#  logs in, then runs the verify script. the act of fetching config variables may get the wrong
-	#  userid.	# if no user is logged in and anonymous login is enabled, returns cookie for anonymous user
+	#  userid.
+	# if no user is logged in and anonymous login is enabled, returns cookie for anonymous user
 	# otherwise returns '' (an empty string)
 	function auth_get_current_user_cookie() {
-		global $g_script_login_cookie;
-
+		global $g_script_login_cookie, $g_cache_anonymous_user_cookie_string;
+ 
 		# if logging in via a script, return that cookie
 		if ( $g_script_login_cookie !== null ) {
 			return $g_script_login_cookie;
 		}
-
-		# fetch user cookie
+			
+		# fetch user cookie 
 		$t_cookie_name = config_get( 'string_cookie' );
 		$t_cookie = gpc_get_cookie( $t_cookie_name, '' );
 
 		# if cookie not found, and anonymous login enabled, use cookie of anonymous account.
 		if ( is_blank( $t_cookie ) ) {
 			if ( ON == config_get( 'allow_anonymous_login' ) ) {
-				$query = sprintf('SELECT id, cookie_string FROM %s WHERE username = "%s"',
-						config_get( 'mantis_user_table' ), config_get( 'anonymous_account' ) );
-				$result = db_query( $query );
+				if ( $g_cache_anonymous_user_cookie_string === null ) {
+                    if ( function_exists( 'db_is_connected' ) && db_is_connected() ) { 
+                        # get anonymous information if database is available
+                        $query = sprintf('SELECT id, cookie_string FROM %s WHERE username = \'%s\'',
+								config_get( 'mantis_user_table' ), config_get( 'anonymous_account' ) );
+                        $result = db_query( $query );
+                        
+                        if ( 1 == db_num_rows( $result ) ) {
+                            $row = db_fetch_array( $result );
+                            $t_cookie = $row['cookie_string'];
 
-				if ( 1 == db_num_rows( $result ) ) {
-					$row		= db_fetch_array( $result );
-					$t_cookie	= $row['cookie_string'];
+                            $g_cache_anonymous_user_cookie_string = $t_cookie;
+                            $g_cache_current_user_id = $row['id'];
+                        }
+                    }
+                } else {
+					$t_cookie = $g_cache_anonymous_user_cookie_string;
 				}
 			}
 		}
@@ -379,11 +425,163 @@
 		return $t_cookie;
 	}
 
+	#===================================
+	# Re-Authentication Tokens
+	#===================================
+
+	/**
+	 * Set authentication tokens for secure session.
+	 * @param integer User ID
+	 */
+	function auth_set_tokens( $p_user_id ) {
+		$t_auth_token = token_get( TOKEN_AUTHENTICATED, $p_user_id );
+		if ( null == $t_auth_token ) {
+			token_set( TOKEN_AUTHENTICATED, true, TOKEN_EXPIRY_AUTHENTICATED, $p_user_id );
+		} else {
+			token_touch( $t_auth_token['id'], TOKEN_EXPIRY_AUTHENTICATED );
+		}
+	}
+
+	/**
+	 * Check for authentication tokens, and display re-authentication page if needed.
+	 * Currently, if using BASIC or HTTP authentication methods, or if logged in anonymously, 
+	 * this function will always "authenticate" the user (do nothing).
+	 */
+	function auth_reauthenticate() {
+		if ( BASIC_AUTH == config_get( 'login_method' ) ||
+				HTTP_AUTH == config_get( 'login_method' ) ) {
+			return true;
+		}
+
+		$t_auth_token = token_get( TOKEN_AUTHENTICATED );
+		if ( null != $t_auth_token ) {
+			token_touch( $t_auth_token['id'], TOKEN_EXPIRY_AUTHENTICATED );
+			return true;
+		} else {
+			$t_anon_account = config_get( 'anonymous_account' );
+			$t_anon_allowed = config_get( 'allow_anonymous_login' );
+
+			$t_user_id = auth_get_current_user_id();
+			$t_username = user_get_field( $t_user_id, 'username' );
+
+			# check for anonymous login
+			if ( ON == $t_anon_allowed && $t_anon_account == $t_username ) {
+				return true;
+			}
+	
+			return auth_reauthenticate_page( $t_user_id, $t_username );
+		}
+	}
+
+	/**
+	 * Generate the intermediate authentication page.
+	 * @param integer User ID
+	 * @param string Username
+	 */
+	function auth_reauthenticate_page( $p_user_id, $p_username ) {
+		$t_error = false;
+
+		if ( true == gpc_get_bool( '_authenticate' ) ) {
+			$f_password     = gpc_get_string( 'password', '' );
+					    
+			if ( auth_attempt_login( $p_username, $f_password ) ) {
+				auth_set_tokens( $p_user_id );
+				return true;
+			} else {
+				$t_error = true;
+			}
+		}
+
+		html_page_top1();
+		html_page_top2();
+
+?>
+<div align="center">
+<p>
+<?php 
+		echo lang_get( 'reauthenticate_message' ); 
+		if ( $t_error != false ) {
+			echo '<br/><font color="red">',lang_get( 'login_error' ),'</font>';
+		}
+?>
+</p>
+<form method="post" action="<?php echo $_SERVER['PHP_SELF']; ?>">
+
+<?php
+		print_hidden_inputs( gpc_strip_slashes( $_POST ) );
+		print_hidden_inputs( gpc_strip_slashes( $_GET ) );
+?>
+
+<input type="hidden" name="_authenticate" value="1" />
+
+<table class="width50 center">
+<tr>
+	<td class="form-title"><?php echo lang_get( 'reauthenticate_title' ); ?></td>
+</tr>
+
+<tr class="row-1">
+	<td class="category"><?php echo lang_get( 'username' ); ?></td>
+	<td><input type="text" disabled="disabled" size="32" maxlength="32" value="<?php echo $p_username; ?>" /></td>
+</tr>
+
+<tr class="row-2">
+	<td class="category"><?php echo lang_get( 'password' ); ?></td>
+	<td><input type="password" name="password" size="16" maxlength="32" /></td>
+</tr>
+
+<tr>
+	<td class="center" colspan="2"><input type="submit" class="button" value="<?php echo lang_get( 'login_button' ); ?>" /></td>
+</tr>
+</table>
+
+</form>
+</div>
+
+		<?php
+		html_page_bottom1();
+
+		exit;
+	}
 
 	#===================================
 	# Data Access
 	#===================================
 
+	#########################################
+	# is cookie valid?
+
+	function auth_is_cookie_valid( $p_cookie_string ) {
+		global $g_cache_current_user_id;
+		
+		# fail if DB isn't accessible
+		if ( !db_is_connected() ) {
+			return false;
+		}
+
+		# fail if cookie is blank
+		if ( '' === $p_cookie_string ) {
+			return false;
+		}
+
+		# succeeed if user has already been authenticated
+		if ( null !== $g_cache_current_user_id ) {
+			return true;
+		}
+		
+		# look up cookie in the database to see if it is valid
+		$t_user_table = config_get( 'mantis_user_table' );
+
+		$c_cookie_string = db_prepare_string( $p_cookie_string );
+
+		$query = "SELECT id
+				  FROM $t_user_table
+				  WHERE cookie_string='$c_cookie_string'";
+		$result = db_query( $query );
+
+		# return true if a matching cookie was found
+ 		return ( 1 == db_num_rows( $result ) );
+	}
+
 	#########################################
 	# SECURITY NOTE: cache globals are initialized here to prevent them
 	#   being spoofed if register_globals is turned on
@@ -415,7 +613,7 @@
 		# and give them an Access Denied message.
 		if ( db_num_rows( $result ) < 1 ) {
 			auth_clear_cookies();
-			access_denied();
+		    access_denied(); # never returns
 			return false;
 		}
 
@@ -425,7 +623,6 @@
 		return $t_user_id;
 	}
 
-
 	#===================================
 	# HTTP Auth
 	#===================================
