@@ -1,12 +1,24 @@
 <?php
-	# Mantis - a php based bugtracking system
-	# Copyright (C) 2000 - 2002  Kenzaburo Ito - kenito@300baud.org
-	# Copyright (C) 2002 - 2004  Mantis Team   - mantisbt-dev@lists.sourceforge.net
-	# This program is distributed under the terms and conditions of the GPL
-	# See the README and LICENSE files for details
+# Mantis - a php based bugtracking system
+
+# Copyright (C) 2000 - 2002  Kenzaburo Ito - kenito@300baud.org
+# Copyright (C) 2002 - 2007  Mantis Team   - mantisbt-dev@lists.sourceforge.net
+
+# Mantis is free software: you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation, either version 2 of the License, or
+# (at your option) any later version.
+#
+# Mantis is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with Mantis.  If not, see <http://www.gnu.org/licenses/>.
 
 	# --------------------------------------------------------
-	# $Id: bug_api.php,v 1.95.8.1.6.1 2006/04/18 00:53:04 thraxisp Exp $
+	# $Id: bug_api.php,v 1.111.2.1 2007-10-13 22:35:13 giallu Exp $
 	# --------------------------------------------------------
 
 	$t_core_dir = dirname( __FILE__ ).DIRECTORY_SEPARATOR;
@@ -17,6 +29,8 @@
 	require_once( $t_core_dir . 'file_api.php' );
 	require_once( $t_core_dir . 'string_api.php' );
 	require_once( $t_core_dir . 'sponsorship_api.php' );
+	require_once( $t_core_dir . 'twitter_api.php' );
+	require_once( $t_core_dir . 'tag_api.php' );
 
 	# MASC RELATIONSHIP
 	require_once( $t_core_dir.'relationship_api.php' );
@@ -47,6 +61,7 @@
 		var $platform = '';
 		var $version = '';
 		var $fixed_in_version = '';
+		var $target_version = '';
 		var $build = '';
 		var $view_state = VS_PUBLIC;
 		var $summary = '';
@@ -61,6 +76,9 @@
 		var $description = '';
 		var $steps_to_reproduce = '';
 		var $additional_information = '';
+		
+		#internal helper objects
+		var $_stats = null;
 	}
 
 	#===================================
@@ -74,6 +92,25 @@
 	$g_cache_bug = array();
 	$g_cache_bug_text = array();
 
+	# --------------------
+	# Cache an object as a bug.
+	function bug_cache_database_result( $p_bug_datebase_result, $p_stats = null ) {
+		global $g_cache_bug;
+		
+		if ( isset( $g_cache_bug[ $p_bug_datebase_result['id'] ] ) ) {
+			return $g_cache_bug[ $p_bug_datebase_result['id'] ];
+		}	
+		
+		if( !is_int( $p_bug_datebase_result['date_submitted'] ) )
+			$p_bug_datebase_result['date_submitted']	= db_unixtimestamp( $p_bug_datebase_result['date_submitted']['date_submitted'] );
+		if( !is_int( $p_bug_datebase_result['last_updated'] ) )
+			$p_bug_datebase_result['last_updated']	= db_unixtimestamp( $p_bug_datebase_result['last_updated'] );
+		$g_cache_bug[ $p_bug_datebase_result['id'] ] = $p_bug_datebase_result;
+		if( !is_null( $p_stats ) ) {
+			$g_cache_bug[ $p_bug_datebase_result['id'] ]['_stats'] = $p_stats;
+		}
+	}
+
 	# --------------------
 	# Cache a bug row if necessary and return the cached copy
 	#  If the second parameter is true (default), trigger an error
@@ -82,13 +119,13 @@
 	function bug_cache_row( $p_bug_id, $p_trigger_errors=true ) {
 		global $g_cache_bug;
 
+		if ( isset( $g_cache_bug[$p_bug_id] ) ) {
+			return $g_cache_bug[$p_bug_id];
+		}
+
 		$c_bug_id		= db_prepare_int( $p_bug_id );
 		$t_bug_table	= config_get( 'mantis_bug_table' );
 
-		if ( isset( $g_cache_bug[$c_bug_id] ) ) {
-			return $g_cache_bug[$c_bug_id];
-		}
-
 		$query = "SELECT *
 				  FROM $t_bug_table
 				  WHERE id='$c_bug_id'";
@@ -262,6 +299,13 @@
 		return true;
 	}
 
+	# --------------------
+	# Check if the bug is resolved
+	function bug_is_resolved( $p_bug_id ) {
+		$t_status = bug_get_field( $p_bug_id, 'status' );
+		return ( $t_status >= config_get( 'bug_resolved_status_threshold' ) );
+	}
+
 	# --------------------
 	# Validate workflow state to see if bug can be moved to requested state
 	function bug_check_workflow( $p_bug_status, $p_wanted_status ) {
@@ -334,6 +378,19 @@
 			trigger_error( ERROR_EMPTY_FIELD, ERROR );
 		}
 
+		# If category is not specified and not defaulted + project has categories defined, then error.
+		if ( is_blank( $c_category ) && ( category_get_count( $c_project_id ) > 0 ) ) {
+			error_parameters( lang_get( 'category' ) );
+			trigger_error( ERROR_EMPTY_FIELD, ERROR );
+		}
+
+		# Only set target_version if user has access to do so
+		if ( access_has_project_level( config_get( 'roadmap_update_threshold' ) ) ) {
+			$c_target_version	= db_prepare_string( $p_bug_data->target_version );
+		} else { 
+			$c_target_version	= '';
+		}
+
 		$t_bug_table				= config_get( 'mantis_bug_table' );
 		$t_bug_text_table			= config_get( 'mantis_bug_text_table' );
 		$t_project_category_table	= config_get( 'mantis_project_category_table' );
@@ -389,7 +446,9 @@
 				      os, os_build,
 				      platform, version,
 				      build,
-				      profile_id, summary, view_state, sponsorship_total, sticky, fixed_in_version )
+				      profile_id, summary, view_state, sponsorship_total, sticky, fixed_in_version,
+				      target_version 
+				    )
 				  VALUES
 				    ( '$c_project_id',
 				      '$c_reporter_id', '$c_handler_id',
@@ -402,7 +461,9 @@
 				      '$c_os', '$c_os_build',
 				      '$c_platform', '$c_version',
 				      '$c_build',
-				      '$c_profile_id', '$c_summary', '$c_view_state', '$c_sponsorship_total', '$c_sticky', '' )";
+				      '$c_profile_id', '$c_summary', '$c_view_state', '$c_sponsorship_total', '$c_sticky', '',
+				      '$c_target_version'
+				    )";
 		db_query( $query );
 
 		$t_bug_id = db_insert_id($t_bug_table);
@@ -463,6 +524,7 @@
 		bug_set_field( $t_new_bug_id, 'last_updated', $t_mantis_db->DBTimeStamp( $t_bug_data->last_updated ), false );
 		bug_set_field( $t_new_bug_id, 'eta', $t_bug_data->eta );
 		bug_set_field( $t_new_bug_id, 'fixed_in_version', $t_bug_data->fixed_in_version );
+		bug_set_field( $t_new_bug_id, 'target_version', $t_bug_data->target_version );
 		bug_set_field( $t_new_bug_id, 'sponsorship_total', 0 );
 		bug_set_field( $t_new_bug_id, 'sticky', 0 );
 
@@ -555,7 +617,7 @@
 				$t_new_file_name = file_get_display_name( $t_bug_file['filename'] );
 				if ( ( config_get( 'file_upload_method' ) == DISK ) ) {
 					copy( $t_bug_file['diskfile'], $t_new_diskfile_name );
-					chmod( $t_new_diskfile_name, 0400 ); # make file read only in the file system
+					chmod( $t_new_diskfile_name, config_get( 'attachments_file_permissions' ) );
 				}
 
 				$query = "INSERT INTO $t_mantis_bug_file_table
@@ -627,11 +689,19 @@
 		$t_bug_table		= config_get( 'mantis_bug_table' );
 		$t_bug_text_table	= config_get( 'mantis_bug_text_table' );
 
+		# call pre-deletion custom function
+		helper_call_custom_function( 'issue_delete_validate', array( $p_bug_id ) );
+
 		# log deletion of bug
 		history_log_event_special( $p_bug_id, BUG_DELETED, bug_format_id( $p_bug_id ) );
 
 		email_bug_deleted( $p_bug_id );
 
+		# call post-deletion custom function.  We call this here to allow the custom function to access the details of the bug before 
+		# they are deleted from the database given it's id.  The other option would be to move this to the end of the function and
+		# provide it with bug data rather than an id, but this will break backward compatibility.
+		helper_call_custom_function( 'issue_delete_notify', array( $p_bug_id ) );
+
 		# Unmonitor bug for all users
 		bug_unmonitor( $p_bug_id, null );
 
@@ -652,6 +722,9 @@
 		# Delete files
 		file_delete_attachments( $p_bug_id );
 
+		# Detach tags
+		tag_bug_detach_all( $p_bug_id, false );
+		
 		# Delete the bug history
 		history_delete( $p_bug_id );
 
@@ -753,7 +826,16 @@
 					platform='$c_bug_data->platform',
 					version='$c_bug_data->version',
 					build='$c_bug_data->build',
-					fixed_in_version='$c_bug_data->fixed_in_version',
+					fixed_in_version='$c_bug_data->fixed_in_version',";
+
+		$t_roadmap_updated = false;
+		if ( access_has_project_level( config_get( 'roadmap_update_threshold' ) ) ) {
+			$query .= "
+					target_version='$c_bug_data->target_version',";
+			$t_roadmap_updated = true;
+		}
+
+		$query .= "
 					view_state='$c_bug_data->view_state',
 					summary='$c_bug_data->summary',
 					sponsorship_total='$c_bug_data->sponsorship_total',
@@ -782,6 +864,9 @@
 		history_log_event_direct( $p_bug_id, 'version', $t_old_data->version, $p_bug_data->version );
 		history_log_event_direct( $p_bug_id, 'build', $t_old_data->build, $p_bug_data->build );
 		history_log_event_direct( $p_bug_id, 'fixed_in_version', $t_old_data->fixed_in_version, $p_bug_data->fixed_in_version );
+		if ( $t_roadmap_updated ) {
+			history_log_event_direct( $p_bug_id, 'target_version', $t_old_data->target_version, $p_bug_data->target_version );
+		}
 		history_log_event_direct( $p_bug_id, 'view_state', $t_old_data->view_state, $p_bug_data->view_state );
 		history_log_event_direct( $p_bug_id, 'summary', $t_old_data->summary, $p_bug_data->summary );
 		history_log_event_direct( $p_bug_id, 'sponsorship_total', $t_old_data->sponsorship_total, $p_bug_data->sponsorship_total );
@@ -978,7 +1063,19 @@
 	#  associated with the bug was modified and the total bugnote
 	#  count in one db query
 	function bug_get_bugnote_stats( $p_bug_id ) {
+		global $g_cache_bug;
 		$c_bug_id			= db_prepare_int( $p_bug_id );
+
+		if( !is_null( $g_cache_bug[ $c_bug_id ]['_stats'] ) ) {
+			if( $g_cache_bug[ $c_bug_id ]['_stats'] === false ) { 
+				return false;			
+			} else {
+				$t_stats['last_modified'] = db_unixtimestamp( $g_cache_bug[ $c_bug_id ]['_stats']['last_modified'] );
+				$t_stats['count'] = $g_cache_bug[ $c_bug_id ]['_stats']['count'];
+			}
+			return $t_stats;
+		}
+
 		$t_bugnote_table	= config_get( 'mantis_bugnote_table' );
 
 		$query = "SELECT last_modified
@@ -1102,10 +1199,8 @@
 			history_log_event_direct( $c_bug_id, 'status', $h_status, $t_ass_val );
 			history_log_event_direct( $c_bug_id, 'handler_id', $h_handler_id, $p_user_id );
 
-			# Add bugnote if supplied
-			if ( !is_blank( $p_bugnote_text ) ) {
-				bugnote_add( $p_bug_id, $p_bugnote_text, $p_bugnote_private );
-			}
+			# Add bugnote if supplied ignore false return
+			bugnote_add( $p_bug_id, $p_bugnote_text, 0, $p_bugnote_private, 0, '', NULL, FALSE );
 
 			# updated the last_updated date
 			bug_update_date( $p_bug_id );
@@ -1121,15 +1216,15 @@
 
 	# --------------------
 	# close the given bug
-	function bug_close( $p_bug_id, $p_bugnote_text = '', $p_bugnote_private = false ) {
+	function bug_close( $p_bug_id, $p_bugnote_text = '', $p_bugnote_private = false, $p_time_tracking = '0:00' ) {
 		$p_bugnote_text = trim( $p_bugnote_text );
 
-		bug_set_field( $p_bug_id, 'status', CLOSED );
+		# Add bugnote if supplied ignore a false return
+		# Moved bugnote_add before bug_set_field calls in case time_tracking_no_note is off.
+		# Error condition stopped execution but status had already been changed
+		bugnote_add( $p_bug_id, $p_bugnote_text, $p_time_tracking, $p_bugnote_private, 0, '', NULL, FALSE );
 
-		# Add bugnote if supplied
-		if ( !is_blank( $p_bugnote_text ) ) {
-			bugnote_add( $p_bug_id, $p_bugnote_text, $p_bugnote_private );
-		}
+		bug_set_field( $p_bug_id, 'status', CLOSED );
 
 		email_close( $p_bug_id );
 
@@ -1144,11 +1239,16 @@
 
 	# --------------------
 	# resolve the given bug
-	function bug_resolve( $p_bug_id, $p_resolution, $p_fixed_in_version = '', $p_bugnote_text = '', $p_duplicate_id = null, $p_handler_id = null, $p_bugnote_private = false ) {
+	function bug_resolve( $p_bug_id, $p_resolution, $p_fixed_in_version = '', $p_bugnote_text = '', $p_duplicate_id = null, $p_handler_id = null, $p_bugnote_private = false, $p_time_tracking = '0:00' ) {
 		$p_bugnote_text = trim( $p_bugnote_text );
 
-		if( !is_blank( $p_duplicate_id ) && ( $p_duplicate_id != 0 ) ) {
-			# MASC RELATIONSHIP
+		# Add bugnote if supplied
+		# Moved bugnote_add before bug_set_field calls in case time_tracking_no_note is off.
+		# Error condition stopped execution but status had already been changed
+		bugnote_add( $p_bug_id, $p_bugnote_text, $p_time_tracking, $p_bugnote_private, 0, '', NULL, FALSE );
+
+		$t_duplicate = !is_blank( $p_duplicate_id ) && ( $p_duplicate_id != 0 );
+		if ( $t_duplicate ) {
 			if ( $p_bug_id == $p_duplicate_id ) {
 			    trigger_error( ERROR_BUG_DUPLICATE_SELF, ERROR );  # never returns
 			}
@@ -1156,7 +1256,7 @@
 			# the related bug exists...
 			bug_ensure_exists( $p_duplicate_id );
 
-			if( ON == config_get( 'enable_relationship' ) ) {
+			if ( ON == config_get( 'enable_relationship' ) ) {
 				# check if there is other relationship between the bugs...
 				$t_id_relationship = relationship_same_type_exists( $p_bug_id, $p_duplicate_id, BUG_DUPLICATE );
 
@@ -1185,12 +1285,13 @@
 			}
 
 			bug_set_field( $p_bug_id, 'duplicate_id', (int)$p_duplicate_id );
-			# MASC RELATIONSHIP
 		}
+		
+		$c_resolution = db_prepare_int( $p_resolution );
 
 		bug_set_field( $p_bug_id, 'status', config_get( 'bug_resolved_status_threshold' ) );
 		bug_set_field( $p_bug_id, 'fixed_in_version', $p_fixed_in_version );
-		bug_set_field( $p_bug_id, 'resolution', (int)$p_resolution );
+		bug_set_field( $p_bug_id, 'resolution', $c_resolution );
 
 		# only set handler if specified explicitly or if bug was not assigned to a handler
 		if ( null == $p_handler_id ) {
@@ -1202,13 +1303,12 @@
 			bug_set_field( $p_bug_id, 'handler_id', $p_handler_id );
 		}
 
-		# Add bugnote if supplied
-		if ( !is_blank( $p_bugnote_text ) ) {
-			bugnote_add( $p_bug_id, $p_bugnote_text, $p_bugnote_private );
-		}
-
 		email_resolved( $p_bug_id );
 
+		if ( $c_resolution == FIXED ) {
+			twitter_issue_resolved( $p_bug_id );
+		}
+
 		# MASC RELATIONSHIP
 		if ( ON == config_get( 'enable_relationship' ) ) {
 			email_relationship_child_resolved( $p_bug_id );
@@ -1220,17 +1320,17 @@
 
 	# --------------------
 	# reopen the given bug
-	function bug_reopen( $p_bug_id, $p_bugnote_text='', $p_bugnote_private = false ) {
+	function bug_reopen( $p_bug_id, $p_bugnote_text='', $p_time_tracking = '0:00', $p_bugnote_private = false ) {
 		$p_bugnote_text = trim( $p_bugnote_text );
 
+		# Add bugnote if supplied
+		# Moved bugnote_add before bug_set_field calls in case time_tracking_no_note is off.
+		# Error condition stopped execution but status had already been changed
+		bugnote_add( $p_bug_id, $p_bugnote_text, $p_time_tracking, $p_bugnote_private, 0, '', NULL, FALSE );
+
 		bug_set_field( $p_bug_id, 'status', config_get( 'bug_reopen_status' ) );
 		bug_set_field( $p_bug_id, 'resolution', config_get( 'bug_reopen_resolution' ) );
 
-		# Add bugnote if supplied
-		if ( !is_blank( $p_bugnote_text ) ) {
-			bugnote_add( $p_bug_id, $p_bugnote_text, $p_bugnote_private );
-		}
-
 		email_reopen( $p_bug_id );
 
 		return true;
@@ -1341,6 +1441,7 @@
 		$t_bug_data->version			= db_prepare_string( $p_bug_data->version );
 		$t_bug_data->build				= db_prepare_string( $p_bug_data->build );
 		$t_bug_data->fixed_in_version	= db_prepare_string( $p_bug_data->fixed_in_version );
+		$t_bug_data->target_version		= db_prepare_string( $p_bug_data->target_version );
 		$t_bug_data->view_state			= db_prepare_int( $p_bug_data->view_state );
 		$t_bug_data->summary			= db_prepare_string( $p_bug_data->summary );
 		$t_bug_data->sponsorship_total	= db_prepare_int( $p_bug_data->sponsorship_total );
@@ -1365,6 +1466,7 @@
 		$p_bug_data->platform			= string_attribute( $p_bug_data->platform );
 		$p_bug_data->version			= string_attribute( $p_bug_data->version );
 		$p_bug_data->build				= string_attribute( $p_bug_data->build );
+		$p_bug_data->target_version     = string_attribute( $p_bug_data->target_version );
 		$p_bug_data->fixed_in_version	= string_attribute( $p_bug_data->fixed_in_version );
 		$p_bug_data->summary			= string_attribute( $p_bug_data->summary );
 		$p_bug_data->sponsorship_total	= string_attribute( $p_bug_data->sponsorship_total );
@@ -1381,18 +1483,19 @@
 	# Return a copy of the bug structure with all the instvars prepared for editing
 	#  in an HTML form
 	function bug_prepare_display( $p_bug_data ) {
-		$p_bug_data->category			= string_display( $p_bug_data->category );
-		$p_bug_data->date_submitted		= string_display( $p_bug_data->date_submitted );
-		$p_bug_data->last_updated		= string_display( $p_bug_data->last_updated );
-		$p_bug_data->os					= string_display( $p_bug_data->os );
-		$p_bug_data->os_build			= string_display( $p_bug_data->os_build );
-		$p_bug_data->platform			= string_display( $p_bug_data->platform );
-		$p_bug_data->version			= string_display( $p_bug_data->version );
-		$p_bug_data->build				= string_display( $p_bug_data->build );
-		$p_bug_data->fixed_in_version	= string_display( $p_bug_data->fixed_in_version );
-		$p_bug_data->summary			= string_display_links( $p_bug_data->summary );
-		$p_bug_data->sponsorship_total	= string_display( $p_bug_data->sponsorship_total );
-		$p_bug_data->sticky				= string_display( $p_bug_data->sticky );
+		$p_bug_data->category			= string_display_line( $p_bug_data->category );
+		$p_bug_data->date_submitted		= string_display_line( $p_bug_data->date_submitted );
+		$p_bug_data->last_updated		= string_display_line( $p_bug_data->last_updated );
+		$p_bug_data->os					= string_display_line( $p_bug_data->os );
+		$p_bug_data->os_build			= string_display_line( $p_bug_data->os_build );
+		$p_bug_data->platform			= string_display_line( $p_bug_data->platform );
+		$p_bug_data->version			= string_display_line( $p_bug_data->version );
+		$p_bug_data->build				= string_display_line( $p_bug_data->build );
+		$p_bug_data->target_version		= string_display_line( $p_bug_data->target_version );
+		$p_bug_data->fixed_in_version	= string_display_line( $p_bug_data->fixed_in_version );
+		$p_bug_data->summary			= string_display_line_links( $p_bug_data->summary );
+		$p_bug_data->sponsorship_total	= string_display_line( $p_bug_data->sponsorship_total );
+		$p_bug_data->sticky				= string_display_line( $p_bug_data->sticky );
 
 		$p_bug_data->description		= string_display_links( $p_bug_data->description );
 		$p_bug_data->steps_to_reproduce	= string_display_links( $p_bug_data->steps_to_reproduce );
