@@ -1,12 +1,24 @@
 <?php
-	# Mantis - a php based bugtracking system
-	# Copyright (C) 2000 - 2002  Kenzaburo Ito - kenito@300baud.org
-	# Copyright (C) 2002 - 2006  Mantis Team   - mantisbt-dev@lists.sourceforge.net
-	# This program is distributed under the terms and conditions of the GPL
-	# See the README and LICENSE files for details
+# Mantis - a php based bugtracking system
+
+# Copyright (C) 2000 - 2002  Kenzaburo Ito - kenito@300baud.org
+# Copyright (C) 2002 - 2007  Mantis Team   - mantisbt-dev@lists.sourceforge.net
+
+# Mantis is free software: you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation, either version 2 of the License, or
+# (at your option) any later version.
+#
+# Mantis is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with Mantis.  If not, see <http://www.gnu.org/licenses/>.
 
 	# --------------------------------------------------------
-	# $Id: html_api.php,v 1.184.4.1.2.1.2.1.2.2 2006/09/09 05:47:14 vboctor Exp $
+	# $Id: html_api.php,v 1.218.2.4 2007-10-28 15:39:31 nuclear_eclipse Exp $
 	# --------------------------------------------------------
 
 	###########################################################################
@@ -56,19 +68,27 @@
 	require_once( $t_core_dir . 'helper_api.php' );
 	require_once( $t_core_dir . 'authentication_api.php' );
 	require_once( $t_core_dir . 'user_api.php' );
+	require_once( $t_core_dir . 'rss_api.php' );
+	require_once( $t_core_dir . 'wiki_api.php' );
 
 	$g_rss_feed_url = null;
 
 	# flag for error handler to skip header menus
 	$g_error_send_page_header = true;
+	
+	# Projax library disabled by default.  It will be enabled if projax_api.php
+	# is included.  But it must be included after html_api.php
+	$g_enable_projax = false;
 
 	# --------------------
 	# Sets the url for the rss link associated with the current page.
 	# null: means no feed (default).
 	function html_set_rss_link( $p_rss_feed_url )
 	{
-		global $g_rss_feed_url;
-		$g_rss_feed_url = $p_rss_feed_url;
+		if ( OFF != config_get( 'rss_enabled' ) ) {
+			global $g_rss_feed_url;
+			$g_rss_feed_url = $p_rss_feed_url;
+		}
 	}
 
 	# --------------------
@@ -92,6 +112,7 @@
 		html_content_type();
 		include( config_get( 'meta_include_file' ) );
 		html_rss_link();
+		echo '<link rel="shortcut icon" href="images/favicon.ico" type="image/x-icon" />';
 		html_title( $p_page_title );
 		html_head_javascript();
 	}
@@ -153,10 +174,6 @@
 	#  the menu.  This is used during the login process and other times when the
 	#  user may not be authenticated.
 	function html_page_bottom1a( $p_file = null ) {
-		if ( !php_version_at_least( '4.1.0' ) ) {
-			global $_SERVER;
-		}
-
 		if ( null === $p_file ) {
 			$p_file = basename( $_SERVER['PHP_SELF'] );
 		}
@@ -231,7 +248,7 @@
 		}
 
 		if ( null === $p_time ) {
-			$p_time = config_get( 'wait_time' );
+			$p_time = current_user_get_pref( 'redirect_delay' );
 		}
 
 		if ( $p_sanitize ) {
@@ -249,8 +266,17 @@
 	# (6a) Javascript...
 	function html_head_javascript() {
 		if ( ON == config_get( 'use_javascript' ) ) {
-			echo "\t" . '<script type="text/JavaScript" src="javascript/common.js">';
+			echo "\t" . '<script type="text/javascript" language="JavaScript" src="javascript/common.js">';
 			echo '</script>' . "\n";
+			echo "\t" . '<script type="text/JavaScript" src="javascript/ajax.js">';
+			echo '</script>' . "\n";
+
+			global $g_enable_projax;
+
+			if ( $g_enable_projax ) {
+				echo '<script type="text/javascript" src="javascript/projax/prototype.js"></script>';
+				echo '<script type="text/javascript" src="javascript/projax/scriptaculous.js"></script>';
+			}
 		}
 	}
 
@@ -288,7 +314,7 @@
 			}
 
 			echo '<div align="', $t_align, '">';
-			echo '<a href="http://www.mantisbugtracker.com" title="Mantis Bugtracker"><img border="0" width="238" height="78" alt="Mantis Bugtracker" src="images/mantis_logo.gif" /></a>';
+			echo '<a href="http://www.mantisbt.org" title="Free Web Based Bug Tracker"><img border="0" width="242" height="102" alt="Mantis Bugtracker" src="images/mantis_logo.gif" /></a>';
 			echo '</div>';
 		}
 	}
@@ -306,10 +332,6 @@
 		PRINT '<tr>';
 			PRINT '<td class="login-info-left">';
 				if ( current_user_is_anonymous() ) {
-					if ( !php_version_at_least( '4.1.0' ) ) {
-						global $_SERVER;
-					}
-
 					$t_return_page = $_SERVER['PHP_SELF'];
 					if ( isset( $_SERVER['QUERY_STRING'] ) ) {
 						$t_return_page .=  '?' . $_SERVER['QUERY_STRING'];
@@ -321,8 +343,8 @@
 						PRINT ' | <a href="signup_page.php">' . lang_get( 'signup_link' ) . '</a>';
 					}
 				} else {
-					echo lang_get( 'logged_in_as' ), ": <span class=\"italic\">$t_username</span> <span class=\"small\">";
-					echo is_blank( $t_realname ) ? "($t_access_level)" : "($t_realname - $t_access_level)";
+					echo lang_get( 'logged_in_as' ), ": <span class=\"italic\">", string_display( $t_username ), "</span> <span class=\"small\">";
+					echo is_blank( $t_realname ) ? "($t_access_level)" : "(" . string_display( $t_realname ) . " - $t_access_level)";
 					echo "</span>";
 				}
 			PRINT '</td>';
@@ -333,14 +355,26 @@
 				PRINT '<form method="post" name="form_set_project" action="set_project.php">';
 
 				echo lang_get( 'email_project' ), ': ';
-				if ( ON == config_get( 'use_javascript' )) {
-					PRINT '<select name="project_id" class="small" onchange="document.forms.form_set_project.submit();">';
+				if ( ON == config_get( 'show_extended_project_browser' ) ) {
+					print_extended_project_browser( helper_get_current_project_trace() );
 				} else {
-					PRINT '<select name="project_id" class="small">';
+					if ( ON == config_get( 'use_javascript' ) ) {
+						PRINT '<select name="project_id" class="small" onchange="document.forms.form_set_project.submit();">';
+					} else {
+						PRINT '<select name="project_id" class="small">';
+					}
+					print_project_option_list( join( ';', helper_get_current_project_trace() ), true, null, true );
+					PRINT '</select> ';
 				}
-				print_project_option_list( join( ';', helper_get_current_project_trace() ), true, null, true );
-				PRINT '</select> ';
 				PRINT '<input type="submit" class="button-small" value="' . lang_get( 'switch' ) . '" />';
+
+				if ( OFF != config_get( 'rss_enabled' ) ) {
+					# Link to RSS issues feed for the selected project, including authentication details.
+					PRINT '<a href="' . rss_get_issues_feed_url() . '">';
+					PRINT '<img src="images/rss.gif" alt="' . lang_get( 'rss' ) . '" style="border-style: none; margin: 5px; vertical-align: middle;" />';
+					PRINT '</a>';
+				}
+
 				PRINT '</form>';
 			PRINT '</td>';
 		PRINT '</tr>';
@@ -360,7 +394,7 @@
 	# --------------------
 	# (13) Print the page footer information
 	function html_footer( $p_file ) {
-		global $g_timer, $g_queries_array;
+		global $g_timer, $g_queries_array, $g_request_time;
 
 		# If a user is logged in, update their last visit time.
 		# We do this at the end of the page so that:
@@ -378,10 +412,10 @@
 
 		echo '<table border="0" width="100%" cellspacing="0" cellpadding="0"><tr valign="top"><td>';
 		if ( ON == config_get( 'show_version' ) ) {
-			echo "\t", '<span class="timer"><a href="http://www.mantisbugtracker.com/">Mantis ', config_get( 'mantis_version' ), '</a>',
-					'[<a href="http://www.mantisbugtracker.com/" target="_blank">^</a>]</span>', "\n";
+			echo "\t", '<span class="timer"><a href="http://www.mantisbt.org/" title="Free Web Based Bug Tracker">Mantis ', MANTIS_VERSION, '</a>',
+					'[<a href="http://www.mantisbt.org/"  title="Free Web Based Bug Tracker" target="_blank">^</a>]</span>', "\n";
 		}
-		echo "\t", '<address>Copyright &copy; 2000 - 2006 Mantis Group</address>', "\n";
+		echo "\t", '<address>Copyright &copy; 2000 - 2008 Mantis Group</address>', "\n";
 
 		# only display webmaster email is current user is not the anonymous user
 		if ( ! is_page_name( 'login_page.php' ) && !current_user_is_anonymous() ) {
@@ -394,7 +428,7 @@
 		}
 
 		# print db queries that were run
-		if ( ON == config_get( 'show_queries_count' ) ) {
+		if ( helper_show_queries() ) {
 			$t_count = count( $g_queries_array );
 			echo "\t",  $t_count, ' total queries executed.<br />', "\n";
 			$t_unique_queries = 0;
@@ -402,10 +436,10 @@
 			for ( $i = 0; $i < $t_count; $i++ ) {
 				if ( ! in_array( $g_queries_array[$i][0], $t_shown_queries ) ) {
 					$t_unique_queries++;
-					$g_queries_array[$i][2] = false;
+					$g_queries_array[$i][3] = false;
 					array_push( $t_shown_queries, $g_queries_array[$i][0] );
 				} else {
-					$g_queries_array[$i][2] = true;
+					$g_queries_array[$i][3] = true;
 				}
 			}
 			echo "\t",  $t_unique_queries . ' unique queries executed.<br />', "\n";
@@ -414,20 +448,26 @@
 				$t_total = 0;
 				for ( $i = 0; $i < $t_count; $i++ ) {
 					$t_time = $g_queries_array[$i][1];
+					$t_caller = $g_queries_array[$i][2];
 					$t_total += $t_time;
-					if ( true == $g_queries_array[$i][2] ) {
-						echo "\t",  '<tr valign="top"><td style="color: red">', ($i+1), '</td><td style="color: red">', $t_time , '</td><td style="color: red">', string_html_specialchars($g_queries_array[$i][0]), '</td></tr>', "\n";
-					} else {
-						echo "\t",  '<tr valign="top"><td>', ($i+1), '</td><td>'. $t_time . '</td><td>', string_html_specialchars($g_queries_array[$i][0]), '</td></tr>', "\n";
+					$t_style_tag = '';
+					if ( true == $g_queries_array[$i][3] ) {
+						$t_style_tag = ' style="color: red;"';
 					}
+					echo "\t",  '<tr valign="top"><td', $t_style_tag, '>', ($i+1), '</td>';
+					echo '<td', $t_style_tag, '>', $t_time , '</td>';
+					echo '<td', $t_style_tag, '><span style="color: gray;">', $t_caller, '</span><br />', string_html_specialchars($g_queries_array[$i][0]), '</td></tr>', "\n";
 				}
-				echo "\t", '<tr><td></td><td>', $t_total, '</td><td></td></tr>', "\n";
+
+				# @@@ Note sure if we should localize them given that they are debug info.  Will add if requested by users.
+				echo "\t", '<tr><td></td><td>', $t_total, '</td><td>SQL Queries Total Time</td></tr>', "\n";
+				echo "\t", '<tr><td></td><td>', round( microtime_float() - $g_request_time, 4 ), '</td><td>Page Request Total Time</td></tr>', "\n";
 				echo "\t",  '</table>', "\n";
 			}
 		}
 
 		echo '</td><td><div align="right">';
-		echo '<a href="http://www.mantisbugtracker.com" title="Powered by Mantis Bugtracker"><img src="images/mantis_logo_button.gif" width="88" height="35" alt="Powered by Mantis Bugtracker" border="0" /></a>';
+		echo '<a href="http://www.mantisbt.org" title="Free Web Based Bug Tracker"><img src="images/mantis_logo_button.gif" width="88" height="35" alt="Powered by Mantis Bugtracker" border="0" /></a>';
 		echo '</div></td></tr></table>';
 	}
 
@@ -454,7 +494,7 @@
 
 		foreach( $t_custom_menu_options as $t_custom_option ) {
 			$t_access_level = $t_custom_option[1];
-			if ( access_has_global_level( $t_access_level ) ) {
+			if ( access_has_project_level( $t_access_level ) ) {
 				$t_caption = lang_get_defaulted( $t_custom_option[0] );
 				$t_link = $t_custom_option[2];
 				$t_options[] = "<a href=\"$t_link\">$t_caption</a>";
@@ -469,6 +509,8 @@
 	function print_menu() {
 		if ( auth_is_user_authenticated() ) {
 			$t_protected = current_user_get_field( 'protected' );
+			$t_current_project = helper_get_current_project();
+
 			PRINT '<table class="width100" cellspacing="0">';
 			PRINT '<tr>';
 			PRINT '<td class="menu">';
@@ -493,6 +535,11 @@
 					$t_menu_options[] = '<a href="changelog_page.php">' . lang_get( 'changelog_link' ) . '</a>';
 				}
 
+				# Roadmap Page
+				if ( access_has_project_level( config_get( 'roadmap_view_threshold' ) ) ) {
+					$t_menu_options[] = '<a href="roadmap_page.php">' . lang_get( 'roadmap_link' ) . '</a>';
+				}
+
 				# Summary Page
 				if ( access_has_project_level( config_get( 'view_summary_threshold' ) ) ) {
 					$t_menu_options[] = '<a href="summary_page.php">' . lang_get( 'summary_link' ) . '</a>';
@@ -503,11 +550,16 @@
 					$t_menu_options[] = '<a href="proj_doc_page.php">' . lang_get( 'docs_link' ) . '</a>';
 				}
 
+				# Project Wiki
+				if ( wiki_is_enabled() ) {
+					$t_menu_options[] = '<a href="wiki.php?type=project&amp;id=' . $t_current_project . '">' . lang_get( 'wiki' ) . '</a>';
+				}
+
 				# Manage Users (admins) or Manage Project (managers) or Manage Custom Fields
-				$t_show_access = min( config_get( 'manage_project_threshold' ), config_get( 'manage_custom_fields_threshold' ), ADMINISTRATOR );
+				$t_show_access = min( config_get( 'manage_user_threshold' ), config_get( 'manage_project_threshold' ), config_get( 'manage_custom_fields_threshold' ) );
 				if ( access_has_global_level( $t_show_access) || access_has_any_project( $t_show_access ) )  {
 					$t_current_project = helper_get_current_project();
-					if ( access_has_project_level( ADMINISTRATOR, $t_current_project ) ) {
+					if ( access_has_global_level( config_get( 'manage_user_threshold' ) ) ) {
 						$t_link = 'manage_user_page.php';
 					} else {
 						if ( access_has_project_level( config_get( 'manage_project_threshold' ), $t_current_project )
@@ -538,6 +590,8 @@
 				# Add custom options
 				$t_custom_options = prepare_custom_menu_options( 'main_menu_custom_options' );
 				$t_menu_options = array_merge( $t_menu_options, $t_custom_options );
+				if ( config_get('time_tracking_enabled') && config_get('time_tracking_with_billing') )
+					$t_menu_options[] = '<a href="billing_page.php">' . lang_get( 'time_tracking_billing_link' ) . '</a>';
 
 				# Logout (no if anonymously logged in)
 				if ( !current_user_is_anonymous() ) {
@@ -545,9 +599,16 @@
 				}
 				PRINT implode( $t_menu_options, ' | ' );
 			PRINT '</td>';
-			PRINT '<td class="right" style="white-space: nowrap;">';
+			PRINT '<td class="menu right nowrap">';
 				PRINT '<form method="post" action="jump_to_bug.php">';
-				PRINT "<input type=\"text\" name=\"bug_id\" size=\"10\" class=\"small\" />&nbsp;";
+
+				if ( ON == config_get( 'use_javascript' ) ) {
+					$t_bug_label = lang_get( 'issue_id' );
+					PRINT "<input type=\"text\" name=\"bug_id\" size=\"10\" class=\"small\" value=\"$t_bug_label\" onfocus=\"if (this.value == '$t_bug_label') this.value = ''\" onblur=\"if (this.value == '') this.value = '$t_bug_label'\" />&nbsp;";
+				} else {
+					PRINT "<input type=\"text\" name=\"bug_id\" size=\"10\" class=\"small\" />&nbsp;";
+				}
+
 				PRINT '<input type="submit" class="button-small" value="' . lang_get( 'jump' ) . '" />&nbsp;';
 				PRINT '</form>';
 			PRINT '</td>';
@@ -611,7 +672,7 @@
 		$t_manage_user_page 		= 'manage_user_page.php';
 		$t_manage_project_menu_page = 'manage_proj_page.php';
 		$t_manage_custom_field_page = 'manage_custom_field_page.php';
-		$t_manage_config_page = 'adm_permissions_report.php';
+		$t_manage_config_page = 'adm_config_report.php';
 		$t_manage_prof_menu_page    = 'manage_prof_menu_page.php';
 		# $t_documentation_page 		= 'documentation_page.php';
 
@@ -637,7 +698,7 @@
 		}
 
 		PRINT '<br /><div align="center">';
-		if ( access_has_global_level( ADMINISTRATOR ) ) {
+		if ( access_has_global_level( config_get( 'manage_user_threshold' ) ) ) {
 			print_bracket_link( $t_manage_user_page, lang_get( 'manage_users_link' ) );
 		}
 		if ( access_has_project_level( config_get( 'manage_project_threshold' ) ) ) {
@@ -660,12 +721,16 @@
 	# Print the menu for the manage configuration section
 	# $p_page specifies the current page name so it's link can be disabled
 	function print_manage_config_menu( $p_page = '' ) {
+		$t_configuration_report = 'adm_config_report.php';
 		$t_permissions_summary_report = 'adm_permissions_report.php';
 		$t_manage_work_threshold     = 'manage_config_work_threshold_page.php';
 		$t_manage_email 		= 'manage_config_email_page.php';
 		$t_manage_workflow 		= 'manage_config_workflow_page.php';
 
 		switch ( $p_page ) {
+			case $t_configuration_report:
+				$t_configuration_report = '';
+				break;
 			case $t_permissions_summary_report:
 				$t_permissions_summary_report = '';
 				break;
@@ -682,6 +747,7 @@
 
 		PRINT '<br /><div align="center">';
 		if ( access_has_project_level( config_get( 'view_configuration_threshold' ) ) ) {
+			print_bracket_link( $t_configuration_report, lang_get_defaulted( 'configuration_report' ) );
 			print_bracket_link( $t_permissions_summary_report, lang_get( 'permissions_summary_report' ) );
 			print_bracket_link( $t_manage_work_threshold, lang_get( 'manage_threshold_config' ) );
 			print_bracket_link( $t_manage_workflow, lang_get( 'manage_workflow_config' ) );
@@ -786,6 +852,9 @@
 
 		PRINT '</tr>';
 		PRINT '</table>';
+		if ( ON == config_get( 'status_percentage_legend' ) ) {
+			html_status_percentage_legend();
+		}
 	}
 
  	# --------------------
@@ -821,7 +890,7 @@
 			echo '<br />';
 			echo '<table class="width100" cellspacing="1">';
 			echo '<tr>';
-			echo '<td colspan="'.$enum_count.'"><strong>'.lang_get( 'issue_status_percentage' ).'</strong></td>';
+			echo '<td class="form-title" colspan="'.$enum_count.'">'.lang_get( 'issue_status_percentage' ).'</td>';
 			echo '</tr>';
 			echo '<tr>';
 
@@ -848,22 +917,28 @@
 
 	# --------------------
 	# Print an html button inside a form
-	function html_button ( $p_action, $p_button_text, $p_fields = null ) {
+	function html_button ( $p_action, $p_button_text, $p_fields = null, $p_method = 'post' ) {
 		$p_action		= urlencode( $p_action );
 		$p_button_text	= string_attribute( $p_button_text );
 		if ( null === $p_fields ) {
 			$p_fields = array();
 		}
-
-		PRINT "<form method=\"post\" action=\"$p_action\">\n";
-
+		
+		if ( strtolower( $p_method ) == 'get' ) {
+			$t_method = 'get';
+		} else {
+			$t_method = 'post';
+		}
+	 
+		PRINT "<form method=\"$t_method\" action=\"$p_action\">\n";
+	 
 		foreach ( $p_fields as $key => $val ) {
 			$key = string_attribute( $key );
 			$val = string_attribute( $val );
-
+	 
 			PRINT "	<input type=\"hidden\" name=\"$key\" value=\"$val\" />\n";
 		}
-
+	 
 		PRINT "	<input type=\"submit\" class=\"button\" value=\"$p_button_text\" />\n";
 		PRINT "</form>\n";
 	}
@@ -1074,6 +1149,19 @@
 		}
 	}
 
+	# --------------------
+	# Print a button to create a wiki page
+	function html_button_wiki( $p_bug_id ) {
+		if ( ON == config_get( 'wiki_enable' ) ) {
+			if ( access_has_bug_level( config_get( 'update_bug_threshold' ), $p_bug_id ) ) {
+				html_button( 'wiki.php',
+							 lang_get_defaulted( 'Wiki' ),
+							 array( 'id' => $p_bug_id, 'type' => 'issue' ),
+							 'get' );
+			}
+		}
+	}
+
 	# --------------------
 	# Print all buttons for view bug pages
 	function html_buttons_view_bug_page( $p_bug_id ) {
@@ -1140,4 +1228,5 @@
 
 		echo '</tr></table>';
 	}
+
 ?>
