@@ -1,20 +1,34 @@
 <?php
-	# Mantis - a php based bugtracking system
-	# Copyright (C) 2000 - 2002  Kenzaburo Ito - kenito@300baud.org
-	# Copyright (C) 2002 - 2005  Mantis Team   - mantisbt-dev@lists.sourceforge.net
-	# This program is distributed under the terms and conditions of the GPL
-	# See the README and LICENSE files for details
+# Mantis - a php based bugtracking system
+
+# Copyright (C) 2000 - 2002  Kenzaburo Ito - kenito@300baud.org
+# Copyright (C) 2002 - 2007  Mantis Team   - mantisbt-dev@lists.sourceforge.net
+
+# Mantis is free software: you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation, either version 2 of the License, or
+# (at your option) any later version.
+#
+# Mantis is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with Mantis.  If not, see <http://www.gnu.org/licenses/>.
 
 	# --------------------------------------------------------
-	# $Id: print_api.php,v 1.143.6.1.4.1.2.4 2007/03/06 07:00:33 vboctor Exp $
+	# $Id: print_api.php,v 1.182.2.5 2007-10-24 05:28:10 vboctor Exp $
 	# --------------------------------------------------------
 
 	$t_core_dir = dirname( __FILE__ ).DIRECTORY_SEPARATOR;
 
+	require_once( $t_core_dir . 'ajax_api.php' );
 	require_once( $t_core_dir . 'current_user_api.php' );
 	require_once( $t_core_dir . 'string_api.php' );
 	require_once( $t_core_dir . 'prepare_api.php' );
 	require_once( $t_core_dir . 'profile_api.php' );
+	require_once( $t_core_dir . 'last_visited_api.php' );
 
 	### Print API ###
 
@@ -26,19 +40,17 @@
 	#  immediately
 	# If we have handled any errors on this page and the 'stop_on_errors' config
 	#  option is turned on, return false and don't redirect.
+	# $p_sanitize - true/false - true in the case where the URL is extracted from GET/POST or untrusted source.
+	# This would be false if the URL is trusted (e.g. read from config_inc.php).
 	function print_header_redirect( $p_url, $p_die = true, $p_sanitize = false ) {
 		$t_use_iis = config_get( 'use_iis');
 
 		if ( ON == config_get( 'stop_on_errors' ) && error_handled() ) {
 			return false;
 		}
-		
+
 		# validate the url as part of this site before continuing
-		if ( $p_sanitize ) {
-			$t_url = string_sanitize_url( $p_url );
-		} else {
-			$t_url = $p_url;
-		}
+		$t_url = $p_sanitize ? string_sanitize_url( $p_url ) : $p_url;
 
 		# don't send more headers if they have already been sent (guideweb)
 		if ( ! headers_sent() ) {
@@ -80,7 +92,7 @@
 	#  configured system wait time.
 	# If the show query count is OFF, redirect right away.
 	function print_successful_redirect( $p_redirect_to ) {
-		if ( ON == config_get( 'show_queries_count' ) ) {
+		if ( helper_show_queries() ) {
 			html_meta_redirect( $p_redirect_to );
 			html_page_top1();
 			html_page_top2();
@@ -104,11 +116,35 @@
 	function print_header_redirect_report() {
 		print_header_redirect( string_get_bug_report_url() );
 	}
+
+	
+	# Print avatar image for the given user ID
+	function print_avatar( $p_user_id ) {
+		if ( !user_exists( $p_user_id ) ) {
+			return;
+		}
+
+		if ( access_has_project_level( config_get( 'show_avatar_threshold' ), null, $p_user_id ) ) {
+			$t_avatar = user_get_avatar( $p_user_id );
+			if ( false !== $t_avatar ) {
+				$t_avatar_url = $t_avatar[0];
+				$t_width = $t_avatar[1];
+				$t_height = $t_avatar[2];
+				echo '<a rel="nofollow" href="http://site.gravatar.com">' .
+					'<img class="avatar" src="' . $t_avatar_url . '" alt="User avatar"' .
+					' width="' . $t_width . '" height="' . $t_height . '" /></a>';
+			}
+		}
+	}
+
+
 	# --------------------
 	# prints the name of the user given the id.  also makes it an email link.
 	function print_user( $p_user_id ) {
 	    echo prepare_user_name( $p_user_id );
 	}
+
+
 	# --------------------
 	# same as print_user() but fills in the subject with the bug summary
 	function print_user_with_subject( $p_user_id, $p_bug_id ) {
@@ -238,6 +274,70 @@
 			PRINT "<option value=\"$t_duplicate_id\">".$t_duplicate_id."</option>";
 		}
 	}
+
+	/**
+	 * Print the entire form for attaching a tag to a bug.
+	 * @param integer Bug ID
+	 * @param string Default contents of the input box
+	 */
+	function print_tag_attach_form( $p_bug_id, $p_string="" ) {
+		?>
+		<small><?php echo sprintf( lang_get( 'tag_separate_by' ), config_get('tag_separator') ) ?></small> 
+		<form method="post" action="tag_attach.php">
+		<?php echo form_security_field( 'tag_attach' ) ?>
+		<input type="hidden" name="bug_id" value="<?php echo $p_bug_id ?>" />
+		<?php
+			print_tag_input( $p_bug_id, $p_string );
+		?>
+		<input type="submit" value="<?php echo lang_get( 'tag_attach' ) ?>" class="button" />
+		</form>
+		<?php
+		return true;
+	}
+
+	/**
+	 * Print the separator comment, input box, and existing tag dropdown menu.
+	 * @param integer Bug ID
+	 * @param string Default contents of the input box
+	 */
+	function print_tag_input( $p_bug_id = 0, $p_string="" ) {
+		?>
+		<input type="hidden" id="tag_separator" value="<?php echo config_get( 'tag_separator' ) ?>" />
+		<input type="text" name="tag_string" id="tag_string" size="40" value="<?php echo string_attribute( $p_string ) ?>" />
+		<select <?php echo helper_get_tab_index() ?> name="tag_select" id="tag_select">
+			<?php print_tag_option_list( $p_bug_id ); ?>
+		</select>
+		<?php
+
+		return true;
+	}
+
+	/**
+	 * Print the dropdown combo-box of existing tags.
+	 * When passed a bug ID, the option list will not contain any tags attached to the given bug.
+	 * @param integer Bug ID
+	 */
+	function print_tag_option_list( $p_bug_id = 0 ) {
+		$t_tag_table = config_get( 'mantis_tag_table' );
+
+		$query = "SELECT id, name FROM $t_tag_table ";
+		if ( 0 != $p_bug_id ) {
+			$c_bug_id = db_prepare_int( $p_bug_id );
+			$t_bug_tag_table = config_get( 'mantis_bug_tag_table' );
+			
+			$query .= "	WHERE id NOT IN ( 
+						SELECT tag_id FROM $t_bug_tag_table WHERE bug_id='$c_bug_id' ) ";
+		}
+
+		$query .= " ORDER BY name ASC ";
+		$result = db_query( $query );
+
+		echo '<option value="0">',lang_get( 'tag_existing' ),'</option>';
+		while ( $row = db_fetch_array( $result ) ) {
+			echo '<option value="',$row['id'],'" onclick="tag_string_append(\'',$row['name'],'\')">',$row['name'],'</option>';
+		}
+	}
+
 	# --------------------
 	# Get current headlines and id  prefix with v_
 	function print_news_item_option_list() {
@@ -338,7 +438,7 @@
 		# only show VS_PRIVATE posts to configured threshold and above
 		if ( ( VS_PRIVATE == $row['view_state'] ) &&
 			 !access_has_project_level( config_get( 'private_news_threshold' ) ) ) {
-			continue;
+			return;
 		}
 
 		print_news_entry_from_row( $row );
@@ -404,52 +504,148 @@
 				}
 				PRINT "$t_full_id\"";
 				check_selected( $p_project_id, $t_full_id );
-				PRINT '>' . str_repeat( "&raquo; ", count( $p_parents ) ) . string_display( project_get_field( $t_id, 'name' ) ) . '</option>' . "\n";
+				PRINT '>' . str_repeat( '&nbsp;', count( $p_parents ) ) . str_repeat( '&raquo;', count( $p_parents ) ) . ' ' . string_display( project_get_field( $t_id, 'name' ) ) . '</option>' . "\n";
 				print_subproject_option_list( $t_id, $p_project_id, $p_filter_project_id, $p_trace, $p_parents );
 			}
 		}
 	}
+	# --------------------
+	# Print extended project browser
+	function print_extended_project_browser( $p_trace=Array() ) {
+		project_cache_all();
+		$t_project_ids = current_user_get_accessible_projects();
+
+		echo '<script type="text/javascript" language="JavaScript">' . "\n";
+		echo "<!--\n";
+		echo "var subprojects = new Object();\n";
+
+		$t_projects = Array();
+
+		$t_project_count = count( $t_project_ids );
+		for ($i=0;$i<$t_project_count;$i++) {
+			$t_id = $t_project_ids[$i];
+			echo 'subprojects[\'' . $t_id . '\'] = new Object();' . "\n";
+
+			$t_name = project_get_field( $t_id, 'name' );
+			$c_name = addslashes( $t_name );
+			echo 'subprojects[\'' . $t_id . '\'][\'' . $t_id . '\'] = \'' . $c_name . '\';' . "\n";
+
+			$t_projects[$t_id] = $t_name;
+			
+			print_extended_project_browser_subproject_javascript( $t_id );
+		}
+
+		echo "\n";
+		echo 'function setProject(projectVal) {' . "\n";
+		echo "\t" . 'var spInput = document.form_set_project.project_id;' . "\n";
+		echo "\t" . 'spInput.options.length = 0' . "\n";
+		echo "\t" . 'if (projectVal == "' . ALL_PROJECTS . '") {' . "\n";
+		echo "\t\t" . 'spInput.options[0] = new Option(\'--- All Projects ---\', \'' . ALL_PROJECTS . '\');' . "\n";
+		echo "\t" . '} else {' . "\n";
+		echo "\t\t" . 'var i = 0;' . "\n";
+		echo "\t\t" . 'var project = subprojects[ projectVal ];' . "\n";
+		echo "\t\t" . 'for ( var sp in project ) {' . "\n";
+		echo "\t\t\t" . 'spInput.options[ i++ ] = new Option( project[sp], sp );' . "\n";
+		echo "\t\t" . '}' . "\n";
+		echo "\t" . '}' . "\n";
+		echo '}' . "\n";
+		
+		echo '// --></script>' . "\n";
+		echo '<select name="top_id" onChange="setProject(this.value); document.form_set_project.submit()" class="small">' . "\n";
+		echo '<option value="' . ALL_PROJECTS . '"';
+		echo check_selected( $p_project_id, ALL_PROJECTS );
+		echo '>' . lang_get('all_projects') . '</option>' . "\n";
+		
+		foreach ( $t_projects as $t_id => $t_name ) {
+			$c_name = string_display( $t_name );
+			echo '<option value="' . $t_id . '"';
+			echo check_selected( $p_project_id, $t_id );
+		        echo '>' . $c_name . '</option>' . "\n";
+		}
+
+		echo '</select>' . "\n";
+
+		if ( 0 === count( $p_trace ) ) {
+			$t_top_id = ALL_PROJECTS;
+		} else {
+			$t_top_id = $p_trace[0];
+			$t_trace_str = join( ';', $p_trace );
+		}
+
+		echo '<select name="project_id" onChange="document.form_set_project.submit()" class="small-subprojects"></select>' . "\n";
+		echo '<script type="text/javascript" language="JavaScript">' . "\n";
+		echo '<!--' . "\n";
+		echo 'document.form_set_project.top_id.value = \'' . $t_top_id . '\';'. "\n";
+		echo 'setProject(' . $t_top_id . ');' . "\n";
+		echo 'document.form_set_project.project_id.value = \'' . $t_trace_str . '\';' . "\n";
+		echo '// --></script>' . "\n";
+	}
+
+	# --------------------
+	# print the subproject javascript for the extended project browser
+	function print_extended_project_browser_subproject_javascript( $p_trace ) {
+		$t_trace_projects = split( ';', $p_trace);
+		$t_top_id = $t_trace_projects[0];
+		$t_level = count( $t_trace_projects );
+		$t_parent_id = $t_trace_projects[ $t_level - 1 ];
+		
+		$t_project_ids = current_user_get_accessible_subprojects( $t_parent_id );
+		$t_project_count = count( $t_project_ids );
+
+		for ($i=0;$i<$t_project_count;$i++) {
+			$t_id = $t_project_ids[$i];
+			$t_nbsp = chr( 160 );
+			$t_name = addslashes( str_repeat( $t_nbsp , $t_level ) . str_repeat( '&raquo;', $t_level ) . ' ' . project_get_field( $t_id, 'name' ) );
+			echo 'subprojects[\'' . $t_top_id . '\'][\'' . $p_trace . ';' . $t_id . '\'] = \'' . $t_name . '\';' . "\n";
+
+			print_extended_project_browser_subproject_javascript( $p_trace . ';' . $t_id );
+		}
+	}
+		
 	# --------------------
 	# prints the profiles given the user id
-	function print_profile_option_list( $p_user_id, $p_select_id='' ) {
+	function print_profile_option_list( $p_user_id, $p_select_id='', $p_profiles = null ) {
 		if ( '' === $p_select_id ) {
 			$p_select_id = profile_get_default( $p_user_id );
 		}
-		$t_profiles = profile_get_all_for_user( $p_user_id );
-
-		PRINT '<option value=""></option>';
-		foreach ( $t_profiles as $t_profile ) {
-			extract( $t_profile, EXTR_PREFIX_ALL, 'v' );
-			$v_platform	= string_display( $v_platform );
-			$v_os		= string_display( $v_os );
-			$v_os_build	= string_display( $v_os_build );
-
-			PRINT "<option value=\"$v_id\"";
-			check_selected( $p_select_id, $v_id );
-			PRINT ">$v_platform $v_os $v_os_build</option>";
+		if ( $p_profiles != null ) {
+			$t_profiles = $p_profiles;
+		} else {
+			$t_profiles = profile_get_all_for_user( $p_user_id );
 		}
+		print_profile_option_list_from_profiles( $t_profiles, $p_select_id );
 	}
+	
 	# --------------------
 	# prints the profiles used in a certain project
-	function print_profile_option_list_for_project( $p_project_id, $p_select_id='') {
+	function print_profile_option_list_for_project( $p_project_id, $p_select_id='', $p_profiles = null) {
 		if ( '' === $p_select_id ) {
 			$p_select_id = profile_get_default( $p_user_id );
 		}
-
-		$t_profiles = profile_get_all_for_project( $p_project_id );
-
-		PRINT '<option value=""></option>';
-		foreach ( $t_profiles as $t_profile ) {
+		if ( $p_profiles != null ) {
+			$t_profiles = $p_profiles;
+		} else {
+			$t_profiles = profile_get_all_for_project( $p_project_id );
+		}
+		print_profile_option_list_from_profiles( $t_profiles, $p_select_id );
+	}
+	
+	# --------------------
+	# print the profile option list from profiles array
+	function print_profile_option_list_from_profiles ( $p_profiles, $p_select_id) {
+		echo '<option value=""></option>';
+		foreach ( $p_profiles as $t_profile ) {
 			extract( $t_profile, EXTR_PREFIX_ALL, 'v' );
 			$v_platform	= string_display( $v_platform );
 			$v_os		= string_display( $v_os );
 			$v_os_build	= string_display( $v_os_build );
-
-			PRINT "<option value=\"$v_id\"";
+	
+			echo '<option value="' . $v_id . '"';
 			check_selected( $p_select_id, $v_id );
-			PRINT ">$v_platform $v_os $v_os_build</option>";
+			echo '>' . $v_platform . ' ' . $v_os . ' ' . $v_os_build . '</option>';
 		}
 	}
+	
 	# --------------------
 	function print_news_project_option_list( $p_project_id ) {
 		$t_mantis_project_table = config_get( 'mantis_project_table' );
@@ -505,6 +701,14 @@
 			$row = db_fetch_array( $result );
 			$cat_arr[] = string_attribute( $row['category'] );
 		}
+
+		# Add the default option if not in the list retrieved from DB		
+		# This is useful for default categories and when updating an
+		# issue with a deleted category.
+		if ( !is_blank( $p_category ) && !in_array( $p_category, $cat_arr ) ) {
+			$cat_arr[] = $p_category;
+		}
+
 		sort( $cat_arr );
 		$cat_arr = array_unique( $cat_arr );
 
@@ -564,6 +768,43 @@
 			PRINT ">$t_category</option>";
 		}
 	}
+	
+	# --------------------
+	# Print the option list for platforms accessible for the specified user.
+	function print_platform_option_list( $p_platform, $p_user_id = null ) {
+		$t_platforms_array = profile_get_field_all_for_user( 'platform', $p_user_id );
+
+		foreach ( $t_platforms_array as $t_platform ) {
+			echo "<option value=\"$t_platform\"";
+			check_selected( $p_platform, $t_platform );
+			echo ">$t_platform</option>";
+		}
+	}
+
+	# --------------------
+	# Print the option list for OSes accessible for the specified user.
+	function print_os_option_list( $p_os, $p_user_id = null ) {
+		$t_os_array = profile_get_field_all_for_user( 'os', $p_user_id );
+
+		foreach ( $t_os_array as $t_os ) {
+			echo "<option value=\"$t_os\"";
+			check_selected( $p_os, $t_os );
+			echo ">$t_os</option>";
+		}
+	}
+
+	# --------------------
+	# Print the option list for os_build accessible for the specified user.
+	function print_os_build_option_list( $p_os_build, $p_user_id = null ) {
+		$t_os_build_array = profile_get_field_all_for_user( 'os_build', $p_user_id );
+
+		foreach ( $t_os_build_array as $t_os_build ) {
+			echo "<option value=\"$t_os_build\"";
+			check_selected( $p_os_build, $t_os_build );
+			echo ">$t_os_build</option>";
+		}
+	}
+
 	# --------------------
 	# Print the option list for versions
 	# $p_version = currently selected version.
@@ -587,11 +828,12 @@
 		if ( $p_leading_blank ) {
 			echo '<option value=""></option>';
 		}
+
 		foreach( $versions as $version ) {
-			$t_version = string_shorten( string_attribute( $version['version'] ) );
+			$t_version = string_attribute( $version['version'] );
 			echo "<option value=\"$t_version\"";
 			check_selected( $p_version, $t_version );
-			echo ">$t_version</option>";
+			echo '>', string_shorten( $t_version ), '</option>';
 		}
 	}
 	# --------------------
@@ -642,6 +884,7 @@
 			echo ">$t_elem2</option>";
 		} # end for
 	}
+	
 	# --------------------
 	# Select the proper enum values for status based on workflow
 	# or the input parameter if workflows are not used
@@ -693,7 +936,7 @@
 			# resort the list into ascending order
 			ksort( $t_enum_list );
 			reset( $t_enum_list );
-			echo '<select name="' . $p_select_label . '">';
+			echo '<select ', helper_get_tab_index(), ' name="' . $p_select_label . '">';
 			foreach ( $t_enum_list as $key => $val ) {
 				echo "<option value=\"$key\"";
 				check_selected( $key, $p_current_value );
@@ -713,7 +956,7 @@
 	}
 	# --------------------
 	# prints the list of access levels that are less than or equal to the access level of the
-	# logged in user. This is used when adding users to projects
+	# logged in user.  This is used when adding users to projects
 	function print_project_access_levels_option_list( $p_val, $p_project_id = null ) {
 		$t_current_user_access_level = access_get_project_level( $p_project_id );
 
@@ -764,12 +1007,24 @@
 							'UP_PRIOR' => lang_get('actiongroup_menu_update_priority'),
 							'UP_STATUS' => lang_get('actiongroup_menu_update_status'),
 							'UP_CATEGORY' => lang_get('actiongroup_menu_update_category'),
-							'VIEW_STATUS' => lang_get( 'actiongroup_menu_update_view_status' ) );
+							'VIEW_STATUS' => lang_get( 'actiongroup_menu_update_view_status' ),
+							'EXT_ADD_NOTE' => lang_get( 'actiongroup_menu_add_note' ),
+							'EXT_ATTACH_TAGS' => lang_get( 'actiongroup_menu_attach_tags' ),
+					);
 
 		$t_project_id = helper_get_current_project();
 
 		if ( ALL_PROJECTS != $t_project_id ) {
 			$t_user_id = auth_get_current_user_id();
+
+			if ( access_has_project_level( config_get( 'update_bug_threshold' ), $t_project_id ) ) {
+				$commands['UP_FIXED_IN_VERSION'] = lang_get( 'actiongroup_menu_update_fixed_in_version' );
+			}
+
+			if ( access_has_project_level( config_get( 'roadmap_update_threshold' ), $t_project_id ) ) {
+				$commands['UP_TARGET_VERSION'] = lang_get( 'actiongroup_menu_update_target_version' );
+			}
+
 			$t_custom_field_ids = custom_field_get_linked_ids( $t_project_id );
 
 			foreach( $t_custom_field_ids as $t_custom_field_id ) {
@@ -789,7 +1044,12 @@
 		$t_custom_group_actions = config_get( 'custom_group_actions' );
 
 		foreach( $t_custom_group_actions as $t_custom_group_action ) {
-			$commands[$t_custom_group_action['action']] = lang_get_defaulted( $t_custom_group_action['action'] );
+			# use label if provided to get the localized text, otherwise fallback to action name.
+			if ( isset( $t_custom_group_action['label'] ) ) {
+				$commands[$t_custom_group_action['action']] = lang_get_defaulted( $t_custom_group_action['label'] );
+			} else {
+				$commands[$t_custom_group_action['action']] = lang_get_defaulted( $t_custom_group_action['action'] );
+			}
 		}
 
 		while (list ($key,$val) = each ($commands)) {
@@ -904,6 +1164,54 @@
 			echo '<br />';
 		}
 	}
+	
+	# --------------------
+	# List of projects with which the specified field id is linked.
+	# For every project, the project name is listed and then the list of custom 
+	# fields linked in order with their sequence numbers.  The specified field
+	# is always highlighted in italics and project names in bold.
+	#
+	# $p_field_id - The field to list the projects associated with.
+	function print_custom_field_projects_list( $p_field_id ) {
+		$c_field_id = (integer)$p_field_id;
+		$t_project_ids = custom_field_get_project_ids( $p_field_id );
+
+		$t_security_token = form_security_param( 'manage_proj_custom_field_remove' );
+
+		foreach ( $t_project_ids as $t_project_id ) {
+			$t_project_name = project_get_field( $t_project_id, 'name' );
+			$t_sequence = custom_field_get_sequence( $p_field_id, $t_project_id );
+			echo '<b>', $t_project_name, '</b>: ';
+			print_bracket_link( "manage_proj_custom_field_remove.php?field_id=$c_field_id&amp;project_id=$t_project_id&amp;return=custom_field$t_security_token", lang_get( 'remove_link' ) );
+			echo '<br />- ';
+			
+			$t_linked_field_ids = custom_field_get_linked_ids( $t_project_id );
+
+			$t_current_project_fields = array();
+
+			$t_first = true;
+			foreach ( $t_linked_field_ids as $t_current_field_id ) {
+				if ( $t_first ) {
+					$t_first = false;
+				} else {
+					echo ', ';
+				}
+
+				if ( $t_current_field_id == $p_field_id ) {
+					echo '<em>';
+				}
+
+				echo string_display( custom_field_get_field( $t_current_field_id, 'name' ) );
+				echo ' (', custom_field_get_sequence( $t_current_field_id, $t_project_id ), ')';
+
+				if ( $t_current_field_id == $p_field_id ) {
+					echo '</em>';
+				}
+			}
+
+			echo '<br /><br />';
+		}
+	}
 
 	# --------------------
 	###########################################################################
@@ -1044,7 +1352,7 @@
 	# --------------------
 	function print_manage_user_sort_link( $p_page, $p_string, $p_field, $p_dir, $p_sort_by, $p_hide=0 ) {
 		if ( $p_sort_by == $p_field ) {   # If this is the selected field flip the order
-			if ( 'ASC' == $p_dir || ASC == $p_dir ) {
+			if ( 'ASC' == $p_dir || ASCENDING == $p_dir ) {
 				$t_dir = 'DESC';
 			} else {
 				$t_dir = 'ASC';
@@ -1058,7 +1366,7 @@
 	# --------------------
 	function print_manage_project_sort_link( $p_page, $p_string, $p_field, $p_dir, $p_sort_by ) {
 		if ( $p_sort_by == $p_field ) {   # If this is the selected field flip the order
-			if ( 'ASC' == $p_dir || ASC == $p_dir ) {
+			if ( 'ASC' == $p_dir || ASCENDING == $p_dir ) {
 				$t_dir = 'DESC';
 			} else {
 				$t_dir = 'ASC';
@@ -1071,25 +1379,37 @@
 	}
 	# --------------------
 	# print a button which presents a standalone form.
-	# if the $p_link is blank then the text is printed but no link is created
-	# if $p_new_window is true, link will open in a new window, default false.
-	function print_button( $p_action_page, $p_label ) {
-		echo '<form method="POST" action="', $p_action_page, '"><input type="submit" class="button-small" value="', $p_label, '" /></form>';
+	# $p_action_page - The action page
+	# $p_label - The button label
+	# $p_args_to_post - An associative array with key => value to be posted, can be null.
+	function print_button( $p_action_page, $p_label, $p_args_to_post = null ) {
+		echo '<form method="post" action="', $p_action_page, '">';
+		echo '<input type="submit" class="button-small" value="', $p_label, '" />';
+		
+		if ( $p_args_to_post !== null ) {
+			foreach( $p_args_to_post as $t_var => $t_value ) {
+				echo "<input type=\"hidden\" name=\"$t_var\" value=\"$t_value\" />";
+			}
+		}
+
+		echo '</form>';
 	}
 	# --------------------
 	# print the bracketed links used near the top
 	# if the $p_link is blank then the text is printed but no link is created
 	# if $p_new_window is true, link will open in a new window, default false.
 	function print_bracket_link( $p_link, $p_url_text, $p_new_window = false ) {
+		PRINT '<span class="bracket-link">[&nbsp;';
 		if (is_blank( $p_link )) {
-			PRINT "[&nbsp;$p_url_text&nbsp;]";
+			PRINT $p_url_text;
 		} else {
 			if( true == $p_new_window ) {
-				PRINT "[&nbsp;<a href=\"$p_link\" target=\"_blank\">$p_url_text</a>&nbsp;]";
+				PRINT "<a href=\"$p_link\" target=\"_blank\">$p_url_text</a>";
 			} else {
-				PRINT "[&nbsp;<a href=\"$p_link\">$p_url_text</a>&nbsp;]";
+				PRINT "<a href=\"$p_link\">$p_url_text</a>";
 			}
 		}
+		PRINT '&nbsp;]</span> ';
 	}
 	# --------------------
 	# print a HTML link
@@ -1102,20 +1422,25 @@
 	}
 	# --------------------
 	# print a HTML page link
-	function print_page_link( $p_page_url, $p_text = '', $p_page_no=0, $p_page_cur=0 ) {
+	function print_page_link( $p_page_url, $p_text = '', $p_page_no=0, $p_page_cur=0, $p_temp_filter_id = 0 ) {
 		if (is_blank( $p_text )) {
 			$p_text = $p_page_no;
 		}
 
 		if ( ( 0 < $p_page_no ) && ( $p_page_no != $p_page_cur ) ) {
-			PRINT " <a href=\"$p_page_url?page_number=$p_page_no\">$p_text</a> ";
+			if ( $p_temp_filter_id > 0 ) {
+				PRINT " <a href=\"$p_page_url?filter=$p_temp_filter_id&amp;page_number=$p_page_no\">$p_text</a> ";		
+			} else {
+				PRINT " <a href=\"$p_page_url?page_number=$p_page_no\">$p_text</a> ";		
+			}
+		
 		} else {
 			PRINT " $p_text ";
 		}
 	}
 	# --------------------
 	# print a list of page number links (eg [1 2 3])
-	function print_page_links( $p_page, $p_start, $p_end, $p_current ) {
+	function print_page_links( $p_page, $p_start, $p_end, $p_current,$p_temp_filter_id = 0 ) {
 		$t_items = array();
 		$t_link = '';
 
@@ -1137,8 +1462,8 @@
 		print( "[ " );
 
 		# First and previous links
-		print_page_link( $p_page, $t_first, 1, $p_current );
-		print_page_link( $p_page, $t_prev, $p_current - 1, $p_current );
+		print_page_link( $p_page, $t_first, 1, $p_current, $p_temp_filter_id );
+		print_page_link( $p_page, $t_prev, $p_current - 1, $p_current, $p_temp_filter_id );
 
 		# Page numbers ...
 
@@ -1157,7 +1482,11 @@
 			if ( $i == $p_current ) {
 				array_push( $t_items, $i );
 			} else {
-				array_push( $t_items, "<a href=\"$p_page?page_number=$i\">$i</a>" );
+				if ( $p_temp_filter_id > 0 ) {
+					array_push( $t_items, "<a href=\"$p_page?filter=$p_temp_filter_id&amp;page_number=$i\">$i</a>" );				
+				} else {
+					array_push( $t_items, "<a href=\"$p_page?page_number=$i\">$i</a>" );
+				}
 			}
 		}
 		PRINT implode( '&nbsp;', $t_items );
@@ -1168,11 +1497,11 @@
 
 		# Next and Last links
 		if ( $p_current < $p_end ) {
-			print_page_link( $p_page, $t_next, $p_current + 1, $p_current );
+			print_page_link( $p_page, $t_next, $p_current + 1, $p_current, $p_temp_filter_id );
 		} else {
-			print_page_link( $p_page, $t_next );
+			print_page_link( $p_page, $t_next, null, null, $p_temp_filter_id );
 		}
-		print_page_link( $p_page, $t_last, $p_end, $p_current );
+		print_page_link( $p_page, $t_last, $p_end, $p_current, $p_temp_filter_id );
 
     	print( " ]" );
 	}
@@ -1215,7 +1544,7 @@
 	#
 	# If a value is an array an input will be created for each item with a name
 	#  that ends with []
-	# The names and values are passed through string_html_specialchars() before being displayed
+	# The names and values are passed through htmlspecialchars() before being displayed
 	function print_hidden_inputs( $p_assoc_array ) {
 		foreach ( $p_assoc_array as $key => $val ) {
 			$key = string_html_specialchars( $key );
@@ -1300,24 +1629,12 @@
 	# this function should rarely (if ever) be reached.  instead the db_()
 	# functions should trap (although inelegantly).
 	function print_sql_error( $p_query ) {
-		global $MANTIS_ERROR, $g_administrator_email;
+		global $g_administrator_email;
 
-		PRINT $MANTIS_ERROR[ERROR_SQL];
+		PRINT error_string( ERROR_SQL );
 		print_email_link( $g_administrator_email, lang_get( 'administrator' ) );
 		PRINT "<br />$p_query;<br />";
 	}
-	# --------------------
-	# This is our generic error printing function
-	# Errors should terminate the script immediately
-	function print_mantis_error( $p_error_num=0 ) {
-		global $MANTIS_ERROR;
-
-		PRINT '<html><head></head><body>';
-		PRINT $MANTIS_ERROR[$p_error_num];
-		PRINT '</body></html>';
-		exit;
-	}
-
 	# --------------------
 	# Get icon corresponding to the specified filename
 	function print_file_icon( $p_filename ) {
@@ -1329,14 +1646,79 @@
 		}
 
 		$t_name = $t_file_type_icons[$ext];
-		PRINT '<img src="' . config_get( 'path' ) . 'images/'. $t_name . '" width="16" height="16" border="0" />';
+		PRINT '<img src="' . config_get( 'path' ) . 'images/fileicons/'. $t_name .
+			'" alt="' . $ext . ' file icon" width="16" height="16" border="0" />';
 	}
 
-
 	# --------------------
 	# Prints an RSS image that is hyperlinked to an RSS feed.
 	function print_rss( $p_feed_url, $p_title = '' ) {
 		$t_path = config_get( 'path' );
 		echo '<a href="', $p_feed_url, '" title="', $p_title, '"><img src="', $t_path, '/images/', 'rss.gif" border="0" alt="', $p_title, '" width="26" height="13" /></a>';
 	}
+
+	# --------------------
+	# Prints the recently visited issues.
+	function print_recently_visited() {
+		if ( !last_visited_enabled() ) {
+			return;
+		}
+
+		$t_ids = last_visited_get_array();
+		
+		if ( count( $t_ids ) == 0 ) {
+			return;
+		}
+
+		echo '<div align="right"><small>' . lang_get( 'recently_visited' ) . ': ';		
+		$t_first = true;
+
+		foreach( $t_ids as $t_id ) {
+			if ( !$t_first ) {
+				echo ', ';
+			} else {
+				$t_first = false;
+			}
+
+			echo string_get_bug_view_link( $t_id );
+		}
+		echo '</small></div>';
+	}
+
+
+	# ----------------------
+	# print a dropdown box from input array
+	function get_dropdown( $p_control_array, $p_control_name, $p_match = '', $p_add_any=false, $p_multiple=false, $p_change_script = '') {
+		$t_control_array = $p_control_array;
+		if ( $p_multiple ){
+			$t_size = ' SIZE="5"';
+			$t_multiple = ' MULTIPLE';
+		} else {
+			$t_size = '';
+			$t_multiple = '';
+		}
+		$t_script = ($p_change_script == '' ? '' : ' onchange="'.$p_change_script.'"');
+		$t_info = sprintf("<SELECT %s NAME=\"%s\" id=\"%s\"%s%s>", 
+		    $t_multiple, $p_control_name, $p_control_name, $t_size, $t_script);
+		if ( $p_add_any ) {
+			array_unshift_assoc( $t_control_array, FILTER_META_ANY, lang_trans( '[any]' ) );
+		}
+		while( list( $t_name, $t_desc ) = each( $t_control_array ) ) {
+			$t_sel = "";
+			if( is_array( $p_match ) ) {
+				if( in_array( $t_name, array_values( $p_match ) ) || 
+						in_array( $t_desc, array_values( $p_match ) ) ) {
+					$t_sel = " SELECTED";
+				}
+			} else {
+				if( ( $t_name === $p_match ) || ( $t_desc === $p_match ) ) {
+					$t_sel = " SELECTED";
+				}
+			}
+			$t_info .= sprintf("<OPTION%s VALUE=\"%s\">%s", $t_sel, $t_name, $t_desc);
+		}
+		$t_info .= "</SELECT>\n";
+		return $t_info;
+	}
+	
 ?>
