@@ -1,12 +1,24 @@
 <?php
-	# Mantis - a php based bugtracking system
-	# Copyright (C) 2000 - 2002  Kenzaburo Ito - kenito@300baud.org
-	# Copyright (C) 2002 - 2004  Mantis Team   - mantisbt-dev@lists.sourceforge.net
-	# This program is distributed under the terms and conditions of the GPL
-	# See the README and LICENSE files for details
+# Mantis - a php based bugtracking system
+
+# Copyright (C) 2000 - 2002  Kenzaburo Ito - kenito@300baud.org
+# Copyright (C) 2002 - 2007  Mantis Team   - mantisbt-dev@lists.sourceforge.net
+
+# Mantis is free software: you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation, either version 2 of the License, or
+# (at your option) any later version.
+#
+# Mantis is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with Mantis.  If not, see <http://www.gnu.org/licenses/>.
 
 	# --------------------------------------------------------
-	# $Id: string_api.php,v 1.75.4.2.2.1.2.1.2.2 2006/07/05 03:04:41 thraxisp Exp $
+	# $Id: string_api.php,v 1.92.2.1 2007-10-13 22:35:43 giallu Exp $
 	# --------------------------------------------------------
 
 	$t_core_dir = dirname( __FILE__ ).DIRECTORY_SEPARATOR;
@@ -50,7 +62,7 @@
 	# Prepare a string to be printed without being broken into multiple lines
 	function string_no_break( $p_string ) {
 		if ( strpos( $p_string, ' ' ) !== false ) {
-			return "<nobr>$p_string</nobr>";
+			return '<span class="nowrap">' . $p_string . "</span>";
 		} else {
 			return $p_string;
 		}
@@ -61,37 +73,55 @@
 	# <pre> tags.
 	# additionally, wrap the text an $p_wrap character intervals if the config is set
 	function string_nl2br( $p_string, $p_wrap = 100 ) {
-		$p_string = nl2br( $p_string );
-
-		# fix up eols within <pre> tags (#1146)
-		$pre2 = array();
-		preg_match_all("/<pre[^>]*?>(.|\n)*?<\/pre>/", $p_string, $pre1);
-		for ( $x = 0; $x < count($pre1[0]); $x++ ) {
-			$pre2[$x] = preg_replace("/<br[^>]*?>/", "", $pre1[0][$x]);
-			# @@@ thraxisp - this may want to be replaced by html_entity_decode (or equivalent)
-			#     if other encoded characters are a problem
-			$pre2[$x] = preg_replace("/&nbsp;/", " ", $pre2[$x]);
-			if ( ON == config_get( 'wrap_in_preformatted_text' ) ) {
-				$pre2[$x] = preg_replace("/([^\n]{".$p_wrap."})(?!<\/pre>)/", "$1\n", $pre2[$x]);
+		$output = '';
+		$pieces = preg_split('/(<pre[^>]*>.*?<\/pre>)/is', $p_string, -1, PREG_SPLIT_DELIM_CAPTURE); 	
+		if(isset($pieces[1])) 
+		{
+			foreach($pieces as $piece)
+			{
+				if(preg_match('/(<pre[^>]*>.*?<\/pre>)/is', $piece)) 
+				{
+					$piece = preg_replace("/<br[^>]*?>/", "", $piece);
+					# @@@ thraxisp - this may want to be replaced by html_entity_decode (or equivalent)
+					#     if other encoded characters are a problem
+					$piece = preg_replace("/&nbsp;/", " ", $piece);
+					if ( ON == config_get( 'wrap_in_preformatted_text' ) ) {
+						$output .= preg_replace('/([^\n]{'.$p_wrap.'})(?!<\/pre>)/', "$1\n", $piece);
+					} else {
+						$output .= $piece;
+					}
+				} else {
+					$output .= nl2br($piece);
+				}
 			}
-			$pre1[0][$x] = "/" . preg_quote($pre1[0][$x], "/") . "/";
+			return $output;
+		} else {
+			return nl2br($p_string);
 		}
-
-		return preg_replace( $pre1[0], $pre2, $p_string );
 	}
 
 	# --------------------
-	# Prepare a string for display to HTML
-	function string_display( $p_string ) {
+	# Prepare a multiple line string for display to HTML
+	function string_display( $p_string ) {	
 		$p_string = string_strip_hrefs( $p_string );
 		$p_string = string_html_specialchars( $p_string );
-		$p_string = string_restore_valid_html_tags( $p_string );
+		$p_string = string_restore_valid_html_tags( $p_string, /* multiline = */ true );
 		$p_string = string_preserve_spaces_at_bol( $p_string );
 		$p_string = string_nl2br( $p_string );
 
 		return $p_string;
 	}
 
+	# --------------------
+	# Prepare a single line string for display to HTML
+	function string_display_line( $p_string ) {
+		$p_string = string_strip_hrefs( $p_string );
+		$p_string = string_html_specialchars( $p_string );
+		$p_string = string_restore_valid_html_tags( $p_string, /* multiline = */ false );
+
+		return $p_string;
+	}
+
 	# --------------------
 	# Prepare a string for display to HTML and add href anchors for URLs, emails,
 	#  bug references, and cvs references
@@ -105,6 +135,19 @@
 		return $p_string;
 	}
 
+	# --------------------
+	# Prepare a single line string for display to HTML and add href anchors for 
+	# URLs, emails, bug references, and cvs references
+	function string_display_line_links( $p_string ) {
+		$p_string = string_display_line( $p_string );
+		$p_string = string_insert_hrefs( $p_string );
+		$p_string = string_process_bug_link( $p_string );
+		$p_string = string_process_bugnote_link( $p_string );
+		$p_string = string_process_cvs_link( $p_string );
+
+		return $p_string;
+	}
+
 	# --------------------
 	# Prepare a string for display in rss
 	function string_rss_links( $p_string ) {
@@ -176,7 +219,6 @@
 	# --------------------
 	# validate the url as part of this site before continuing
 	function string_sanitize_url( $p_url ) {
-
 		$t_url = strip_tags( urldecode( $p_url ) );
 		if ( preg_match( '?http(s)*://?', $t_url ) > 0 ) { 
 			// no embedded addresses
@@ -192,15 +234,22 @@
 		// split and encode parameters
 		if ( strpos( $t_url, '?' ) !== FALSE ) {
 			list( $t_path, $t_param ) = split( '\?', $t_url, 2 );
-			if ( $t_param !== "" ) {
+			if ( !is_blank($t_param ) ) {
 				$t_vals = array();
-				parse_str( $t_param, $t_vals );
+				parse_str( html_entity_decode( $t_param ), $t_vals );
 				$t_param = '';
-				foreach($t_vals as $k => $v) {
-					if ($t_param != '') {
-						$t_param .= '&'; 
+				foreach( $t_vals as $k => $v ) {
+					if ( $t_param != '' ) {
+						$t_param .= '&amp;'; 
+					}
+					if ( is_array( $v ) ) {
+						for ( $i = 0, $t_size = sizeof( $v ); $i < $t_size; $i++ ) {
+							$t_param .= $k . urlencode( '[]' ) . '=' . urlencode( strip_tags( urldecode( $v[$i] ) ) );
+							$t_param .= ( $i != $t_size - 1 ) ? '&amp;' : '';
+						}
+					} else {
+						$t_param .= "$k=" . urlencode( strip_tags( urldecode( $v ) ) );
 					}
-					$t_param .= "$k=" . urlencode( strip_tags( urldecode( $v ) ) );
 				}
 				return $t_path . '?' . $t_param;
 			} else {
@@ -243,48 +292,40 @@
 	#  preceeded by a character that is not a letter, a number or an underscore
 	#
 	# if $p_include_anchor = false, $p_fqdn is ignored and assumed to true.
+	$string_process_bug_link_callback = array();
+
 	function string_process_bug_link( $p_string, $p_include_anchor = true, $p_detail_info = true, $p_fqdn = false ) {
+		global $string_process_bug_link_callback;
+
 		$t_tag = config_get( 'bug_link_tag' );
 		# bail if the link tag is blank
-		if ( '' == $t_tag ) {
+		if ( '' == $t_tag || $p_string == '' ) {
 			return $p_string;
 		}
 
-		preg_match_all( '/(^|.+?)(?:(?<=^|\W)' . preg_quote($t_tag, '/') . '(\d+)|$)/s',
-								$p_string, $t_matches, PREG_SET_ORDER );
-		$t_result = '';
-
-		if ( $p_include_anchor ) {
-			foreach ( $t_matches as $t_match ) {
-				$t_result .= $t_match[1];
-
-				if ( isset( $t_match[2] ) ) {
-					$t_bug_id = $t_match[2];
-					if ( bug_exists( $t_bug_id ) ) {
-						$t_result .= string_get_bug_view_link( $t_bug_id, null, $p_detail_info, $p_fqdn );
-					} else {
-						$t_result .= $t_bug_id;
-					}
-				}
-			}
-		} else {
-			foreach ( $t_matches as $t_match ) {
-				$t_result .= $t_match[1];
-
-				if ( isset( $t_match[2] ) ) {
-					$t_bug_id = $t_match[2];
-					# We might as well create the link here even if the bug
-					#  doesn't exist.  In the case above we don't want to do
-					#  the summary lookup on a non-existant bug.  But here, we
-					#  can create the link and by the time it is clicked on, the
-					#  bug may exist.
-
-					$t_result .= string_get_bug_view_url_with_fqdn( $t_bug_id, null );
-				}
+		if ( !isset( $string_process_bug_link_callback[$p_include_anchor][$p_detail_info][$p_fqdn] ) ) {
+			if ($p_include_anchor) {
+				$string_process_bug_link_callback[$p_include_anchor][$p_detail_info][$p_fqdn] = create_function('$p_array','
+										if (bug_exists( (int)$p_array[2] ) ) { 
+											return $p_array[1] . string_get_bug_view_link( (int)$p_array[2], null, ' . ($p_detail_info ? 'true' : 'false') . ', ' . ($p_fqdn ? 'true' : 'false') . ');
+										} else {    	
+											return $p_array[0];
+										}
+										');
+			} else {
+				$string_process_bug_link_callback[$p_include_anchor][$p_detail_info][$p_fqdn] = create_function('$p_array','
+										# We might as well create the link here even if the bug
+										#  doesnt exist.  In the case above we dont want to do
+										#  the summary lookup on a non-existant bug.  But here, we
+										#  can create the link and by the time it is clicked on, the
+										#  bug may exist.			
+										return $p_array[1] . string_get_bug_view_url_with_fqdn( (int)$p_array[2], null );
+										');
 			}
 		}
 
-		return $t_result;
+		$p_string = preg_replace_callback( '/(^|[^\w&])' . preg_quote($t_tag, '/') . '(\d+)\b/', $string_process_bug_link_callback[$p_include_anchor][$p_detail_info][$p_fqdn], $p_string);
+		return $p_string;
 	}
 
 	# --------------------
@@ -300,52 +341,49 @@
 	#  preceeded by a character that is not a letter, a number or an underscore
 	#
 	# if $p_include_anchor = false, $p_fqdn is ignored and assumed to true.
+	$string_process_bugnote_link_callback = array();
+
 	function string_process_bugnote_link( $p_string, $p_include_anchor = true, $p_detail_info = true, $p_fqdn = false ) {
+		global $string_process_bugnote_link_callback;
 		$t_tag = config_get( 'bugnote_link_tag' );
+
 		# bail if the link tag is blank
-		if ( '' == $t_tag ) {
+		if ( '' == $t_tag || $p_string == '' ) {
 			return $p_string;
 		}
 
-		preg_match_all( '/(^|.+?)(?:(?<=^|\W)' . preg_quote($t_tag) . '(\d+)|$)/s',
-								$p_string, $t_matches, PREG_SET_ORDER );
-		$t_result = '';
-
-		if ( $p_include_anchor ) {
-			foreach ( $t_matches as $t_match ) {
-				$t_result .= $t_match[1];
-
-				if ( isset( $t_match[2] ) ) {
-					$t_bugnote_id = $t_match[2];
-					if ( bugnote_exists( $t_bugnote_id ) ) {
-						$t_bug_id = bugnote_get_field( $t_bugnote_id, 'bug_id' );
-						if ( bug_exists( $t_bug_id ) ) {
-							$t_result .= string_get_bugnote_view_link( $t_bug_id, $t_bugnote_id, null, $p_detail_info, $p_fqdn );
-						} else {
-							$t_result .= $t_bugnote_id;
-						}
-					}
-				}
-			}
-		} else {
-			foreach ( $t_matches as $t_match ) {
-				$t_result .= $t_match[1];
-
-				if ( isset( $t_match[2] ) ) {
-					$t_bugnote_id = $t_match[2];
-					$t_bug_id = bugnote_get_field( $t_bugnote_id, 'bug_id' );
-					# We might as well create the link here even if the bug
-					#  doesn't exist.  In the case above we don't want to do
-					#  the summary lookup on a non-existant bug.  But here, we
-					#  can create the link and by the time it is clicked on, the
-					#  bug may exist.
-
-					$t_result .= string_get_bugnote_view_url_with_fqdn( $t_bug_id, $t_bugnote_id, null );
-				}
+		if ( !isset ( $string_process_bugnote_link_callback[$p_include_anchor][$p_detail_info][$p_fqdn] ) ) {
+			if ($p_include_anchor) {
+				$string_process_bugnote_link_callback[$p_include_anchor][$p_detail_info][$p_fqdn] = create_function('$p_array','
+										if ( bugnote_exists( (int)$p_array[2] ) ) {
+											$t_bug_id = bugnote_get_field( (int)$p_array[2], \'bug_id\' );
+											if ( bug_exists( $t_bug_id ) ) {
+												return $p_array[1] . string_get_bugnote_view_link( $t_bug_id, (int)$p_array[2], null, ' . ($p_detail_info ? 'true' : 'false') . ', ' . ($p_fqdn ? 'true' : 'false') . ' );
+											} else {
+												return $p_array[0];
+											}
+										} else {
+											return $p_array[0];
+										}
+										');
+			} else {
+				$string_process_bugnote_link_callback[$p_include_anchor][$p_detail_info][$p_fqdn] = create_function('$p_array','
+										# We might as well create the link here even if the bug
+										#  doesnt exist.  In the case above we dont want to do
+										#  the summary lookup on a non-existant bug.  But here, we
+										#  can create the link and by the time it is clicked on, the
+										#  bug may exist.	
+										$t_bug_id = bugnote_get_field( (int)$p_array[2], \'bug_id\' );
+										if ( bug_exists( $t_bug_id ) ) {
+											return $p_array[1] . string_get_bugnote_view_url_with_fqdn( $t_bug_id, (int)$p_array[2], null );
+										} else {
+											return $p_array[0];
+										}
+										');
 			}
 		}
-
-		return $t_result;
+		$p_string = preg_replace_callback( '/(^|[^\w])' . preg_quote($t_tag, '/') .'(\d+)\b/', $string_process_bugnote_link_callback[$p_include_anchor][$p_detail_info][$p_fqdn], $p_string);
+		return $p_string;
 	}
 
 	#===================================
@@ -373,34 +411,8 @@
 			ini_set( 'magic_quotes_sybase', true );
 		}
 
-		# Set up a simple subset of RFC 822 email address parsing
-		#  We don't allow domain literals or quoted strings
-		#  We also don't allow the & character in domains even though the RFC
-		#  appears to do so.  This was to prevent &gt; etc from being included.
-		#  Note: we could use email_get_rfc822_regex() but it doesn't work well
-		#  when applied to data that has already had entities inserted.
-		#
-		# bpfennig: '@' doesn't accepted anymore
-		$t_atom = '[^\'@\'](?:[^()<>@,;:\\\".\[\]\000-\037\177 &]+)';
-
-		# In order to avoid selecting URLs containing @ characters as email
-		#  addresses we limit our selection to addresses that are preceded by:
-		#  * the beginning of the string
-		#  * a &lt; entity (allowing '<foo@bar.baz>')
-		#  * whitespace
-		#  * a : (allowing 'send email to:foo@bar.baz')
-		#  * a \n, \r, or > (because newlines have been replaced with <br />
-		#    and > isn't valid in URLs anyway
-		#
-		# At the end of the string we allow the opposite:
-		#  * the end of the string
-		#  * a &gt; entity
-		#  * whitespace
-		#  * a , character (allowing 'email foo@bar.baz, or ...')
-		#  * a \n, \r, or <
-
-		$p_string = preg_replace( '/(?<=^|&quot;|&lt;|[\s\:\>\n\r])('.$t_atom.'(?:\.'.$t_atom.')*\@'.$t_atom.'(?:\.'.$t_atom.')*)(?=$|&quot;|&gt;|[\s\,\<\n\r])/s',
-								'<a href="mailto:\1">\1</a>',
+		$p_string = preg_replace( '/\b' . email_regex_simple() . '\b/i',
+								'<a href="mailto:\0">\0</a>',
 								$p_string);
 
 		return $p_string;
@@ -426,23 +438,24 @@
 	# This function looks for text with htmlentities
 	# like &lt;b&gt; and converts is into corresponding
 	# html <b> based on the configuration presets
-	function string_restore_valid_html_tags( $p_string ) {
-		$t_html_valid_tags = config_get( 'html_valid_tags' );
+	function string_restore_valid_html_tags( $p_string, $p_multiline = true ) {
+		$t_html_valid_tags = config_get( $p_multiline ? 'html_valid_tags' : 'html_valid_tags_single_line' );
 
 		if ( OFF === $t_html_valid_tags || is_blank( $t_html_valid_tags ) ) {
 			return $p_string;
 		}
 
 		$tags = explode( ',', $t_html_valid_tags );
+		foreach ($tags as $key => $value) { 
+           if ( !is_blank( $value ) ) {
+           	$tags[$key] = trim($value); 
+           }
+          }
+        $tags = implode( '|', $tags);
 
-		foreach ( $tags as $tag ) {
-			if ( !is_blank( $tag ) ) {
-				$tag = trim( $tag );
-				$p_string = eregi_replace( "&lt;($tag)[[:space:]]*&gt;", "<\\1>", $p_string );
-				$p_string = eregi_replace( "&lt;\/($tag)[[:space:]]*&gt;", "</\\1>", $p_string );
-				$p_string = eregi_replace( "&lt;($tag)[[:space:]]*\/&gt;", "<\\1 />", $p_string );
-			}
-		}
+		$p_string = eregi_replace( '&lt;(' . $tags . ')[[:space:]]*&gt;', '<\\1>', $p_string );
+		$p_string = eregi_replace( '&lt;\/(' .$tags . ')[[:space:]]*&gt;', '</\\1>', $p_string );
+		$p_string = eregi_replace( '&lt;(' . $tags . ')[[:space:]]*\/&gt;', '<\\1 />', $p_string );
 
 		return $p_string;
 	}
@@ -539,7 +552,7 @@
 	# return the name and GET parameters of a bug VIEW page for the given bug
 	#  account for the user preference and site override
 	function string_get_bugnote_view_url( $p_bug_id, $p_bugnote_id, $p_user_id = null ) {
-		return 'view.php?id=' . $p_bug_id . '#'. $p_bugnote_id;
+		return 'view.php?id=' . $p_bug_id . '#c'. $p_bugnote_id;
 	}
 
 	# --------------------
@@ -548,7 +561,7 @@
 	# The returned url includes the fully qualified domain, hence it is suitable to be included
 	# in emails.
 	function string_get_bugnote_view_url_with_fqdn( $p_bug_id, $p_bugnote_id, $p_user_id = null ) {
-		return config_get( 'path' ) . string_get_bug_view_url( $p_bug_id, $p_user_id ).'#'.$p_bugnote_id;
+		return config_get( 'path' ) . string_get_bug_view_url( $p_bug_id, $p_user_id ).'#c'.$p_bugnote_id;
 	}
 
 	# --------------------
@@ -628,8 +641,7 @@
 	# --------------------
 	# Format date for display
 	function string_format_complete_date( $p_date ) {
-		$t_timestamp = db_unixtimestamp( $p_date );
-		return date( config_get( 'complete_date_format' ), $t_timestamp );
+		return date( config_get( 'complete_date_format' ), $p_date );
 	}
 
 	# --------------------
@@ -680,24 +692,19 @@
 
 	# --------------------
 	# Calls htmlentities on the specified string, passing along
-	# the current charset, if the current PHP version supports it.
+	# the current charset.
 	function string_html_entities( $p_string ) {
-		if ( php_version_at_least( '4.1.0' ) ) {
-			return htmlentities( $p_string, ENT_COMPAT, lang_get( 'charset' ) );
-		} else {
-			return htmlentities( $p_string );
-		}
+		return htmlentities( $p_string, ENT_COMPAT, lang_get( 'charset' ) );
 	}
 
 	# --------------------
 	# Calls htmlspecialchars on the specified string, passing along
 	# the current charset, if the current PHP version supports it.
 	function string_html_specialchars( $p_string ) {
-		if ( php_version_at_least( '4.1.0' ) ) {
-			return htmlspecialchars( $p_string, ENT_COMPAT, lang_get( 'charset' ) );
-		} else {
-			return htmlspecialchars( $p_string );
-		}
+		# achumakov: @ added to avoid warning output in unsupported codepages
+		# e.g. 8859-2, windows-1257, Korean, which are treated as 8859-1.
+		# This is VERY important for Eastern European, Baltic and Korean languages
+		return preg_replace("/&amp;(#[0-9]+|[a-z]+);/i", "&$1;", @htmlspecialchars( $p_string, ENT_COMPAT, lang_get( 'charset' ) ) );
 	}
 	
 	# --------------------
@@ -717,4 +724,14 @@
 
 		return $t_string;
 	}
+
+	# --------------------
+	# Checks the supplied string for scripting characters, if it contains any, then return true, otherwise return false.
+	function string_contains_scripting_chars( $p_string ) {
+		if ( ( strstr( $p_string, '<' ) !== false ) || ( strstr( $p_string, '>' ) !== false ) ) {
+			return true;
+		}
+
+		return false;
+	}
 ?>
