@@ -1,12 +1,24 @@
 <?php
-	# Mantis - a php based bugtracking system
-	# Copyright (C) 2000 - 2002  Kenzaburo Ito - kenito@300baud.org
-	# Copyright (C) 2002 - 2004  Mantis Team   - mantisbt-dev@lists.sourceforge.net
-	# This program is distributed under the terms and conditions of the GPL
-	# See the README and LICENSE files for details
+# Mantis - a php based bugtracking system
+
+# Copyright (C) 2000 - 2002  Kenzaburo Ito - kenito@300baud.org
+# Copyright (C) 2002 - 2007  Mantis Team   - mantisbt-dev@lists.sourceforge.net
+
+# Mantis is free software: you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation, either version 2 of the License, or
+# (at your option) any later version.
+#
+# Mantis is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with Mantis.  If not, see <http://www.gnu.org/licenses/>.
 
 	# --------------------------------------------------------
-	# $Id: manage_proj_cat_delete.php,v 1.22 2004/12/14 20:37:07 marcelloscata Exp $
+	# $Id: manage_proj_cat_delete.php,v 1.23.2.1 2007-10-13 22:33:31 giallu Exp $
 	# --------------------------------------------------------
 
 	require_once( 'core.php' );
@@ -15,6 +27,8 @@
 
 	require_once( $t_core_path.'category_api.php' );
 
+	auth_reauthenticate();
+
 	$f_project_id = gpc_get_int( 'project_id' );
 	$f_category = gpc_get_string( 'category' );
 
@@ -25,6 +39,7 @@
 		'<br/>' . lang_get( 'category' ) . ': ' . $f_category,
 		lang_get( 'delete_category_button' ) );
 
+	form_security_validate( 'manage_proj_cat_delete' );
 	category_remove( $f_project_id, $f_category );
 
 	$t_redirect_url = 'manage_proj_edit_page.php?project_id=' . $f_project_id;
