@@ -1,15 +1,26 @@
 <?php
-	# Mantis - a php based bugtracking system
-	# Copyright (C) 2000 - 2002  Kenzaburo Ito - kenito@300baud.org
-	# Copyright (C) 2002 - 2004  Mantis Team   - mantisbt-dev@lists.sourceforge.net
-	# This program is distributed under the terms and conditions of the GPL
-	# See the README and LICENSE files for details
+# Mantis - a php based bugtracking system
+
+# Copyright (C) 2000 - 2002  Kenzaburo Ito - kenito@300baud.org
+# Copyright (C) 2002 - 2007  Mantis Team   - mantisbt-dev@lists.sourceforge.net
+
+# Mantis is free software: you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation, either version 2 of the License, or
+# (at your option) any later version.
+#
+# Mantis is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with Mantis.  If not, see <http://www.gnu.org/licenses/>.
 
 	# --------------------------------------------------------
-	# $Id: manage_proj_edit_page.php,v 1.92.6.1.4.3 2007/03/06 07:00:33 vboctor Exp $
+	# $Id: manage_proj_edit_page.php,v 1.104.2.2 2007-10-19 07:25:59 vboctor Exp $
 	# --------------------------------------------------------
-?>
-<?php
+
 	require_once( 'core.php' );
 
 	$t_core_path = config_get( 'core_path' );
@@ -18,25 +29,27 @@
 	require_once( $t_core_path . 'version_api.php' );
 	require_once( $t_core_path . 'custom_field_api.php' );
 	require_once( $t_core_path . 'icon_api.php' );
-?>
-<?php
+
+	auth_reauthenticate();
+
 	$f_project_id = gpc_get_int( 'project_id' );
 
 	access_ensure_project_level( config_get( 'manage_project_threshold' ), $f_project_id );
 
 	$row = project_get_row( $f_project_id );
+	
+	html_page_top1( project_get_field( $f_project_id, 'name' ) );
+	html_page_top2();
+
+	print_manage_menu( 'manage_proj_edit_page.php' );
 ?>
-<?php html_page_top1() ?>
-<?php html_page_top2() ?>
-
-<?php print_manage_menu( 'manage_proj_edit_page.php' ) ?>
-
 <br />
 
 
 <!-- PROJECT PROPERTIES -->
 <div align="center">
 <form method="post" action="manage_proj_update.php">
+<?php echo form_security_field( 'manage_proj_update' ) ?>
 <table class="width75" cellspacing="1">
 
 <!-- Title -->
@@ -109,7 +122,7 @@
 		<?php echo lang_get( 'description' ) ?>
 	</td>
 	<td>
-		<textarea name="description" cols="60" rows="5" wrap="virtual"><?php echo string_textarea( $row['description'] ) ?></textarea>
+		<textarea name="description" cols="60" rows="5"><?php echo string_textarea( $row['description'] ) ?></textarea>
 	</td>
 </tr>
 
@@ -132,6 +145,7 @@
 if ( access_has_global_level ( config_get( 'delete_project_threshold' ) ) ) { ?>
 <div class="border-center">
 	<form method="post" action="manage_proj_delete.php">
+		<?php echo form_security_field( 'manage_proj_delete' ) ?>
 		<input type="hidden" name="project_id" value="<?php echo $f_project_id ?>" />
 		<input type="submit" class="button" value="<?php echo lang_get( 'delete_project_button' ) ?>" />
 	</form>
@@ -213,7 +227,7 @@ if ( access_has_global_level ( config_get( 'delete_project_threshold' ) ) ) { ?>
 		<?php
 				print_button( 'manage_proj_edit_page.php?project_id=' . $t_subproject['id'], lang_get( 'edit_link' ) );
 				echo '&nbsp;';
-				print_button( 'manage_proj_subproj_delete.php?project_id=' . $f_project_id . '&amp;subproject_id=' . $t_subproject['id'], lang_get( 'unlink_link' ) );
+				print_button( 'manage_proj_subproj_delete.php?project_id=' . $f_project_id . '&amp;subproject_id=' . $t_subproject['id'] . form_security_param( 'manage_proj_subproj_delete' ), lang_get( 'unlink_link' ) );
 		?>
 	</td>
 </tr>
@@ -226,6 +240,7 @@ if ( access_has_global_level ( config_get( 'delete_project_threshold' ) ) ) { ?>
 <tr>
 	<td class="left" colspan="2">
 		<form method="post" action="manage_proj_subproj_add.php">
+			<?php echo form_security_field( 'manage_proj_subproj_add' ) ?>
 			<input type="hidden" name="project_id" value="<?php echo $f_project_id ?>" />
 			<select name="subproject_id">
 <?php
@@ -235,7 +250,7 @@ if ( access_has_global_level ( config_get( 'delete_project_threshold' ) ) ) { ?>
 
 	$t_projects = project_get_all_rows();
 
-	$t_projects = multi_sort( $t_projects, 'name', ASC );
+	$t_projects = multi_sort( $t_projects, 'name', ASCENDING );
 
 	foreach ( $t_projects as $t_project ) {
 		if ( in_array( $t_project['id'], $t_all_subprojects ) ||
@@ -260,6 +275,7 @@ if ( access_has_global_level ( config_get( 'delete_project_threshold' ) ) ) { ?>
 <br />
 
 <!-- PROJECT CATEGORIES -->
+<a name="categories" />
 <div align="center">
 <table class="width75" cellspacing="1">
 
@@ -311,7 +327,7 @@ if ( access_has_global_level ( config_get( 'delete_project_threshold' ) ) ) { ?>
 
 					print_button( 'manage_proj_cat_edit_page.php?project_id=' . $f_project_id . '&amp;category=' . $t_name, lang_get( 'edit_link' ) );
 					echo '&nbsp;';
-					print_button( 'manage_proj_cat_delete.php?project_id=' . $f_project_id . '&amp;category=' . $t_name, lang_get( 'delete_link' ) );
+					print_button( 'manage_proj_cat_delete.php?project_id=' . $f_project_id . '&amp;category=' . $t_name . form_security_param( 'manage_proj_cat_delete' ), lang_get( 'delete_link' ) );
 				?>
 			</td>
 		</tr>
@@ -323,6 +339,7 @@ if ( access_has_global_level ( config_get( 'delete_project_threshold' ) ) ) { ?>
 <tr>
 	<td class="left" colspan="3">
 		<form method="post" action="manage_proj_cat_add.php">
+			<?php echo form_security_field( 'manage_proj_cat_add' ) ?>
 			<input type="hidden" name="project_id" value="<?php echo $f_project_id ?>" />
 			<input type="text" name="category" size="32" maxlength="64" />
 			<input type="submit" class="button" value="<?php echo lang_get( 'add_category_button' ) ?>" />
@@ -334,6 +351,7 @@ if ( access_has_global_level ( config_get( 'delete_project_threshold' ) ) ) { ?>
 <tr>
 	<td class="left" colspan="3">
 		<form method="post" action="manage_proj_cat_copy.php">
+			<?php echo form_security_field( 'manage_proj_cat_copy' ) ?>
 			<input type="hidden" name="project_id" value="<?php echo $f_project_id ?>" />
 			<select name="other_project_id">
 				<?php print_project_option_list( null, false, $f_project_id ); ?>
@@ -353,6 +371,7 @@ if ( access_has_global_level ( config_get( 'delete_project_threshold' ) ) ) { ?>
 ?>
 
 <!-- PROJECT VERSIONS -->
+<a name="versions" />
 <table class="width75" cellspacing="1">
 
 <!-- Title -->
@@ -370,6 +389,9 @@ if ( access_has_global_level ( config_get( 'delete_project_threshold' ) ) ) { ?>
 			<td>
 				<?php echo lang_get( 'version' ) ?>
 			</td>
+			<td class="center">
+				<?php echo lang_get( 'released' ) ?>
+			</td>
 			<td class="center">
 				<?php echo lang_get( 'timestamp' ) ?>
 			</td>
@@ -382,6 +404,7 @@ if ( access_has_global_level ( config_get( 'delete_project_threshold' ) ) ) { ?>
 
 	foreach ( $t_versions as $t_version ) {
 		$t_name = $t_version['version'];
+		$t_released = $t_version['released'];
 		$t_date_order = $t_version['date_order'];
 		$t_date_formatted = string_format_complete_date( $t_version['date_order'] );
 ?>
@@ -390,6 +413,9 @@ if ( access_has_global_level ( config_get( 'delete_project_threshold' ) ) ) { ?>
 			<td>
 				<?php echo string_display( $t_name ) ?>
 			</td>
+			<td class="center">
+				<?php echo trans_bool( $t_released ) ?>
+			</td>
 			<td class="center">
 				<?php echo $t_date_formatted ?>
 			</td>
@@ -399,7 +425,7 @@ if ( access_has_global_level ( config_get( 'delete_project_threshold' ) ) ) { ?>
 
 					print_button( 'manage_proj_ver_edit_page.php?version_id=' . $t_version_id, lang_get( 'edit_link' ) );
 					echo '&nbsp;';
-					print_button( 'manage_proj_ver_delete.php?version_id=' . $t_version_id, lang_get( 'delete_link' ) );
+					print_button( 'manage_proj_ver_delete.php?version_id=' . $t_version_id . form_security_param( 'manage_proj_ver_delete' ), lang_get( 'delete_link' ) );
 				?>
 			</td>
 		</tr>
@@ -411,6 +437,7 @@ if ( access_has_global_level ( config_get( 'delete_project_threshold' ) ) ) { ?>
 <tr>
 	<td class="left" colspan="3">
 		<form method="post" action="manage_proj_ver_add.php">
+			<?php echo form_security_field( 'manage_proj_ver_add' ) ?>
 			<input type="hidden" name="project_id" value="<?php echo $f_project_id ?>" />
 			<input type="text" name="version" size="32" maxlength="64" />
 			<input type="submit" name="add_version" class="button" value="<?php echo lang_get( 'add_version_button' ) ?>" />
@@ -418,6 +445,19 @@ if ( access_has_global_level ( config_get( 'delete_project_threshold' ) ) ) { ?>
 		</form>
 	</td>
 </tr>
+<tr>
+	<td class="left" colspan="3">
+		<form method="post" action="manage_proj_ver_copy.php">
+			<?php echo form_security_field( 'manage_proj_ver_copy' ) ?>
+			<input type="hidden" name="project_id" value="<?php echo $f_project_id ?>" />
+			<select name="other_project_id">
+				<?php print_project_option_list( null, false, $f_project_id ); ?>
+			</select>
+			<input type="submit" name="copy_from" class="button" value="<?php echo lang_get( 'copy_versions_from' ) ?>" />
+			<input type="submit" name="copy_to" class="button" value="<?php echo lang_get( 'copy_versions_to' ) ?>" />
+		</form>
+	</td>
+</tr>
 </table>
 </div>
 
@@ -428,6 +468,8 @@ if ( access_has_global_level ( config_get( 'delete_project_threshold' ) ) ) { ?>
 ?>
 
 <!-- PROJECT CUSTOM FIELD -->
+<a name="customfields" />
+
 <?php
 # You need either global permissions or project-specific permissions to link
 #  custom fields
@@ -459,7 +501,9 @@ if ( access_has_project_level( config_get( 'custom_field_link_threshold' ), $f_p
 				</td>
 			</tr>
 	<?php
-		}
+		$t_index = 0;	
+
+		$t_custom_field_security = form_security_field( 'manage_proj_custom_field_update' );
 
 		foreach( $t_custom_fields as $t_field_id ) {
 			$t_desc = custom_field_get_definition( $t_field_id );
@@ -470,25 +514,31 @@ if ( access_has_project_level( config_get( 'custom_field_link_threshold' ), $f_p
 				</td>
 				<td>
 <form method="post" action="manage_proj_custom_field_update.php">
+	<?php echo $t_custom_field_security ?>
 	<input type="hidden" name="project_id" value="<?php echo $f_project_id ?>" />
 	<input type="hidden" name="field_id" value="<?php echo $t_field_id ?>" />
 	<input type="text" name="sequence" value="<?php echo custom_field_get_sequence( $t_field_id, $f_project_id ) ?>" size="2" />
 	<input type="submit" class="button-small" value="<?php echo lang_get( 'update' ) ?>" />
 </form>
+	<?php 
+		$t_index++; 
+	?>
 				</td>
 				<td class="center">
 				<?php
 					# You need global permissions to edit custom field defs
-					print_button( "manage_proj_custom_field_remove.php?field_id=$t_field_id&amp;project_id=$f_project_id", lang_get( 'remove_link' ) );
+					print_button( "manage_proj_custom_field_remove.php?field_id={$t_field_id}&amp;project_id={$f_project_id}", lang_get( 'remove_link' ) );
 				?>
 				</td>
 			</tr>
 	<?php
 		} # end for loop
-	?>
+		}
+?>
 	<tr>
 		<td class="left" colspan="3">
 			<form method="post" action="manage_proj_custom_field_add_existing.php">
+			<?php echo form_security_field( 'manage_proj_custom_field_add_existing' ) ?>
 			<input type="hidden" name="project_id" value="<?php echo $f_project_id ?>" />
 			<select name="field_id">
 				<?php
@@ -507,6 +557,19 @@ if ( access_has_project_level( config_get( 'custom_field_link_threshold' ), $f_p
 			</form>
 		</td>
 	</tr>
+	<tr>
+		<td class="left" colspan="3">
+			<form method="post" action="manage_proj_custom_field_copy.php">
+				<?php echo form_security_field( 'manage_proj_custom_field_copy' ) ?>
+				<input type="hidden" name="project_id" value="<?php echo $f_project_id ?>" />
+				<select name="other_project_id">
+					<?php print_project_option_list( null, false, $f_project_id ); ?>
+				</select>
+				<input type="submit" name="copy_from" class="button" value="<?php echo lang_get( 'copy_from' ) ?>" />
+				<input type="submit" name="copy_to" class="button" value="<?php echo lang_get( 'copy_to' ) ?>" />
+			</form>
+		</td>
+	</tr>	
 	</table>
 	</div>
 <?php
@@ -543,6 +606,7 @@ if ( access_has_project_level( config_get( 'project_user_threshold' ), $f_projec
 <div align="center">
 	<table class="width75" cellspacing="1">
 		<form method="post" action="manage_proj_user_add.php">
+			<?php echo form_security_field( 'manage_proj_user_add' ) ?>
 			<input type="hidden" name="project_id" value="<?php echo $f_project_id ?>" />
 			<tr>
 				<td class="form-title" colspan="5">
@@ -577,6 +641,7 @@ if ( access_has_project_level( config_get( 'project_user_threshold' ), $f_projec
 		</form>
 		<!-- Copy Users Form -->
 		<form method="post" action="manage_proj_user_copy.php">
+			<?php echo form_security_field( 'manage_proj_user_copy' ) ?>
 			<tr>
 				<td class="left" colspan="3">
 						<input type="hidden" name="project_id" value="<?php echo $f_project_id ?>" />
@@ -642,6 +707,8 @@ if ( access_has_project_level( config_get( 'project_user_threshold' ), $f_projec
 	# reset the class counter
 	helper_alternate_class( 0 );
 
+	$t_user_remove_security = form_security_param( 'manage_proj_user_remove' );
+
 	for ($i = 0; $i < count( $t_sort ); $i++ ) {
 		$t_user = $t_users[$i];
 ?>
@@ -664,7 +731,7 @@ if ( access_has_project_level( config_get( 'project_user_threshold' ), $f_projec
 				#  from this project
 				if ( access_has_project_level( config_get( 'project_user_threshold' ), $f_project_id ) ) {
 					if ( project_includes_user( $f_project_id, $t_user['id'] )  ) {
-						print_button( 'manage_proj_user_remove.php?project_id=' . $f_project_id . '&amp;user_id=' . $t_user['id'], lang_get( 'remove_link' ) );
+						print_button( 'manage_proj_user_remove.php?project_id=' . $f_project_id . '&amp;user_id=' . $t_user['id'] . $t_user_remove_security, lang_get( 'remove_link' ) );
 					}
 				}
 			?>
@@ -682,7 +749,7 @@ if ( access_has_project_level( config_get( 'project_user_threshold' ), $f_projec
 		# You need global or project-specific permissions to remove users
 		#  from this project
 		if ( access_has_project_level( config_get( 'project_user_threshold' ), $f_project_id ) ) {
-			print_button( 'manage_proj_user_remove.php?project_id=' . $f_project_id, lang_get( 'remove_all_link' ) );
+			print_button( 'manage_proj_user_remove.php?project_id=' . $f_project_id . $t_user_remove_security, lang_get( 'remove_all_link' ) );
 		}
 	?>
 	</td>
