@@ -1,9 +1,21 @@
 <?php
-	# Mantis - a php based bugtracking system
-	# Copyright (C) 2000 - 2002  Kenzaburo Ito - kenito@300baud.org
-	# Copyright (C) 2002 - 2003  Mantis Team   - mantisbt-dev@lists.sourceforge.net
-	# This program is distributed under the terms and conditions of the GPL
-	# See the README and LICENSE files for details
+# Mantis - a php based bugtracking system
+
+# Copyright (C) 2000 - 2002  Kenzaburo Ito - kenito@300baud.org
+# Copyright (C) 2002 - 2007  Mantis Team   - mantisbt-dev@lists.sourceforge.net
+
+# Mantis is free software: you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation, either version 2 of the License, or
+# (at your option) any later version.
+#
+# Mantis is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with Mantis.  If not, see <http://www.gnu.org/licenses/>.
 ?>
 <?php
 	require_once( 'core.php' );
@@ -16,6 +28,7 @@
 	require_once( $t_core_path.'bug_api.php' );
 	require_once( $t_core_path.'string_api.php' );
 	require_once( $t_core_path.'date_api.php' );
+	require_once( $t_core_path.'tag_api.php' );
 
 	auth_ensure_user_authenticated();
 
@@ -30,7 +43,7 @@
 		?>
 		<body onload="SetInitialFocus();">
 
-		<script language="Javascript">
+		<script type="text/javascript" language="JavaScript">
 		<!--
 		function SetInitialFocus() {
 			<?php
@@ -86,7 +99,7 @@
 	$t_custom_rows = 0;
 
 	#get valid target fields
-	$t_fields = helper_call_custom_function( 'get_columns_to_view', array() );
+	$t_fields = helper_get_columns_to_view();
 	$t_n_fields = count( $t_fields );
 	for ( $i=0; $i < $t_n_fields; $i++ ) {
 		if ( in_array( $t_fields[$i], array( 'selection', 'edit', 'bugnotes_count', 'attachment' ) ) ) {
@@ -372,21 +385,42 @@ if ( ON == config_get( 'filter_by_custom_fields' ) ) {
 		}
 	}
 }
+
+if ( 'simple' == $f_view_type ) {
+	$t_project_cols = 0;
+} else {
+	$t_project_cols = 3;
+}
 ?>
 
 <tr class="row-1">
 	<td class="small-caption" colspan="<?php echo ( 1 * $t_custom_cols ); ?>" valign="top">
 		<?php PRINT lang_get( 'sort' ) ?>:
 	</td>
-	<td valign="top" colspan="<?php echo ( ( $t_filter_cols - 1 ) * $t_custom_cols ); ?>">
+	<td valign="top" colspan="<?php echo ( ( $t_filter_cols - 1 - $t_project_cols ) * $t_custom_cols ); ?>">
 		<?php
 			print_filter_show_sort();
 		?>
 	</td>
+	<?php
+		if ( 'advanced' == $f_view_type ) {
+	?>
+			<td class="small-caption" colspan="<?php echo ( 1 * $t_custom_cols ); ?>" valign="top">
+				<?php PRINT lang_get( 'email_project' ) ?>:
+			</td>
+			<td valign="top" colspan="<?php echo( 2 * $t_custom_cols ); ?>">
+				<?php
+					print_filter_project_id();
+				?>
+			</td>
+	<?php
+		}
+	?>
 </tr>
 <tr class="row-category2">
 <td class="small-caption" colspan="<?php echo ( 1 * $t_custom_cols ); ?>"><?php echo lang_get( 'search' ) ?></td>
-<td class="small-caption" colspan="<?php echo ( ( $t_filter_cols - 1 ) * $t_custom_cols ); ?>"></td>
+<td class="small-caption" colspan="<?php echo ( ( $t_filter_cols - 2 ) * $t_custom_cols ); ?>"><?php echo lang_get( 'tags' ) ?></td>
+<td class="small-caption" colspan="<?php echo ( 1 * $t_custom_cols ); ?>"></td>
 </tr>
 <tr>
 	<!-- Search field -->
@@ -394,13 +428,12 @@ if ( ON == config_get( 'filter_by_custom_fields' ) ) {
 		<input type="text" size="16" name="search" value="<?php echo string_html_specialchars( $t_filter['search'] ); ?>" />
 	</td>
 
-	<td class="small-caption" colspan="<?php echo ( ( $t_filter_cols - 3 ) * $t_custom_cols ); ?>"></td>
+	<td class="small-caption" colspan="<?php echo ( ( $t_filter_cols - 2 ) * $t_custom_cols ); ?>"><?php print_filter_tag_string() ?></td>
 
 	<!-- Submit button -->
 	<td class="right" colspan="<?php echo ( 1 * $t_custom_cols ); ?>">
 		<input type="submit" name="filter" class="button" value="<?php echo lang_get( 'filter_button' ) ?>" />
 	</td>
-	<td class="small-caption" colspan="<?php echo ( 1 * $t_custom_cols ); ?>"></td>
 </tr>
 </table>
 </form>
